@@ -1,18 +1,15 @@
-/* $Id: dot.c,v 1.51 2010/01/07 14:58:48 arif Exp $ $Revision: 1.51 $ */
+/* $Id: dot.c,v 1.60 2011/03/07 18:05:47 erg Exp $ $Revision: 1.60 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 /*
  * Written by Stephen North and Eleftherios Koutsofios.
@@ -35,6 +32,13 @@ __declspec(dllimport) boolean MemTest;
 
 #ifdef WIN32_DLL
 __declspec(dllimport) boolean MemTest;
+/*gvc.lib cgraph.lib*/
+#ifdef WITH_CGRAPH
+    #pragma comment( lib, "cgraph.lib" )
+#else
+    #pragma comment( lib, "graph.lib" )
+#endif
+    #pragma comment( lib, "gvc.lib" )
 #endif
 
 #include <stdlib.h>
@@ -127,6 +131,7 @@ static graph_t *create_test_graph(void)
 
     Agnode_t *node[NUMNODES];
     Agraph_t *g;
+    Agraph_t *sg;
     int j, k;
     char name[10];
 
@@ -161,14 +166,18 @@ static graph_t *create_test_graph(void)
 #endif /* WITH_CGRAPH */
 	}
     }
+
+    sg = agsubg (g, "cluster1");
+    aginsert (sg, node[0]);
+
     return g;
 }
 
 int main(int argc, char **argv)
 {
     graph_t *prev = NULL;
+    int r, rc = 0;
 #ifndef WITH_CGRAPH
-
 #endif /* WITH_CGRAPH */
 
     Gvc = gvContextPlugins(lt_preloaded_symbols, DEMAND_LOADING);
@@ -209,9 +218,14 @@ int main(int argc, char **argv)
 	    }
 	    gvLayoutJobs(Gvc, G);  /* take layout engine from command line */
 	    gvRenderJobs(Gvc, G);
+	    r = agreseterrors();
+	    rc = MAX(rc,r);
 	    prev = G;
 	}
     }
     gvFinalize(Gvc);
-    return (gvFreeContext(Gvc));
+    
+
+    r = gvFreeContext(Gvc);
+    return (MAX(rc,r));
 }
