@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,11 +54,65 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 
 
+/* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
+#line 14 "../../../cmd/lefty/dot2l/dotparse.y"
+
+#if _PACKAGE_ast
+#include <ast.h>
+#endif
+#include <stdio.h>
+
+typedef void *Tobj;
+
+#include "config.h"
+#include "dot2l.h"
+
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+
+#include <string.h>
+
+static char portstr[SMALLBUF];
+
+extern void yyerror(const char *fmt, ...);
+
+
+/* Line 189 of yacc.c  */
+#line 96 "y.tab.c"
+
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+
+/* Enabling verbose error messages.  */
+#ifdef YYERROR_VERBOSE
+# undef YYERROR_VERBOSE
+# define YYERROR_VERBOSE 1
+#else
+# define YYERROR_VERBOSE 0
+#endif
+
+/* Enabling the token table.  */
+#ifndef YYTOKEN_TABLE
+# define YYTOKEN_TABLE 0
+#endif
+
+
 /* Tokens.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
@@ -89,71 +142,33 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 17 "../../../cmd/lefty/dot2l/dotparse.y"
-
-#if _PACKAGE_ast
-#include <ast.h>
-#endif
-#include <stdio.h>
-
-typedef void *Tobj;
-
-#include "config.h"
-#include "dot2l.h"
-
-#ifdef HAVE_STDLIB_H
-# include <stdlib.h>
-#endif
-
-#include <string.h>
-
-static char portstr[SMALLBUF];
-
-extern void yyerror(const char *fmt, ...);
-
-
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
-
-/* Enabling verbose error messages.  */
-#ifdef YYERROR_VERBOSE
-# undef YYERROR_VERBOSE
-# define YYERROR_VERBOSE 1
-#else
-# define YYERROR_VERBOSE 0
-#endif
-
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
-#endif
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 39 "../../../cmd/lefty/dot2l/dotparse.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 36 "../../../cmd/lefty/dot2l/dotparse.y"
+
     long i;
     char *s;
     void *o;
-}
-/* Line 187 of yacc.c.  */
-#line 144 "y.tab.c"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 160 "y.tab.c"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 157 "y.tab.c"
+/* Line 264 of yacc.c  */
+#line 172 "y.tab.c"
 
 #ifdef short
 # undef short
@@ -228,14 +243,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -316,9 +331,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -352,12 +367,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -457,13 +472,13 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    54,    54,    53,    57,    60,    63,    65,    67,    69,
-      73,    74,    77,    78,    81,    82,    85,    86,    87,    88,
-      91,    91,    95,    99,   104,   106,   103,   110,   112,   109,
-     117,   120,   119,   121,   124,   123,   127,   128,   129,   130,
-     131,   134,   138,   147,   154,   153,   157,   161,   163,   165,
-     169,   172,   173,   176,   179,   180,   183,   187,   188,   191,
-     193,   193,   195,   199
+       0,    51,    51,    50,    54,    57,    60,    62,    64,    66,
+      70,    71,    74,    75,    78,    79,    82,    83,    84,    85,
+      88,    88,    92,    96,   101,   103,   100,   107,   109,   106,
+     114,   117,   116,   118,   121,   120,   124,   125,   126,   127,
+     128,   131,   135,   144,   151,   150,   154,   158,   160,   162,
+     166,   169,   170,   173,   176,   177,   180,   184,   185,   188,
+     190,   190,   192,   196
 };
 #endif
 
@@ -475,12 +490,12 @@ static const char *const yytname[] =
   "$end", "error", "$undefined", "T_graph", "T_digraph", "T_strict",
   "T_node", "T_edge", "T_edgeop", "T_id", "T_subgraph", "'{'", "'}'",
   "';'", "':'", "'('", "','", "')'", "'@'", "'['", "']'", "'='", "$accept",
-  "file", "@1", "graph_type", "stmt_list", "stmt_list1", "stmt", "stmt1",
-  "node_stmt", "@2", "node_id", "node_name", "edge_stmt", "@3", "@4", "@5",
-  "@6", "edgeRHS", "@7", "@8", "node_port", "port_location", "port_angle",
-  "attr_stmt", "@9", "attr_class", "opt_attr_list", "rec_attr_list",
-  "attr_list", "inside_attr_list", "attr_set", "optcomma", "subg_stmt",
-  "@10", "subg_hdr", 0
+  "file", "$@1", "graph_type", "stmt_list", "stmt_list1", "stmt", "stmt1",
+  "node_stmt", "$@2", "node_id", "node_name", "edge_stmt", "$@3", "$@4",
+  "$@5", "$@6", "edgeRHS", "$@7", "$@8", "node_port", "port_location",
+  "port_angle", "attr_stmt", "$@9", "attr_class", "opt_attr_list",
+  "rec_attr_list", "attr_list", "inside_attr_list", "attr_set", "optcomma",
+  "subg_stmt", "$@10", "subg_hdr", 0
 };
 #endif
 
@@ -793,17 +808,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -837,11 +855,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1121,10 +1139,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1140,11 +1156,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1152,9 +1167,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1178,14 +1193,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1193,51 +1233,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1267,7 +1284,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1275,7 +1291,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1298,9 +1313,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1311,7 +1325,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1321,6 +1334,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1329,16 +1345,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1370,20 +1386,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1423,129 +1435,179 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 54 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 51 "../../../cmd/lefty/dot2l/dotparse.y"
     { D2Lbegin ((yyvsp[(2) - (2)].s)); free ((yyvsp[(2) - (2)].s)); }
     break;
 
   case 3:
-#line 56 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 53 "../../../cmd/lefty/dot2l/dotparse.y"
     { D2Lend (); }
     break;
 
   case 4:
-#line 58 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 55 "../../../cmd/lefty/dot2l/dotparse.y"
     { D2Labort (); }
     break;
 
   case 5:
-#line 60 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 57 "../../../cmd/lefty/dot2l/dotparse.y"
     { D2Labort (); }
     break;
 
   case 6:
-#line 64 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 61 "../../../cmd/lefty/dot2l/dotparse.y"
     { gtype = "graph"; etype = "--"; }
     break;
 
   case 7:
-#line 66 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 63 "../../../cmd/lefty/dot2l/dotparse.y"
     { gtype = "strict graph"; etype = "--"; }
     break;
 
   case 8:
-#line 68 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 65 "../../../cmd/lefty/dot2l/dotparse.y"
     { gtype = "digraph"; etype = "->"; }
     break;
 
   case 9:
-#line 70 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 67 "../../../cmd/lefty/dot2l/dotparse.y"
     { gtype = "strict digraph"; etype = "->"; }
     break;
 
   case 19:
-#line 88 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 85 "../../../cmd/lefty/dot2l/dotparse.y"
     {}
     break;
 
   case 20:
-#line 91 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 88 "../../../cmd/lefty/dot2l/dotparse.y"
     { attrclass = NODE; portstr[0] = '\000'; }
     break;
 
   case 21:
-#line 92 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 89 "../../../cmd/lefty/dot2l/dotparse.y"
     { attrclass = GRAPH; }
     break;
 
   case 22:
-#line 96 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 93 "../../../cmd/lefty/dot2l/dotparse.y"
     { (yyval.o) = (yyvsp[(1) - (2)].o); }
     break;
 
   case 23:
-#line 100 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 97 "../../../cmd/lefty/dot2l/dotparse.y"
     { (yyval.o) = D2Linsertnode ((yyvsp[(1) - (1)].s)); free ((yyvsp[(1) - (1)].s)); }
     break;
 
   case 24:
-#line 104 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 101 "../../../cmd/lefty/dot2l/dotparse.y"
     { D2Lbeginedge (NODE, (yyvsp[(1) - (1)].o), portstr); portstr[0] = '\000'; }
     break;
 
   case 25:
-#line 106 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 103 "../../../cmd/lefty/dot2l/dotparse.y"
     { attrclass = EDGE; }
     break;
 
   case 26:
-#line 108 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 105 "../../../cmd/lefty/dot2l/dotparse.y"
     { D2Lendedge (); attrclass = GRAPH; }
     break;
 
   case 27:
-#line 110 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 107 "../../../cmd/lefty/dot2l/dotparse.y"
     { D2Lbeginedge (GRAPH, (yyvsp[(1) - (1)].o), ""); }
     break;
 
   case 28:
-#line 112 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 109 "../../../cmd/lefty/dot2l/dotparse.y"
     { attrclass = EDGE; }
     break;
 
   case 29:
-#line 114 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 111 "../../../cmd/lefty/dot2l/dotparse.y"
     { D2Lendedge (); attrclass = GRAPH; }
     break;
 
   case 30:
-#line 118 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 115 "../../../cmd/lefty/dot2l/dotparse.y"
     { D2Lmidedge (NODE, (yyvsp[(2) - (2)].o), portstr); portstr[0] = '\000'; }
     break;
 
   case 31:
-#line 120 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 117 "../../../cmd/lefty/dot2l/dotparse.y"
     { D2Lmidedge (NODE, (yyvsp[(2) - (2)].o), portstr); portstr[0] = '\000'; }
     break;
 
   case 33:
-#line 122 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 119 "../../../cmd/lefty/dot2l/dotparse.y"
     { D2Lmidedge (GRAPH, (yyvsp[(2) - (2)].o), ""); portstr[0] = '\000'; }
     break;
 
   case 34:
-#line 124 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 121 "../../../cmd/lefty/dot2l/dotparse.y"
     { D2Lmidedge (GRAPH, (yyvsp[(2) - (2)].o), ""); portstr[0] = '\000'; }
     break;
 
   case 41:
-#line 135 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 132 "../../../cmd/lefty/dot2l/dotparse.y"
     {
         strcat (portstr, (yyvsp[(2) - (2)].s)); free ((yyvsp[(2) - (2)].s));
     }
     break;
 
   case 42:
-#line 139 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 136 "../../../cmd/lefty/dot2l/dotparse.y"
     {
         strcat (portstr, "("); strcat (portstr, (yyvsp[(3) - (6)].s));
         strcat (portstr, ","); strcat (portstr, (yyvsp[(5) - (6)].s));
@@ -1555,75 +1617,102 @@ yyreduce:
     break;
 
   case 43:
-#line 148 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 145 "../../../cmd/lefty/dot2l/dotparse.y"
     {
         strcat (portstr, "@"); strcat (portstr, (yyvsp[(2) - (2)].s)); free ((yyvsp[(2) - (2)].s));
     }
     break;
 
   case 44:
-#line 154 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 151 "../../../cmd/lefty/dot2l/dotparse.y"
     { inattrstmt = TRUE; }
     break;
 
   case 45:
-#line 156 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 153 "../../../cmd/lefty/dot2l/dotparse.y"
     { attrclass = GRAPH; inattrstmt = FALSE; }
     break;
 
   case 46:
-#line 158 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 155 "../../../cmd/lefty/dot2l/dotparse.y"
     { attrclass = GRAPH; }
     break;
 
   case 47:
-#line 162 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 159 "../../../cmd/lefty/dot2l/dotparse.y"
     { attrclass = GRAPH; }
     break;
 
   case 48:
-#line 164 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 161 "../../../cmd/lefty/dot2l/dotparse.y"
     { attrclass = NODE; }
     break;
 
   case 49:
-#line 166 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 163 "../../../cmd/lefty/dot2l/dotparse.y"
     { attrclass = EDGE; }
     break;
 
   case 56:
-#line 184 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 181 "../../../cmd/lefty/dot2l/dotparse.y"
     { D2Lsetattr ((yyvsp[(1) - (3)].s), (yyvsp[(3) - (3)].s)); free ((yyvsp[(1) - (3)].s)); free ((yyvsp[(3) - (3)].s)); }
     break;
 
   case 59:
-#line 192 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 189 "../../../cmd/lefty/dot2l/dotparse.y"
     { (yyval.o) = D2Lpopgraph (); }
     break;
 
   case 60:
-#line 193 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 190 "../../../cmd/lefty/dot2l/dotparse.y"
     { D2Lpushgraph (NULL); }
     break;
 
   case 61:
-#line 194 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 191 "../../../cmd/lefty/dot2l/dotparse.y"
     { (yyval.o) = D2Lpopgraph (); }
     break;
 
   case 62:
-#line 196 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 193 "../../../cmd/lefty/dot2l/dotparse.y"
     { (yyval.o) = D2Lpopgraph (); }
     break;
 
   case 63:
-#line 200 "../../../cmd/lefty/dot2l/dotparse.y"
+
+/* Line 1455 of yacc.c  */
+#line 197 "../../../cmd/lefty/dot2l/dotparse.y"
     { D2Lpushgraph ((yyvsp[(2) - (2)].s)); free ((yyvsp[(2) - (2)].s)); }
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1627 "y.tab.c"
+
+/* Line 1455 of yacc.c  */
+#line 1716 "y.tab.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1634,7 +1723,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -1699,7 +1787,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -1716,7 +1804,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -1773,9 +1861,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -1800,7 +1885,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -1811,7 +1896,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
