@@ -1,18 +1,15 @@
-/* $Id: draw.c,v 1.52 2009/12/03 19:16:04 arif Exp $ $Revision: 1.52 $ */
+/* $Id: draw.c,v 1.69 2011/01/25 16:30:46 ellson Exp $ $Revision: 1.69 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 /*
 
@@ -20,16 +17,20 @@ XDOT DRAWING FUNCTIONS, maybe need to move them somewhere else
 		for now keep them at the bottom
 */
 #include "draw.h"
-#include "topview.h"
+/* #include "topview.h" */
 #include "colorprocs.h"
+#include "smyrna_utils.h"
 #include "glutils.h"
 #include "math.h"
-#include "selection.h"
+
 #include "xdot.h"
 #include "viewport.h"
 #include "topfisheyeview.h"
 #include "appmouse.h"
 #include "hotkeymap.h"
+#include "polytess.h"
+#include "glcompimage.h"
+
 
 //delta values
 static float dx = 0.0;
@@ -42,23 +43,22 @@ GLubyte rasters[24] = {
     0xc0, 0x00, 0xc0, 0x00, 0xc0, 0x00, 0xff, 0xc0, 0xff, 0xc0
 };
 
-void DrawBezier(GLfloat * xp, GLfloat * yp, GLfloat * zp, int filled,
-		int param)
+static void DrawBezier(xdot_point* pts, int filled, int param)
 {
     /*copied from NEHE */
     /*Written by: David Nikdel ( ogapo@ithink.net ) */
-    double Ax = xp[0];
-    double Ay = yp[0];
-    double Az = zp[0];
-    double Bx = xp[1];
-    double By = yp[1];
-    double Bz = zp[1];
-    double Cx = xp[2];
-    double Cy = yp[2];
-    double Cz = zp[2];
-    double Dx = xp[3];
-    double Dy = yp[3];
-    double Dz = zp[3];
+    double Ax = pts[0].x;
+    double Ay = pts[0].y;
+    double Az = pts[0].z;
+    double Bx = pts[1].x;
+    double By = pts[1].y;
+    double Bz = pts[1].z;
+    double Cx = pts[2].x;
+    double Cy = pts[2].y;
+    double Cz = pts[2].z;
+    double Dx = pts[3].x;
+    double Dy = pts[3].y;
+    double Dz = pts[3].z;
     double X;
     double Y;
     double Z;
@@ -73,7 +73,7 @@ void DrawBezier(GLfloat * xp, GLfloat * yp, GLfloat * zp, int filled,
 	if (param == 0)
 	    glColor4f(view->penColor.R, view->penColor.G, view->penColor.B,
 		      view->penColor.A);
-	if (param == 1)		//selected
+	else if (param == 1)		//selected
 	    glColor4f(view->selectedNodeColor.R, view->selectedNodeColor.G,
 		      view->selectedNodeColor.B,
 		      view->selectedNodeColor.A);
@@ -82,7 +82,7 @@ void DrawBezier(GLfloat * xp, GLfloat * yp, GLfloat * zp, int filled,
 	if (param == 0)
 	    glColor4f(view->fillColor.R, view->fillColor.G,
 		      view->fillColor.B, view->penColor.A);
-	if (param == 1)		//selected
+	else if (param == 1)		//selected
 	    glColor4f(view->selectedNodeColor.R, view->selectedNodeColor.G,
 		      view->selectedNodeColor.B,
 		      view->selectedNodeColor.A);
@@ -125,9 +125,10 @@ static void set_options(sdot_op * op, int param)
 
 }
 
+#if 0
 static void relocate_spline(sdot_op * sop, int param)
 {
-/*    Agedge_t *e;
+    Agedge_t *e;
     Agnode_t *tn;		//tail node
     Agnode_t *hn;		//head node
     int i = 0;
@@ -199,63 +200,45 @@ static void relocate_spline(sdot_op * sop, int param)
 				}
 			}
 		}
-	}*/
+	}
 }
+#endif
 
-void DrawBeziers(sdot_op* o, int param)
+static void DrawBeziers(sdot_op* o, int param)
 {
-    //SEND ALL CONTROL POINTS IN 3D ARRAYS
-
-	GLfloat tempX[4];
-    GLfloat tempY[4];
-    GLfloat tempZ[4];
-    int temp = 0;
+    /* GLfloat tempX[4]; */
+    /* GLfloat tempY[4]; */
+    /* GLfloat tempZ[4]; */
+    /* int temp = 0; */
     int filled;
     int i = 0;
-	static xdot_op * op;
-	op=&o->op;
-	view->Topview->global_z=view->Topview->global_z+o->layer*LAYER_DIFF;
+    xdot_op *  op=&o->op;
+    xdot_point* ps = op->u.bezier.pts;
+    view->Topview->global_z = view->Topview->global_z + o->layer*LAYER_DIFF;
 
-//    SelectBeziers((sdot_op *) op);
-    relocate_spline((sdot_op *) op, param);
+    /* SelectBeziers((sdot_op *) op); */
+    /* relocate_spline((sdot_op *) op, param); */
     if (op->kind == xd_filled_bezier)
 	filled = 1;
     else
 	filled = 0;
 
-    for (i = 0; i < op->u.bezier.cnt; i = i + 1) {
-	if (temp == 4) {
-	    DrawBezier(tempX, tempY, tempZ, filled, param);
-	    tempX[0] = (GLfloat) op->u.bezier.pts[i - 1].x;
-	    tempY[0] = (GLfloat) op->u.bezier.pts[i - 1].y;
-	    tempZ[0] = (GLfloat) op->u.bezier.pts[i - 1].z;
-	    temp = 1;
-	    tempX[temp] = (GLfloat) op->u.bezier.pts[i].x;
-	    tempY[temp] = (GLfloat) op->u.bezier.pts[i].y;
-	    tempZ[temp] = (GLfloat) op->u.bezier.pts[i].z;
-	    temp = temp + 1;
-	} else {
-	    tempX[temp] = (GLfloat) op->u.bezier.pts[i].x;
-	    tempY[temp] = (GLfloat) op->u.bezier.pts[i].y;
-	    tempZ[temp] = (GLfloat) op->u.bezier.pts[i].z;
-	    temp = temp + 1;
-	}
+    for (i = 1; i < op->u.bezier.cnt; i += 3) {
+	DrawBezier(ps, filled, param);
+	ps += 3;
     }
-    DrawBezier(tempX, tempY, tempZ, filled, param);
 }
 
-
 //Draws an ellpise made out of points.
 //void DrawEllipse(xdot_point* xpoint,GLfloat xradius, GLfloat yradius,int filled)
-void DrawEllipse(sdot_op*  o, int param)
+static void DrawEllipse(sdot_op*  o, int param)
 {
     //to draw a circle set xradius and yradius same values
     GLfloat x, y, xradius, yradius;
     int i = 0;
     int filled;
-	static xdot_op * op;
-	op=&o->op;
-	view->Topview->global_z=view->Topview->global_z+o->layer*LAYER_DIFF;
+    xdot_op * op=&o->op;
+    view->Topview->global_z=view->Topview->global_z+o->layer*LAYER_DIFF;
     set_options((sdot_op *) op, param);
     x = op->u.ellipse.x - dx;
     y = op->u.ellipse.y - dy;
@@ -297,14 +280,12 @@ void DrawEllipse(sdot_op*  o, int param)
     glEnd();
 }
 
-extern void DrawPolygon(sdot_op * o, int param)
+static void DrawPolygon(sdot_op * o, int param)
 //void DrawPolygon(xdot_point* xpoint,int count, int filled)
 {
-    int i = 0;
     int filled;
-	static xdot_op * op;
-	op=&o->op;
-	view->Topview->global_z=view->Topview->global_z+o->layer*LAYER_DIFF;
+    xdot_op *  op=&o->op;
+    view->Topview->global_z=view->Topview->global_z+o->layer*LAYER_DIFF;
 
 	//SelectPolygon((sdot_op *) op);
     set_options((sdot_op *) op, param);
@@ -331,6 +312,8 @@ extern void DrawPolygon(sdot_op * o, int param)
 
     }
     glLineWidth(view->LineWidth);
+    drawTessPolygon(o);
+/*
     if (!filled)
 	glBegin(GL_LINE_STRIP);
     else
@@ -341,15 +324,22 @@ extern void DrawPolygon(sdot_op * o, int param)
 		   (GLfloat) op->u.polygon.pts[i].z + view->Topview->global_z);
     }
     glVertex3f((GLfloat) op->u.polygon.pts[0].x - dx, (GLfloat) op->u.polygon.pts[0].y - dy, (GLfloat) op->u.polygon.pts[0].z + view->Topview->global_z);	//close the polygon
-    glEnd();
+    glEnd();*/
 }
 
-void DrawPolyline(sdot_op* o, int param)
+
+#if 0
+static void DrawPolygon2(sdot_op * o, int param)
+{
+    drawTessPolygon(o);
+}
+#endif
+
+static void DrawPolyline(sdot_op* o, int param)
 {
     int i = 0;
-	static xdot_op * op;
-	op=&o->op;
-	view->Topview->global_z=view->Topview->global_z+o->layer*LAYER_DIFF;
+    xdot_op * op=&o->op;
+    view->Topview->global_z=view->Topview->global_z+o->layer*LAYER_DIFF;
 
     if (param == 0)
 	glColor4f(view->penColor.R, view->penColor.G, view->penColor.B,
@@ -369,22 +359,37 @@ void DrawPolyline(sdot_op* o, int param)
     glEnd();
 }
 
-void SetFillColor(sdot_op*  o, int param)
+static glCompColor GetglCompColor(char *color)
 {
-	glCompColor c;
-	static xdot_op * op;
-	op=&o->op;
-    c = GetglCompColor(op->u.color);
+    gvcolor_t cl;
+    glCompColor c;
+    if (color != '\0') {
+	colorxlate(color, &cl, RGBA_DOUBLE);
+	c.R = (float) cl.u.RGBA[0];
+	c.G = (float) cl.u.RGBA[1];
+	c.B = (float) cl.u.RGBA[2];
+	c.A = (float) cl.u.RGBA[3];
+    } else {
+	c.R = view->penColor.R;
+	c.G = view->penColor.G;
+	c.B = view->penColor.B;
+	c.A = view->penColor.A;
+    }
+    return c;
+}
+static void SetFillColor(sdot_op*  o, int param)
+{
+    xdot_op * op=&o->op;
+    glCompColor c = GetglCompColor(op->u.color);
     view->fillColor.R = c.R;
     view->fillColor.G = c.G;
     view->fillColor.B = c.B;
     view->fillColor.A = c.A;
 }
-void SetPenColor(sdot_op* o, int param)
+static void SetPenColor(sdot_op* o, int param)
 {
     glCompColor c;
-	static xdot_op * op;
-	op=&o->op;
+    xdot_op * op=&o->op;
     c = GetglCompColor(op->u.color);
     view->penColor.R = c.R;
     view->penColor.G = c.G;
@@ -392,25 +397,43 @@ void SetPenColor(sdot_op* o, int param)
     view->penColor.A = c.A;
 }
 
-void SetStyle(sdot_op* o, int param)
+static void SetStyle(sdot_op* o, int param)
 {
-	static xdot_op * op;
-	op=&o->op;
-
-
+  /* xdot_op * op=&o->op; */
 }
 
 static sdot_op * font_op;
 
-void SetFont(sdot_op * o, int param)
+static void SetFont(sdot_op * o, int param)
 {
 	font_op=o;
 }
 
-void InsertImage(sdot_op * o, int param)
+/*for now we only support png files in 2d space, no image rotation*/
+static void InsertImage(sdot_op * o, int param)
 {
+    float x,y;
+    glCompImage *i;
+
+    if(!o->obj)
+	return;
+
+
+    if(!o->img) {
+	x = o->op.u.image.pos.x;
+	y = o->op.u.image.pos.y;
+	i = o->img = glCompImageNewFile (NULL, x, y, o->op.u.image.name, 0);
+	if (!o->img) {
+	    fprintf (stderr, "Could not open file \"%s\" to read image.\n", o->op.u.image.name);
+	    return;
+	}
+	i->width = o->op.u.image.pos.w;
+	i->height = o->op.u.image.pos.h;
+	i->common.functions.draw(i);
+    }
 }
-void EmbedText(sdot_op* o, int param)
+
+static void EmbedText(sdot_op* o, int param)
 {
 	GLfloat x,y;
 	glColor4f(view->penColor.R,view->penColor.G,view->penColor.B,view->penColor.A);
@@ -429,22 +452,21 @@ void EmbedText(sdot_op* o, int param)
 
 	}
 	y=o->op.u.text.y;
-	if (o->font)
-		glCompDrawText3D(o->font,x,y,view->Topview->global_z,o->op.u.text.width,font_op->op.u.font.size);
-	else
+	if (!o->font)
 	{
-		o->font=new_font(
+		o->font=glNewFont(
 		view->widgets,
-		o->op.u.text.text,
+		xml_string (o->op.u.text.text),
 		&view->penColor,
 		pangotext,
 		font_op->op.u.font.name,font_op->op.u.font.size,0);
-		//new_font(glCompSet * s, char *text, glCompColor * c, glCompFontType type, char *fontdesc, int fs)*/
-
-
+		//glNewFont(glCompSet * s, char *text, glCompColor * c, glCompFontType type, char *fontdesc, int fs)*/
 	}
+	glCompDrawText3D(o->font,x,y,view->Topview->global_z,o->op.u.text.width,font_op->op.u.font.size);
+
 }
 
+#if 0
 void draw_selection_box(ViewInfo * view)
 {
 /*    if (((view->mouse.mouse_mode == 4) || (view->mouse.mouse_mode == 5))
@@ -474,7 +496,9 @@ void draw_selection_box(ViewInfo * view)
 
     }*/
 }
+#endif
 
+#if 0
 void draw_magnifier(ViewInfo * view)
 {
 
@@ -489,7 +513,7 @@ void draw_magnifier(ViewInfo * view)
 	view->mg.x = mg_x;
 	view->mg.y = mg_y;
 	glLineWidth(4);
-	local_zoom(view->Topview);
+//	local_zoom(view->Topview);
 	//drawing the magnifier borders
 	glBegin(GL_LINE_STRIP);
 	glColor4f((GLfloat) 0.3, (GLfloat) 0.1, (GLfloat) 0.8,
@@ -523,7 +547,7 @@ void draw_magnifier(ViewInfo * view)
 
 }
 
-void draw_circle(float originX, float originY, float radius)
+static void draw_circle(float originX, float originY, float radius)
 {
 /* draw a circle from a bunch of short lines */
     float vectorX1, vectorY1, vectorX, vectorY, angle;
@@ -547,9 +571,7 @@ void draw_circle(float originX, float originY, float radius)
 GLUquadric *fisheyesphere;
 void draw_fisheye_magnifier(ViewInfo * view)
 {
-    if (get_mode(view)==MM_FISHEYE_MAGNIFIER)
-
-    {
+    if (get_mode(view)==MM_FISHEYE_MAGNIFIER) {
 	float a;
 	GLfloat mg_x, mg_y, mg_z;
 	a = GetOGLDistance((int) view->fmg.constantR);
@@ -558,38 +580,33 @@ void draw_fisheye_magnifier(ViewInfo * view)
 		     &mg_x, &mg_y, &mg_z);
 	glColor4f((GLfloat) 0.3, (GLfloat) 0.1, (GLfloat) 0.8,
 		  (GLfloat) 1);
-	if (((view->fmg.x != mg_x) || (view->fmg.y != mg_y))
-	    && (view->active_camera == -1)) {
-	    fisheye_polar(mg_x, mg_y, view->Topview);
-	    draw_circle(mg_x, mg_y, a);
+	if ((view->fmg.x != mg_x) || (view->fmg.y != mg_y)) {
+	    if (view->active_camera == -1) {
+		/* fisheye_polar(mg_x, mg_y, view->Topview); */
+		draw_circle(mg_x, mg_y, a);
+	    }
+	    else {
+		/* fisheye_spherical(mg_x, mg_y, 0.00, view->Topview); */
+		if (!fisheyesphere)
+		    fisheyesphere = gluNewQuadric();
+		gluQuadricDrawStyle(fisheyesphere, GLU_LINE);
+		glColor4f((GLfloat) 0.3, (GLfloat) 0.1, (GLfloat) 0.8, (GLfloat) 0.05);
+		glTranslatef(mg_x, mg_y, 0);
+		gluSphere(fisheyesphere, a, 30, 30);
+		glTranslatef(-mg_x, -mg_y, 0);
+	    }
+	    view->fmg.x = mg_x;
+	    view->fmg.y = mg_y;
 	}
-	if (((view->fmg.x != mg_x) || (view->fmg.y != mg_y))
-	    && (view->active_camera > -1)) {
-	    fisheye_spherical(mg_x, mg_y, 0.00, view->Topview);
-
-
-	    if (!fisheyesphere)
-		fisheyesphere = gluNewQuadric();
-	    gluQuadricDrawStyle(fisheyesphere, GLU_LINE);
-	    glColor4f((GLfloat) 0.3, (GLfloat) 0.1, (GLfloat) 0.8,
-		      (GLfloat) 0.05);
-	    glTranslatef(mg_x, mg_y, 0);
-	    gluSphere(fisheyesphere, a, 30, 30);
-	    glTranslatef(-mg_x, -mg_y, 0);
-	}
-
-
-	view->fmg.x = mg_x;
-	view->fmg.y = mg_y;
-
     }
 }
+#endif
 
 void drawBorders(ViewInfo * view)
 {
     if (view->bdVisible) {
-	glColor4f(view->borderColor.R, view->borderColor.B,
-		  view->borderColor.G, view->borderColor.A);
+	glColor4f(view->borderColor.R, view->borderColor.G,
+		  view->borderColor.B, view->borderColor.A);
 	glLineWidth(2);
 	glBegin(GL_LINE_STRIP);
 	glVertex3d(view->bdxLeft, view->bdyBottom,-0.001);
@@ -649,8 +666,8 @@ static void drawXdotwithattrs(void *e, int param)
 #endif
 
 
-
-/*void drawGraph(Agraph_t * g)
+#if 0
+void drawGraph(Agraph_t * g)
 {
     Agnode_t *v;
     Agedge_t *e;
@@ -694,8 +711,10 @@ static void drawXdotwithattrs(void *e, int param)
 		view->SignalBlock = 0;
     }
 
-}*/
+}
+#endif
 
+#if 0
 
 /*
 	this function is used to cache fonts in view->fontset
@@ -717,7 +736,6 @@ static void scanXdot(xdot * xDot, void *p)
 
 }
 
-
 static void scanXdotwithattr(void *p, char *attr)
 {
     xdot *xDot;
@@ -743,8 +761,7 @@ static void scanXdotwithattrs(void *e)
 	iterate in nodes and edges to cache fonts, run this once or whenever a new font is added to the graph
 */
 
-
-void scanGraph(Agraph_t * g)
+static void scanGraph(Agraph_t * g)
 {
     Agnode_t *v;
     Agedge_t *e;
@@ -773,6 +790,7 @@ int randomize_color(glCompColor * c, int brightness)
     c->B = B;
     return 1;
 }
+#endif
 
 
 void drawCircle(float x, float y, float radius, float zdepth)
@@ -781,7 +799,7 @@ void drawCircle(float x, float y, float radius, float zdepth)
     if (radius < 0.3)
 	radius = (float) 0.4;
     glBegin(GL_POLYGON);
-    for (i = 0; i < 360; i = i + 10) {
+    for (i = 0; i < 360; i = i + 36) {
 	float degInRad = (float) (i * DEG2RAD);
 	glVertex3f((GLfloat) (x + cos(degInRad) * radius),
 		   (GLfloat) (y + sin(degInRad) * radius),
@@ -804,24 +822,6 @@ drawfunc_t OpFns[] = {
     (drawfunc_t)InsertImage,
 };
 
-glCompColor GetglCompColor(char *color)
-{
-    gvcolor_t cl;
-    glCompColor c;
-    if (color != '\0') {
-	colorxlate(color, &cl, RGBA_DOUBLE);
-	c.R = (float) cl.u.RGBA[0];
-	c.G = (float) cl.u.RGBA[1];
-	c.B = (float) cl.u.RGBA[2];
-	c.A = (float) cl.u.RGBA[3];
-    } else {
-	c.R = view->penColor.R;
-	c.G = view->penColor.G;
-	c.B = view->penColor.B;
-	c.A = view->penColor.A;
-    }
-    return c;
-}
 void drawEllipse(float xradius, float yradius, int angle1, int angle2)
 {
     int i;
@@ -836,6 +836,8 @@ void drawEllipse(float xradius, float yradius, int angle1, int angle2)
 
     glEnd();
 }
+
+#if 0
 int draw_node_hintbox_gl_polygon(GLfloat x, GLfloat y, GLfloat z,
 				 GLfloat fs, char *text)
 {
@@ -920,7 +922,9 @@ int draw_node_hintbox(GLfloat x, GLfloat y, GLfloat z, GLfloat fs,
     return 1;
 
 }
+#endif
 
+#if 0
 static GLUquadric *sphere;
 void draw_sphere(float x, float y, float z, float r)
 {
@@ -931,6 +935,28 @@ void draw_sphere(float x, float y, float z, float r)
     gluSphere(fisheyesphere, r, SPHERE_SLICE_COUNT, SPHERE_SLICE_COUNT);
     glTranslatef(-x, -y, -z);
 }
+#endif
+
+void draw_selpoly(glCompPoly* selPoly)
+{
+    int i;
+/*    glColor4f(view->gridColor.R, view->gridColor.G, view->gridColor.B,
+		  view->gridColor.A);*/
+    glColor4f(1,0,0,1);
+    glBegin(GL_LINE_STRIP);
+    for (i = 0;i <  selPoly->cnt ; i++)
+    {
+	glVertex3f(selPoly->pts[i].x,selPoly->pts[i].y,selPoly->pts[i].z);
+    }
+    glEnd();
+    if(selPoly->cnt >0)
+    {
+        glBegin(GL_LINE_STRIP);
+	glVertex3f(selPoly->pts[selPoly->cnt-1].x,selPoly->pts[selPoly->cnt-1].y,selPoly->pts[selPoly->cnt-1].z);
+	glVertex3f(view->mouse.GLpos.x,view->mouse.GLpos.y,0);
+	glEnd();
+    }
+}
 
 #ifdef UNUSED
 void draw_xdot_set(xdot_set * s)
