@@ -1,45 +1,136 @@
-/* $Id: glexpose.c,v 1.47 2009/12/03 19:16:04 arif Exp $Revision: */
+/* $Id: glexpose.c,v 1.58 2011/01/25 16:30:46 ellson Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
-
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 #include "glexpose.h"
 #include "draw.h"
-#include "topview.h"
+#include "topviewfuncs.h"
 #include "glutils.h"
-#include "topview.h"
 #include "topfisheyeview.h"
 #include "gui/toolboxcallbacks.h"
 #include "arcball.h"
 #include "hotkeymap.h"
+#include "polytess.h"
 
-void drawRotatingAxis(void);
-void draw_cube()
+int texture[3];
+static int Status=0;									// Status Indicator
+
+void LoadGLTextures()									// Load Bitmaps And Convert To Textures
+{
+	int imageWidth,imageHeight;
+
+	unsigned char *data = glCompLoadPng ("c:/graphviz-ms/bin/Data/Crate.png", &imageWidth, &imageHeight);
+
+	if (!data)
+	{
+	    printf ("Data/Crate.bmp could not be located\n");
+	    exit(-1);
+	}
+	// Load The Bitmap, Check For Errors, If Bitmap's Not Found Quit
+	glGenTextures(3, &texture[0]);					// Create Three Textures
+
+		// Create Nearest Filtered Texture
+		glBindTexture(GL_TEXTURE_2D, texture[0]);
+		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_NEAREST);
+		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_NEAREST);
+		glTexImage2D(GL_TEXTURE_2D, 0, 3, imageWidth,imageHeight, 0, GL_RGBA, GL_UNSIGNED_BYTE, data);
+
+		// Create Linear Filtered Texture
+		glBindTexture(GL_TEXTURE_2D, texture[1]);
+		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
+		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR);
+		glTexImage2D(GL_TEXTURE_2D, 0, 3, imageWidth,imageHeight, 0, GL_RGBA, GL_UNSIGNED_BYTE, data);
+
+		// Create MipMapped Texture
+		glBindTexture(GL_TEXTURE_2D, texture[2]);
+		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
+		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR_MIPMAP_NEAREST);
+		gluBuild2DMipmaps(GL_TEXTURE_2D, 3, imageWidth,imageHeight, GL_RGBA, GL_UNSIGNED_BYTE,data);
+	Status=1;									// Set The Status To TRUE
+}
+
+
+#if UNUSED
+void draw_cube_tex()
 {
 
+
+    glRotatef(45,1,1,1);
+    glEnable(GL_TEXTURE_2D); // Enable Texture Mapping
+	glHint(GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST);	// Really Nice Perspective Calculations
+    if(!Status)
+	LoadGLTextures();
+    if(!Status)
+	return;
+    glBindTexture(GL_TEXTURE_2D,texture[1]);
+	glBegin(GL_QUADS);
+		// Front Face
+		glColor4f(1, 1, 1,1);	// Color Blue
+
+		glNormal3f( 0.0f, 0.0f, 1.0f);
+		glTexCoord2f(0.0f, 0.0f); glVertex3f(-100.0f, -100.0f,  100.0f);
+		glTexCoord2f(1.0f, 0.0f); glVertex3f( 100.0f, -100.0f,  100.0f);
+		glTexCoord2f(1.0f, 1.0f); glVertex3f( 100.0f,  100.0f,  100.0f);
+		glTexCoord2f(0.0f, 1.0f); glVertex3f(-100.0f,  100.0f,  100.0f);
+		// Back Face
+		glNormal3f( 0.0f, 0.0f,-1.0f);
+		glTexCoord2f(1.0f, 0.0f); glVertex3f(-100.0f, -100.0f, -100.0f);
+		glTexCoord2f(1.0f, 1.0f); glVertex3f(-100.0f,  100.0f, -100.0f);
+		glTexCoord2f(0.0f, 1.0f); glVertex3f( 100.0f,  100.0f, -100.0f);
+		glTexCoord2f(0.0f, 0.0f); glVertex3f( 100.0f, -100.0f, -100.0f);
+		// Top Face
+		glNormal3f( 0.0f, 1.0f, 0.0f);
+		glTexCoord2f(0.0f, 1.0f); glVertex3f(-100.0f,  100.0f, -100.0f);
+		glTexCoord2f(0.0f, 0.0f); glVertex3f(-100.0f,  100.0f,  100.0f);
+		glTexCoord2f(1.0f, 0.0f); glVertex3f( 100.0f,  100.0f,  100.0f);
+		glTexCoord2f(1.0f, 1.0f); glVertex3f( 100.0f,  100.0f, -100.0f);
+		// Bottom Face
+		glNormal3f( 0.0f,-1.0f, 0.0f);
+		glTexCoord2f(1.0f, 1.0f); glVertex3f(-100.0f, -100.0f, -100.0f);
+		glTexCoord2f(0.0f, 1.0f); glVertex3f( 100.0f, -100.0f, -100.0f);
+		glTexCoord2f(0.0f, 0.0f); glVertex3f( 100.0f, -100.0f,  100.0f);
+		glTexCoord2f(1.0f, 0.0f); glVertex3f(-100.0f, -100.0f,  100.0f);
+		// Right face
+		glNormal3f( 1.0f, 0.0f, 0.0f);
+		glTexCoord2f(1.0f, 0.0f); glVertex3f( 100.0f, -100.0f, -100.0f);
+		glTexCoord2f(1.0f, 1.0f); glVertex3f( 100.0f,  100.0f, -100.0f);
+		glTexCoord2f(0.0f, 1.0f); glVertex3f( 100.0f,  100.0f,  100.0f);
+		glTexCoord2f(0.0f, 0.0f); glVertex3f( 100.0f, -100.0f,  100.0f);
+		// Left Face
+		glNormal3f(-1.0f, 0.0f, 0.0f);
+		glTexCoord2f(0.0f, 0.0f); glVertex3f(-100.0f, -100.0f, -100.0f);
+		glTexCoord2f(1.0f, 0.0f); glVertex3f(-100.0f, -100.0f,  100.0f);
+		glTexCoord2f(1.0f, 1.0f); glVertex3f(-100.0f,  100.0f,  100.0f);
+		glTexCoord2f(0.0f, 1.0f); glVertex3f(-100.0f,  100.0f, -100.0f);
+	glEnd();
+    glDisable(GL_TEXTURE_2D);		    // Enable Texture Mapping
+
+
+
+}
+static void draw_cube()
+{
+    glRotatef(30,1,1,1);
     glBegin(GL_QUADS);		// Draw The Cube Using quads
-    glColor3f(0.0f, 100.0f, 0.0f);	// Color Blue
+    glColor4f(0.0f, 100.0f, 0.0f,0.5);	// Color Blue
     glVertex3f(100.0f, 100.0f, -100.0f);	// Top Right Of The Quad (Top)
     glVertex3f(-100.0f, 100.0f, -100.0f);	// Top Left Of The Quad (Top)
     glVertex3f(-100.0f, 100.0f, 100.0f);	// Bottom Left Of The Quad (Top)
     glVertex3f(100.0f, 100.0f, 100.0f);	// Bottom Right Of The Quad (Top)
-    glColor3f(100.0f, 0.5f, 0.0f);	// Color Orange
+    glColor4f(100.0f, 0.5f, 0.0f,0.5);	// Color Orange
     glVertex3f(100.0f, -100.0f, 100.0f);	// Top Right Of The Quad (Bottom)
     glVertex3f(-100.0f, -100.0f, 100.0f);	// Top Left Of The Quad (Bottom)
     glVertex3f(-100.0f, -100.0f, -100.0f);	// Bottom Left Of The Quad (Bottom)
     glVertex3f(100.0f, -100.0f, -100.0f);	// Bottom Right Of The Quad (Bottom)
-    glColor3f(100.0f, 0.0f, 0.0f);	// Color Red    
+    glColor4f(100.0f, 0.0f, 0.0f,0.5);	// Color Red    
     glVertex3f(100.0f, 100.0f, 100.0f);	// Top Right Of The Quad (Front)
     glVertex3f(-100.0f, 100.0f, 100.0f);	// Top Left Of The Quad (Front)
     glVertex3f(-100.0f, -100.0f, 100.0f);	// Bottom Left Of The Quad (Front)
@@ -61,13 +152,12 @@ void draw_cube()
     glVertex3f(100.0f, -100.0f, -100.0f);	// Bottom Right Of The Quad (Right)
     glEnd();
 }
+#endif
 
-
-
-void drawRotatingAxis(void)
+static void drawRotatingAxis(void)
 {
-    static GLUquadricObj *quadratic = (GLUquadricObj *) 0;
-	float AL = 45;
+    static GLUquadricObj *quadratic;
+    float AL = 45;
 
     if (get_mode(view) != MM_ROTATE)
 	    return;
@@ -114,7 +204,7 @@ void drawRotatingAxis(void)
 	params:ViewInfo	, global view variable defined in viewport.c
 	return value:always 1
 */
-int glupdatecamera(ViewInfo * view)
+static int glupdatecamera(ViewInfo * view)
 {
     if (view->active_camera == -1)
 	glTranslatef(-view->panx, -view->pany, view->panz);
@@ -150,65 +240,8 @@ int glupdatecamera(ViewInfo * view)
     return 1;
 }
 
-/*
-	main gl expose ,any time sreen needs to be redrawn, this function is called by gltemplate
-	,all drawings are initialized in this function
-	params:ViewInfo	, global view variable defined in viewport.c
-	return value:0 if something goes wrong with GL 1 , otherwise
-*/
-int glexpose_main(ViewInfo * view)
-{
-    static int doonce = 0;
-    if (!glupdatecamera(view))
-	return 0;
-
-    if (view->activeGraph >= 0) {
-	if (!doonce) {
-	    doonce = 1;
-	    btnToolZoomFit_clicked(NULL, NULL);
-	    btnToolZoomFit_clicked(NULL, NULL);
-	}
-    }
-    else
-	return 0;
-
-    glexpose_grid(view);
-    draw_fisheye_magnifier(view);
-    draw_magnifier(view);
-    drawBorders(view);
-    glexpose_drawgraph(view);
-//      drawRotatingTools();
-//      draw_cube();
-    drawRotatingAxis();
-//              draw_stuff();
-//      test_color_pallete();
-
-
-
-//      drawtestpoly();
-     /*DEBUG*/
-/*	if (view->mouse.mouse_mode == MM_PAN)
-	{
-		glBegin(GL_LINE_STRIP);
-		glColor4f((GLfloat) 1, (GLfloat) 0.0, (GLfloat) 0.0,
-			(GLfloat) 1);
-		glVertex3f((GLfloat) view->GLx, (GLfloat) view->GLy,
-			(GLfloat) 0.001);
-		glVertex3f((GLfloat) view->GLx2, (GLfloat) view->GLy2,
-			(GLfloat) 0.001);
-
-
-		glEnd();
-	}*/
-	 /*DEBUG*/ return 1;
-}
-
-/*
-	draws grid (little dots , with no use)
-	params:ViewInfo	, global view variable defined in viewport.c
-	return value:none
-*/
-void drawtestpoly(void)
+#if 0
+static void drawtestpoly(void)
 {
     glEnable(GL_TEXTURE_2D);
     glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
@@ -231,8 +264,14 @@ void drawtestpoly(void)
     glDisable(GL_TEXTURE_2D);
 
 }
+#endif
 
-void glexpose_grid(ViewInfo * view)
+/*
+	draws grid (little dots , with no use)
+	params:ViewInfo	, global view variable defined in viewport.c
+	return value:none
+*/
+static void glexpose_grid(ViewInfo * view)
 {
     //drawing grids
     float x, y;
@@ -257,14 +296,15 @@ void glexpose_grid(ViewInfo * view)
 	params:ViewInfo	, global view variable defined in viewport.c
 	return value:1 if there is a graph to draw else 0 
 */
-int glexpose_drawgraph(ViewInfo * view)
+static int glexpose_drawgraph(ViewInfo * view)
 {
 
     if (view->activeGraph > -1) {
 //              if (GD_TopView(view->g[view->activeGraph])) 
 //              {
-	if (!view->Topview->is_top_fisheye)
-	    drawTopViewGraph(view->g[view->activeGraph]);	//view->Topview style dots and straight lines
+	if (!view->Topview->fisheyeParams.active)
+//	    drawTopViewGraph(view->g[view->activeGraph]);	//view->Topview style dots and straight lines
+	    renderSmGraph(view->g[view->activeGraph],view->Topview);	    
 	else {
 	    drawtopologicalfisheye(view->Topview);
 	}
@@ -272,12 +312,93 @@ int glexpose_drawgraph(ViewInfo * view)
 //              }
 //              else
 //                      drawGraph(view->g[view->activeGraph]);  //xdot based drawing functions
-	glCompSetDraw(view->widgets);
 	return 1;
     }
     return 0;
 }
 
+#if 0
+static void test_color_pallete(void)
+{
+    int ind = 0;
+    float xGAP = 5;
+    float yGAP = 80;
+    float x = 50;
+    float y = 50;
+    glCompColor c;
+    for (ind = 0; ind < 350; ind++) {
+	getcolorfromschema(view->colschms, ind, 350, &c);
+	x = ind * xGAP;
+	glBegin(GL_POLYGON);
+	glColor3f(c.R, c.G, c.B);
+	glVertex3f(x, y, 0.0);
+	glVertex3f(x + xGAP, y, 0.0);
+	glVertex3f(x + xGAP, y + yGAP, 0.0);
+	glVertex3f(x, y + yGAP, 0.0);
+	glEnd();
+    }
+}
+#endif
+/*
+	main gl expose ,any time sreen needs to be redrawn, this function is called by gltemplate
+	,all drawings are initialized in this function
+	params:ViewInfo	, global view variable defined in viewport.c
+	return value:0 if something goes wrong with GL 1 , otherwise
+*/
+int glexpose_main(ViewInfo * view)
+{
+    static int doonce = 0;
+    if (!glupdatecamera(view))
+	return 0;
+
+//    glEnable(GL_DEPTH_TEST);
+//    draw_cube();
+//    draw_cube_tex();
+
+
+    if (view->activeGraph >= 0) {
+	if (!doonce) {
+	    doonce = 1;
+	    btnToolZoomFit_clicked(NULL, NULL);
+	    btnToolZoomFit_clicked(NULL, NULL);
+	}
+    }
+    else
+	return 0;
+
+
+
+    glexpose_grid(view);
+#if UNUSED
+    draw_fisheye_magnifier(view);
+    draw_magnifier(view);
+#endif
+    drawBorders(view);
+    glexpose_drawgraph(view);
+    drawRotatingAxis();
+    draw_selpoly(&view->Topview->sel.selPoly);
+    glCompSetDraw(view->widgets);
+
+//              draw_stuff();
+//      test_color_pallete();
+//      drawtestpoly();
+     /*DEBUG*/
+/*	if (view->mouse.mouse_mode == MM_PAN)
+	{
+		glBegin(GL_LINE_STRIP);
+		glColor4f((GLfloat) 1, (GLfloat) 0.0, (GLfloat) 0.0,
+			(GLfloat) 1);
+		glVertex3f((GLfloat) view->GLx, (GLfloat) view->GLy,
+			(GLfloat) 0.001);
+		glVertex3f((GLfloat) view->GLx2, (GLfloat) view->GLy2,
+			(GLfloat) 0.001);
+
+
+		glEnd();
+	}*/
+	 /*DEBUG*/ return 1;
+}
+
 /*
 void drawRotatingTools(void)
 {
