@@ -1,30 +1,27 @@
-/* $Id: gltemplate.c,v 1.74 2009/12/03 19:16:04 arif Exp $ $Revision: 1.74 $ */
+/* $Id: gltemplate.c,v 1.85 2011/01/25 16:30:46 ellson Exp $ $Revision: 1.85 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include <stdlib.h>
 #include <math.h>
 #include "gui.h"
-#include "beacon.h"
+/* #include "beacon.h" */
 #include "viewport.h"
-#include "topview.h"
+/* #include "topview.h" */
 #include "gltemplate.h"
 #include "glutils.h"
 #include "glexpose.h"
 #include "glmotion.h"
-#include "selection.h"
+
 #include "glcompset.h"
 #include "viewportcamera.h"
 #include "gui/menucallbacks.h"
@@ -52,13 +49,34 @@ static glMouseButtonType getGlCompMouseType(int n)
 }
 
 
+/*
+	test single opengl parameter, all visual , it doesnt return a value
+	params:gtk gl config class , attribute name and id,if boolean expected send is_boolean true
+	return value:none
+*/
+void print_gl_config_attrib(GdkGLConfig * glconfig,
+			    const gchar * attrib_str,
+			    int attrib, gboolean is_boolean)
+{
+    int value;
+
+    g_print("%s = ", attrib_str);
+    if (gdk_gl_config_get_attrib(glconfig, attrib, &value)) {
+	if (is_boolean)
+	    g_print("%s\n", value == TRUE ? "TRUE" : "FALSE");
+	else
+	    g_print("%d\n", value);
+    } else
+	g_print("*** Cannot get %s attribute value\n", attrib_str);
+}
+
 
 /*
 	test opengl parameters, configuration.Run this function to see machine's open gl capabilities
 	params:gtk gl config class ,gtk takes care of all these tests
 	return value:none
 */
-void examine_gl_config_attrib(GdkGLConfig * glconfig)
+static void examine_gl_config_attrib(GdkGLConfig * glconfig)
 {
     g_print("\nOpenGL visual configurations :\n\n");
     g_print("gdk_gl_config_is_rgba (glconfig) = %s\n",
@@ -109,27 +127,6 @@ void examine_gl_config_attrib(GdkGLConfig * glconfig)
     g_print("\n");
 }
 
-/*
-	test single opengl parameter, all visual , it doesnt return a value
-	params:gtk gl config class , attribute name and id,if boolean expected send is_boolean true
-	return value:none
-*/
-void print_gl_config_attrib(GdkGLConfig * glconfig,
-			    const gchar * attrib_str,
-			    int attrib, gboolean is_boolean)
-{
-    int value;
-
-    g_print("%s = ", attrib_str);
-    if (gdk_gl_config_get_attrib(glconfig, attrib, &value)) {
-	if (is_boolean)
-	    g_print("%s\n", value == TRUE ? "TRUE" : "FALSE");
-	else
-	    g_print("%d\n", value);
-    } else
-	g_print("*** Cannot get %s attribute value\n", attrib_str);
-}
-
 /*
 	initialize the gl , run only once!!
 	params:gtk opgn gl canvas and optional data pointer
@@ -174,9 +171,8 @@ static void realize(GtkWidget * widget, gpointer data)
 //  glEnable (GL_NORMALIZE);
     glEnable(GL_BLEND);
     glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-    glDepthFunc(GL_LESS);
+//    glDepthFunc(GL_LESS);
 //  glEnable(GL_LINE_SMOOTH);
-
     gdk_gl_drawable_gl_end(gldrawable);
 
 
@@ -275,7 +271,10 @@ gboolean expose_event(GtkWidget * widget, GdkEventExpose * event,
 static gboolean button_press_event(GtkWidget * widget,
 				   GdkEventButton * event, gpointer data)
 {
-    Agraph_t* g=view->g[view->activeGraph];
+    Agraph_t* g;
+
+    if (view->g == 0) return FALSE;
+    g=view->g[view->activeGraph];
 
     begin_x = (float) event->x;
     begin_y = (float) event->y;
@@ -301,6 +300,7 @@ static gboolean button_press_event(GtkWidget * widget,
 static gboolean button_release_event(GtkWidget * widget,
 				     GdkEventButton * event, gpointer data)
 {
+    if (view->widgets == 0) return FALSE;
     view->FontSizeConst = GetOGLDistance(14);
     view->arcball->isDragging = 0;
     view->widgets->common.functions.mouseup((glCompObj*)view->widgets,(GLfloat) event->x,(GLfloat) event->y,getGlCompMouseType(event->button));
@@ -321,21 +321,17 @@ static gboolean button_release_event(GtkWidget * widget,
 }
 static gboolean key_press_event(GtkWidget * widget, GdkEventKey * event, gpointer data)
 {
-    view->keymap.down=1;
-    view->keymap.keyVal=event->keyval;
-        return FALSE;
+    appmouse_key_press(view,event->keyval);
+    return FALSE;
+
 
 
 
 }
 static gboolean key_release_event(GtkWidget * widget, GdkEventKey * event, gpointer data)
 {
- //   printf ("key is released:%d\n",event->keyval);
-    view->keymap.down=0;
-    view->keymap.keyVal=0;
-    originate_distorded_coordinates(view->Topview);
-        return FALSE;
-
+    appmouse_key_release(view,event->keyval);
+    return FALSE;
 
 }
 
@@ -379,6 +375,8 @@ static gboolean motion_notify_event(GtkWidget * widget,
     dy = y - begin_y;
     view->mouse.dragX = dx;
     view->mouse.dragY = dy;
+    appmouse_move(view,(int)event->x,(int)event->y);
+
     if((view->mouse.t==glMouseLeftButton) && (view->mouse.down)  )
     {
 	appmouse_left_drag(view,(int)event->x,(int)event->y);
@@ -395,6 +393,8 @@ static gboolean motion_notify_event(GtkWidget * widget,
 	appmouse_middle_drag(view,(int)event->x,(int)event->y);
 	redraw = TRUE;
     }
+    if(view->Topview->sel.selPoly.cnt > 0)
+	redraw=TRUE;
 
 
 
