@@ -1,83 +1,87 @@
-/* $Id: appmouse.c,v 1.13 2009/11/30 18:02:58 arif Exp $Revision: */
+/* $Id: appmouse.c,v 1.25 2011/01/25 16:30:47 ellson Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include "appmouse.h"
 #include "topfisheyeview.h"
 #include "arcball.h"
-#include "topview.h"
+/* #include "topview.h" */
 #include "glmotion.h"
-#include "beacon.h"
+/* #include "beacon.h" */
 #include "hotkeymap.h"
-#include "selection.h"
+
+#include "selectionfuncs.h"
+#include "topviewfuncs.h"
 
 
-    static float prevX=0;
-    static float prevY=0;
+static float prevX=0;
+static float prevY=0;
+static int lastAction;
+
 static void apply_actions(ViewInfo* v,int x,int y)
 {
     int a;
+    gdouble seconds;
     a=get_mode(v);
-    if (a==MM_ROTATE)
-
-    {
-	view->arcball->MousePt.s.X = (GLfloat) x;
-	view->arcball->MousePt.s.Y = (GLfloat) y;
-	if (!view->arcball->isDragging) {
-	    arcmouseClick(view);
-        view->arcball->isDragging = 1;
+    if((a==MM_PAN) && (view->guiMode==GUI_FULLSCREEN) &&((v->active_camera >= 0)))
+	a=MM_ROTATE;	
+    switch (a) {
+    case MM_ROTATE :
+	seconds = g_timer_elapsed(view->timer3, NULL);
+	if (seconds > 0.1) {
+	    g_timer_stop(view->timer3);
+		view->arcball->MousePt.s.X = (GLfloat) x;
+		view->arcball->MousePt.s.Y = (GLfloat) y;
+		if (!view->arcball->isDragging) {
+		    arcmouseClick(view);
+		    view->arcball->isDragging = 1;
+		}
+		else 
+		    arcmouseDrag(view);
+	    g_timer_start(view->timer3);
 	}
-	else 
-            arcmouseDrag(view);
 	return;
-    }
-    if (a==MM_PAN)
-    {
+	break;
+    case MM_PAN :
 	glmotion_pan(v);
-    }
-    if (a==MM_MOVE)
-        move_TVnodes();
-
-    if(a==MM_RECTANGULAR_SELECT)
-    {
-	if (!view->mouse.down)
-	    rectangle_select(v);
-    }
-
-    if (a==MM_SINGLE_SELECT) 
-        pick_node_from_coords(view->mouse.GLfinalPos.x,view->mouse.GLfinalPos.y,view->mouse.GLfinalPos.z);
-
-    if (a==MM_FISHEYE_PICK) 
-    {
-
-	if (view->activeGraph >= 0) 
-	{
-	    if (view->Topview->is_top_fisheye) 
+	break;
+    case MM_MOVE :
+        /* move_TVnodes(); */
+	break;
+    case MM_RECTANGULAR_SELECT :
+	if (!view->mouse.down) {
+//	    rectangle_select(v);
+	    pick_objects_rect(view->g[view->activeGraph]) ;
+	}
+	break;
+    case MM_POLYGON_SELECT :
+	add_selpoly(view->g[view->activeGraph],&view->Topview->sel.selPoly,view->mouse.GLfinalPos);
+	break;
+    case MM_SINGLE_SELECT :
+	pick_object_xyz(view->g[view->activeGraph],view->Topview,view->mouse.GLfinalPos.x,view->mouse.GLfinalPos.y,view->mouse.GLfinalPos.z);
+	break;
+    case MM_FISHEYE_PICK :
+	if (view->activeGraph >= 0) {
+	    if (view->Topview->fisheyeParams.active) 
 		changetopfishfocus(view->Topview,&view->mouse.GLpos.x,&view->mouse.GLpos.y,  0, 1);
+#if 0
 	    else    //single right click
-		//	pick_node_from_coords(view->mouse.GLpos.x, view->mouse.GLpos.y,view->mouse.GLpos.z);
-
-	    {;}
-
+		pick_node_from_coords(view->mouse.GLpos.x, view->mouse.GLpos.y,view->mouse.GLpos.z);
+#endif
 
 	}
+	break;
     }
-
-
-
-
+    lastAction=a;
 }
 
 static int singleclick(ViewInfo* v)
@@ -108,17 +112,17 @@ static void appmouse_down(ViewInfo* v,int x,int y)
     prevX=0;
     prevY=0;
 
-    view->Selection.X = view->mouse.GLpos.x;
-    view->Selection.Y = view->mouse.GLpos.y;
+/*    view->Selection.X = view->mouse.GLpos.x;
+    view->Selection.Y = view->mouse.GLpos.y;*/
 }
 static void appmouse_up(ViewInfo* v,int x,int y)
 {
 
-    int a;
+    /* int a; */
     v->mouse.down=0;
     v->mouse.finalPos.x=x;
     v->mouse.finalPos.y=y;
-    a=get_mode(v);
+    /* a=get_mode(v); */
     to3D(x,y, &v->mouse.GLfinalPos.x,&v->mouse.GLfinalPos.y,&v->mouse.GLfinalPos.z);
     if(singleclick(v))
     {
@@ -127,8 +131,6 @@ static void appmouse_up(ViewInfo* v,int x,int y)
 	if (v->mouse.t==glMouseRightButton)
 	    appmouse_right_click(v,x,y);
     }
-    if ((a== MM_FISHEYE_MAGNIFIER) || (a == MM_MAGNIFIER))	//fisheye mag mouse release, stop distortion
-        originate_distorded_coordinates(v->Topview);
     apply_actions(v,x,y);
     view->mouse.dragX = 0;
     view->mouse.dragY = 0;
@@ -138,16 +140,12 @@ static void appmouse_up(ViewInfo* v,int x,int y)
 }
 static void appmouse_drag(ViewInfo* v,int x,int y)
 {
-    static float x2,y2;
     v->mouse.pos.x=x;
     v->mouse.pos.y=y;
     to3D( x,y, &v->mouse.GLpos.x,&v->mouse.GLpos.y,&v->mouse.GLpos.z);
-    x2=v->mouse.GLpos.x;
-    y2=v->mouse.GLpos.y;
-    prevX=x2;
-    prevY=y2;
+    prevX=v->mouse.GLpos.x;
+    prevY=v->mouse.GLpos.y;
     apply_actions(v,x,y);
-
 }
 
 void appmouse_left_click_down(ViewInfo* v,int x,int y)
@@ -208,4 +206,25 @@ void appmouse_middle_drag(ViewInfo* v,int x,int y)
     appmouse_drag(v,x,y);
 
 }
+void appmouse_move(ViewInfo* v,int x,int y)
+{
+    to3D( x,y, &v->mouse.GLpos.x,&v->mouse.GLpos.y,&v->mouse.GLpos.z);
+}
+void appmouse_key_release(ViewInfo* v,int key)
+{
+    /* int action=get_key_action(v,key); */
+    if(lastAction==MM_POLYGON_SELECT)
+    {
+	clear_selpoly(&view->Topview->sel.selPoly);	
+	glexpose();
+    }
+    v->keymap.down=0;
+    v->keymap.keyVal=0;
+}
+void appmouse_key_press(ViewInfo* v,int key)
+{
+    v->keymap.down=1;
+    v->keymap.keyVal=key;
+}
+
 
