@@ -1,18 +1,15 @@
-/* $Id: callbacks.c,v 1.19 2009/10/29 17:37:30 arif Exp $ $Revision: 1.19 $ */
+/* $Id: callbacks.c,v 1.22 2011/01/25 16:30:47 ellson Exp $ $Revision: 1.22 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #define _CRT_SECURE_NO_DEPRECATE 1
 #ifdef HAVE_CONFIG_H
@@ -21,8 +18,8 @@
 #include <gtk/gtk.h>
 #include "callbacks.h"
 #include "viewport.h"
-#include "topview.h"
-#include "selection.h"
+/* #include "topview.h" */
+#include "selectionfuncs.h"
 #include "memory.h"
 
 //Menu Items 
