@@ -1,18 +1,15 @@
-/* $Id: gui.c,v 1.29 2009/11/16 20:29:02 erg Exp $ $Revision: 1.29 $ */
+/* $Id: gui.c,v 1.32 2011/01/25 16:30:47 ellson Exp $ $Revision: 1.32 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include <stdio.h>
 #include "compat.h"
@@ -100,40 +97,6 @@ void object_properties_graph_init(void)	//customize window for Graph , this show
 }
 
 
-void graph_properties_init(int newgraph)	//initialize little open graph dialog
-{
-    //newgraph 0 : open graph mode
-    //newgraph 1 : new graph mode
-
-
-    gint result = 0;
-    xml = glade_xml_new(smyrnaGlade, NULL, NULL);
-    gladewidget = glade_xml_get_widget(xml, "entryGraphFileName");
-
-    //signals
-    //OK
-    gladewidget = glade_xml_get_widget(xml, "btnOK");
-
-
-    g_signal_connect((gpointer) gladewidget, "clicked",
-		     G_CALLBACK(dlgOpenGraph_OK_Clicked), &newgraph);
-
-
-
-    if (newgraph) {
-	gladewidget = glade_xml_get_widget(xml, "entryGraphName");
-	gtk_entry_set_text((GtkEntry *) gladewidget, "Untitled");
-	gladewidget = glade_xml_get_widget(xml, "entryGraphFileName");
-	gtk_entry_set_text((GtkEntry *) gladewidget, "Untitled.dot");
-    } else {
-	gladewidget = glade_xml_get_widget(xml, "entryGraphName");
-	gtk_entry_set_text((GtkEntry *) gladewidget, "");
-	gladewidget = glade_xml_get_widget(xml, "entryGraphFileName");
-	gtk_entry_set_text((GtkEntry *) gladewidget, "");
-    }
-    gladewidget = glade_xml_get_widget(xml, "dlgOpenGraph");
-    result = gtk_dialog_run(GTK_DIALOG(gladewidget));
-}
 
 GtkComboBox *get_SelectGraph(void)
 {
@@ -284,6 +247,7 @@ char *get_attribute_string_value_from_widget(attribute * att)
 	return guibuffer;
     }
 }
+#if UNUSED
 void change_selected_graph_attributes(Agraph_t * g, char *attrname,
 				      char *attrvalue)
 {
@@ -296,24 +260,31 @@ void change_selected_node_attributes(Agraph_t * g, char *attrname,
 				     char *attrvalue)
 {
     int ind = 0;
-    agattr(g, AGNODE, attrname, "");
+    Agsym_t* ap = agattr(g, AGNODE, attrname, NULL);
+
+    if (!ap)
+	ap = agattr(g, AGNODE, attrname, "");
+	
     for (ind = 0; ind < view->Topview->Nodecount; ind++) {
 	if (view->Topview->Nodes[ind].data.Selected == 1)
-	    agset(view->Topview->Nodes[ind].Node, attrname, attrvalue);
+	    agxset(view->Topview->Nodes[ind].Node, ap, attrvalue);
     }
 }
 void change_selected_edge_attributes(Agraph_t * g, char *attrname,
 				     char *attrvalue)
 {
     int ind = 0;
-    agattr(g, AGEDGE, attrname, "");
+    Agsym_t* ap = agattr(g, AGEDGE, attrname, NULL);
 
+    if (!ap)
+	ap = agattr(g, AGEDGE, attrname, "");
+	
     for (ind = 0; ind < view->Topview->Edgecount; ind++) {
 	if (view->Topview->Edges[ind].data.Selected == 1)
-	    agset(view->Topview->Edges[ind].Edge, attrname, attrvalue);
-
+	    agxset(view->Topview->Edges[ind].Edge, ap, attrvalue);
     }
 }
+#endif
 
 void load_attributes(void)
 {
