@@ -1,74 +1,26 @@
-/* $Id: toolboxcallbacks.c,v 1.23 2009/11/05 14:50:42 arif Exp $ $Revision: 1.23 $ */
+/* $Id: toolboxcallbacks.c,v 1.25 2011/01/25 16:30:47 ellson Exp $ $Revision: 1.25 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include "toolboxcallbacks.h"
 #include "viewport.h"
-#include "selection.h"
+
 #include "gltemplate.h"
 #include "glutils.h"
 #include "glmotion.h"
 
 
 
-void btnToolSingleSelect_clicked(GtkWidget * widget, gpointer user_data)
-{
-    deselect_all(view->g[view->activeGraph]);
-    //gtk_toggle_tool_button_set_active   ((GtkToggleToolButton*)widget,1);
-}
 
-void btnToolRectSelect_clicked(GtkWidget * widget, gpointer user_data)
-{
-
-    deselect_all(view->g[view->activeGraph]);
-}
-
-void btnToolRectXSelect_clicked(GtkWidget * widget, gpointer user_data)
-{
-    deselect_all(view->g[view->activeGraph]);
-    view->Selection.Anti = 0;
-}
-
-void btnToolAntiRectSelect_clicked(GtkWidget * widget, gpointer user_data)
-{
-    view->Selection.Anti = 1;
-
-}
-
-void btnToolAntiRectXSelect_clicked(GtkWidget * widget, gpointer user_data)
-{
-    view->Selection.Anti = 1;
-
-}
-
-
-void btnToolPan_clicked(GtkWidget * widget, gpointer user_data)
-{
-
-
-
-}
-
-void btnToolZoom_clicked(GtkWidget * widget, gpointer user_data)
-{
-}
-
-void btnToolZoomIn_clicked(GtkWidget * widget, gpointer user_data)
-{
-    glmotion_zoom_inc(1);
-}
 
 void btnToolZoomOut_clicked(GtkWidget * widget, gpointer user_data)
 {
