@@ -1,25 +1,21 @@
-/* $Id: topviewsettings.c,v 1.37 2009/12/03 19:16:04 arif Exp $Revision: */
+/* $Id: topviewsettings.c,v 1.48 2011/01/25 16:30:47 ellson Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
-#include "topview.h"
+#include "topviewfuncs.h"
 #include "topviewsettings.h"
 #include "gui.h"
 #include "colorprocs.h"
 #include "viewport.h"
-#include "topview.h"
 #include "memory.h"
 
 void color_change_request(GtkWidget * widget, gpointer user_data)
@@ -41,21 +37,27 @@ void on_settingsApplyBtn_clicked(GtkWidget * widget, gpointer user_data)
 {
     update_graph_from_settings(view->g[view->activeGraph]);
     set_viewport_settings_from_template(view, view->g[view->activeGraph]);
+#if 0
     update_topview(view->g[view->activeGraph], view->Topview, 0);
-/*	settvcolorinfo(view->g[view->activeGraph],view->Topview);
-	init_node_size(view->g[view->activeGraph])*/
+    settvcolorinfo(view->g[view->activeGraph],view->Topview);
+    init_node_size(view->g[view->activeGraph]);
+#endif
+    updateSmGraph(view->g[view->activeGraph],view->Topview);
 }
 void on_dlgSettings_close (GtkWidget * widget, gpointer user_data)
 {
-    printf ("setting window is being closed\n");
+    gtk_widget_hide(glade_xml_get_widget(xml, "dlgSettings"));
+    /* printf ("setting window is being closed\n"); */
 }
 
-
-
 void on_settingsCancelBtn_clicked(GtkWidget * widget, gpointer user_data)
 {
     gtk_widget_hide(glade_xml_get_widget(xml, "dlgSettings"));
 }
+void copy_attr(Agraph_t* destG,char* attr,Agraph_t* g)
+{
+    agattr(g,AGRAPH,attr,agget(destG,attr));
+}
 
 
 static int set_color_button_widget(char *attribute, char *widget_name)
@@ -67,7 +69,10 @@ static int set_color_button_widget(char *attribute, char *widget_name)
     attribute=attribute +13;
     buf = agget(view->g[view->activeGraph], attribute);
     if ((!buf) || (strcmp(buf, "") == 0))
+    {
 	buf = agget(view->systemGraphs.def_attrs, attribute);
+	copy_attr(view->systemGraphs.def_attrs, attribute,view->g[view->activeGraph]);
+    }
     if (buf) {
 	colorxlate(buf, &cl, RGBA_DOUBLE);
 	color.red = (int) (cl.u.RGBA[0] * 65535.0);
@@ -119,7 +124,11 @@ static int set_text_widget(char *attribute, char *widget_name)
 
     buf = agget(view->g[view->activeGraph], attribute);
     if ((!buf) || (strcmp(buf, "") == 0))
+    {
 	buf = agget(view->systemGraphs.def_attrs, attribute);
+	copy_attr(view->systemGraphs.def_attrs, attribute,view->g[view->activeGraph]);
+    }
+
     if (buf) {
 	gtk_entry_set_text((GtkEntry *)
 			   glade_xml_get_widget(xml, widget_name), buf);
@@ -136,7 +145,12 @@ static int set_checkbox_widget(char *attribute, char *widget_name)
 
     buf = agget(view->g[view->activeGraph], attribute);
     if ((!buf) || (strcmp(buf, "") == 0))
+    {
 	buf = agget(view->systemGraphs.def_attrs, attribute);
+	copy_attr(view->systemGraphs.def_attrs, attribute,view->g[view->activeGraph]);
+    }
+
+
     if (buf) {
 	value = atoi(buf);
 	gtk_toggle_button_set_active((GtkToggleButton *)
@@ -163,7 +177,7 @@ static int get_checkbox_widget_to_attribute(char *attribute,
 								    widget_name));
     sprintf(buf, "%d", value);
     agattr(g, AGRAPH, attribute, buf);
-    return 1;
+   return 1;
 }
 
 static int set_spinbtn_widget(char *attribute, char *widget_name)
@@ -174,7 +188,10 @@ static int set_spinbtn_widget(char *attribute, char *widget_name)
 
     buf = agget(view->g[view->activeGraph], attribute);
     if ((!buf) || (strcmp(buf, "") == 0))
+    {
 	buf = agget(view->systemGraphs.def_attrs, attribute);
+	copy_attr(view->systemGraphs.def_attrs, attribute,view->g[view->activeGraph]);
+    }
     if (buf) {
 	value = (float) atof(buf);
 	gtk_spin_button_set_value((GtkSpinButton *)
@@ -225,7 +242,11 @@ static int set_scalebtn_widget_to_attribute(char *attribute,
     buf = agget(view->g[view->activeGraph], attribute);
 
     if ((!buf) || (strcmp(buf, "") == 0))
+    {
 	buf = agget(view->systemGraphs.def_attrs, attribute);
+	copy_attr(view->systemGraphs.def_attrs, attribute,view->g[view->activeGraph]);
+
+    }
     if (buf) {
 	value = (float) atof(buf);
 	gtk_range_set_value((GtkRange *)
@@ -242,9 +263,12 @@ static int set_combobox_widget(char *attribute, char *widget_name)
     attribute=attribute +9;
     buf = agget(view->g[view->activeGraph], attribute);
     if ((!buf) || (strcmp(buf, "") == 0))
+    {
 	buf = agget(view->systemGraphs.def_attrs, attribute);
+	copy_attr(view->systemGraphs.def_attrs, attribute,view->g[view->activeGraph]);
+    }
     if (buf) {
-	value = (int) atof(buf);
+	value = (int) atoi(buf);
 	gtk_combo_box_set_active((GtkComboBox *)
 				 glade_xml_get_widget(xml, widget_name),
 				 (int) value);
@@ -260,16 +284,17 @@ static int get_combobox_widget_to_attribute(char *attribute,
 					    Agraph_t * g)
 {
     char buf[25];
-    float value;
-        attribute=attribute +9;
+    int value;
 
+    attribute=attribute +9;
 
-    value = (float)
+    value = (int)
 	gtk_combo_box_get_active((GtkComboBox *)
 				 glade_xml_get_widget(xml, widget_name));
 
-    sprintf(buf, "%f", value);
+    sprintf(buf, "%d", value);
     agattr(g, AGRAPH, attribute, buf);
+    /* printf ("%s %f \n",attribute,value); */
     return 1;
 
 
@@ -277,26 +302,24 @@ static int get_combobox_widget_to_attribute(char *attribute,
 int load_settings_from_graph(Agraph_t * g)
 {
     Agsym_t* sym=NULL;
-    while ((sym = agnxtattr(view->systemGraphs.attrs_widgets,AGRAPH, sym)))
-    {
-	if(strncmp (sym->name,"color_button",strlen("color_button"))==0)
-	    set_color_button_widget(sym->name, agget(view->systemGraphs.attrs_widgets,sym->name));
-	if(strncmp (sym->name,"check_box",strlen("check_box"))==0)
-	   set_checkbox_widget(sym->name, agget(view->systemGraphs.attrs_widgets,sym->name));
-	if(strncmp (sym->name,"text_box",strlen("text_box"))==0)
-	   set_text_widget(sym->name, agget(view->systemGraphs.attrs_widgets,sym->name));
-	if(strncmp (sym->name,"combobox",strlen("combobox"))==0)
-	   set_combobox_widget(sym->name, agget(view->systemGraphs.attrs_widgets,sym->name));
-	if(strncmp (sym->name,"spin_button",strlen("spin_button"))==0)
-	   set_spinbtn_widget(sym->name, agget(view->systemGraphs.attrs_widgets,sym->name));
-	if(strncmp (sym->name,"scale_button",strlen("scale_button"))==0)
-	   set_scalebtn_widget_to_attribute(sym->name, agget(view->systemGraphs.attrs_widgets,sym->name));
+    while ((sym = agnxtattr(view->systemGraphs.attrs_widgets,AGRAPH, sym))) {
+	    if(strncmp (sym->name,"color_button",strlen("color_button"))==0)
+		set_color_button_widget(sym->name, agget(view->systemGraphs.attrs_widgets,sym->name));
+	    if(strncmp (sym->name,"check_box",strlen("check_box"))==0)
+		set_checkbox_widget(sym->name, agget(view->systemGraphs.attrs_widgets,sym->name));
+    	    if(strncmp (sym->name,"text_box",strlen("text_box"))==0)
+		set_text_widget(sym->name, agget(view->systemGraphs.attrs_widgets,sym->name));
+	    if(strncmp (sym->name,"combobox",strlen("combobox"))==0)
+		set_combobox_widget(sym->name, agget(view->systemGraphs.attrs_widgets,sym->name));
+	    if(strncmp (sym->name,"spin_button",strlen("spin_button"))==0)
+		set_spinbtn_widget(sym->name, agget(view->systemGraphs.attrs_widgets,sym->name));
+	    if(strncmp (sym->name,"scale_button",strlen("scale_button"))==0)
+		set_scalebtn_widget_to_attribute(sym->name, agget(view->systemGraphs.attrs_widgets,sym->name));
 
-    }
+	}
     return 1;
 }
 
-
 int update_graph_from_settings(Agraph_t * g)
 {
     Agsym_t* sym=NULL;
@@ -314,8 +337,6 @@ int update_graph_from_settings(Agraph_t * g)
 	   get_spinbtn_widget_to_attribute(sym->name, agget(view->systemGraphs.attrs_widgets,sym->name),g);
 	if(strncmp (sym->name,"scale_button",strlen("scale_button"))==0)
 	   get_scalebtn_widget_to_attribute(sym->name, agget(view->systemGraphs.attrs_widgets,sym->name),g);
-
-
     }
 
     return 1;
