@@ -1,18 +1,15 @@
-/* $Id: hier.c,v 1.13 2009/10/09 18:28:17 erg Exp $Revision: */
+/* $Id: hier.c,v 1.15 2011/01/25 16:30:47 ellson Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include "smyrnadefs.h"
 #include "hier.h"
@@ -212,6 +209,7 @@ focus_t *initFocus(int ncnt)
     return fs;
 }
 
+#ifdef UNUSED
 void freeFocus(focus_t * fs)
 {
     free(fs->foci_nodes);
@@ -219,3 +217,4 @@ void freeFocus(focus_t * fs)
     free(fs->y_foci);
     free(fs);
 }
+#endif
