@@ -1,18 +1,15 @@
-/* $Id: main.c,v 1.58 2009/12/09 23:45:26 erg Exp $Revision: */
+/* $Id: main.c,v 1.65 2011/01/25 16:30:47 ellson Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 #ifdef HAVE_CONFIG_H
@@ -39,6 +36,8 @@
 #include "libintl.h"
 #endif
 #include <assert.h>
+#include "glexpose.h"
+#include "glutrender.h"
 
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
@@ -54,6 +53,7 @@ gchar *package_locale_dir;
 static char *smyrnaDir;		/* path to directory containin smyrna data files */
 char *smyrnaGlade;
 unsigned char SmyrnaVerbose;
+int width,height;/*glut window size*/
 
 
 /* smyrnaPath:
@@ -87,6 +87,8 @@ char *smyrnaPath(char *suffix)
 }
 
 static char *useString = "Usage: smyrns [-v?] <file>\n\
+  -f<WxH:bits@rate>         - full-screen mode\n\
+  -e         - draw edges as splines if available\n\
   -v         - verbose\n\
   -?         - print usage\n";
 
@@ -101,8 +103,11 @@ static char *parseArgs(int argc, char *argv[], ViewInfo * view)
 {
     unsigned int c;
 
-    while ((c = getopt(argc, argv, ":K:txv?")) != -1) {
+    while ((c = getopt(argc, argv, ":eKf:txv?")) != -1) {
 	switch (c) {
+	case 'e':
+	    view->drawSplines = 1;
+	    break;
 	case 'v':
 	    SmyrnaVerbose = 1;
 	    break;
@@ -117,6 +122,11 @@ static char *parseArgs(int argc, char *argv[], ViewInfo * view)
 	    view->dfltEngine = s2layout(optarg);
 	    break;
 #endif
+	case 'f':
+	    view->guiMode=GUI_FULLSCREEN;
+	    view->optArg=strdup(optarg);
+	    break;
+
 	case '?':
 	    if (optopt == '?')
 		usage(0);
@@ -145,16 +155,74 @@ static void close_cgraph(Agraph_t * g)
 }
 
 #endif
+void display() 
+{
+   glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+   glLoadIdentity();
+   glexpose_main(view);
+   glutSwapBuffers();
 
-int main(int argc, char *argv[])
+}
+#if UNUSED
+static void glutMode()
+{
+    glutInitWindowSize(512,512);
+    glutInitDisplayMode ( GLUT_RGB | GLUT_DOUBLE | GLUT_DEPTH);
+    glutCreateWindow("The glut hello world program");
+    glutDisplayFunc(display);
+  
+    glutMainLoop(); // Infinite event loop
+}
+#endif
+
+static void windowedMode(int argc, char *argv[])
 {
     GdkGLConfig *glconfig;
-    char *initFileName;
     /*combo box to show loaded graphs */
     GtkComboBox *graphComboBox;
 
+    gtk_set_locale();
+    gtk_init(&argc, &argv);
+    if (!(smyrnaGlade))
+	smyrnaGlade = smyrnaPath("smyrna.glade");
+    xml = glade_xml_new(smyrnaGlade, NULL, NULL);
+
+    gladewidget = glade_xml_get_widget(xml, "frmMain");
+    gtk_widget_show(gladewidget);
+    g_signal_connect((gpointer) gladewidget, "destroy",
+		     G_CALLBACK(mQuitSlot), NULL);
+    glade_xml_signal_autoconnect(xml);
+    gtk_gl_init(0, 0);
+    /* Configure OpenGL framebuffer. */
+    glconfig = configure_gl();
+//      gladewidget = glade_xml_get_widget(xml, "vbox2");
+    gladewidget = glade_xml_get_widget(xml, "hbox11");
+
+    gtk_widget_hide(glade_xml_get_widget(xml, "vbox13"));
+    gtk_window_set_deletable ((GtkWindow*)glade_xml_get_widget(xml, "dlgSettings"),0);
+    gtk_window_set_deletable ((GtkWindow*)glade_xml_get_widget(xml, "frmTVNodes"),0);
+    create_window(glconfig, gladewidget);
+    change_cursor(GDK_TOP_LEFT_ARROW);
+
+#ifndef WIN32
+    glutInit(&argc, argv);
+#endif
+
+    gladewidget = glade_xml_get_widget(xml, "hbox13");
+    graphComboBox = (GtkComboBox *) gtk_combo_box_new_text();
+    gtk_box_pack_end((GtkBox*)gladewidget, (GtkWidget*)graphComboBox, 1, 1, 10);
+    gtk_widget_show((GtkWidget*)graphComboBox);
+    view->graphComboBox = graphComboBox;
+
+    if(view->guiMode!=GUI_FULLSCREEN)
+	gtk_main();
+}
 
 
+
+
+int main(int argc, char *argv[])
+{
     smyrnaDir = getenv("SMYRNA_PATH");
     if (!smyrnaDir) {
 #ifdef _WIN32
@@ -187,53 +255,15 @@ int main(int argc, char *argv[])
     textdomain(GETTEXT_PACKAGE);
 #endif
     view = NEW(ViewInfo);
-
     init_viewport(view);
-    gtk_set_locale();
-    gtk_init(&argc, &argv);
-    initFileName = parseArgs(argc, argv, view);
-    if (!(smyrnaGlade))
-	smyrnaGlade = smyrnaPath("smyrna.glade");
-    xml = glade_xml_new(smyrnaGlade, NULL, NULL);
-
-    gladewidget = glade_xml_get_widget(xml, "frmMain");
-    gtk_widget_show(gladewidget);
-    g_signal_connect((gpointer) gladewidget, "destroy",
-		     G_CALLBACK(mQuitSlot), NULL);
-    glade_xml_signal_autoconnect(xml);
-    if (initFileName) {
-	view->initFile = 1;
-	view->initFileName = strdup(initFileName);
-    }
-    gtk_gl_init(0, 0);
-    /* Configure OpenGL framebuffer. */
-    glconfig = configure_gl();
-//      gladewidget = glade_xml_get_widget(xml, "vbox2");
-    gladewidget = glade_xml_get_widget(xml, "hbox11");
-
-    gtk_widget_hide(glade_xml_get_widget(xml, "vbox13"));
-    gtk_window_set_deletable ((GtkWindow*)glade_xml_get_widget(xml, "dlgSettings"),0);
-    gtk_window_set_deletable ((GtkWindow*)glade_xml_get_widget(xml, "dlgTVFilter"),0);
-    gtk_window_set_deletable ((GtkWindow*)glade_xml_get_widget(xml, "frmTVNodes"),0);
-
-
-    create_window(glconfig, gladewidget);
-
-    change_cursor(GDK_TOP_LEFT_ARROW);
-
-#ifndef WIN32
-    glutInit(&argc, argv);
-#endif
-
-    gladewidget = glade_xml_get_widget(xml, "hbox13");
-    graphComboBox = (GtkComboBox *) gtk_combo_box_new_text();
-    gtk_box_pack_end((GtkBox*)gladewidget, (GtkWidget*)graphComboBox, 1, 1, 10);
-    gtk_widget_show((GtkWidget*)graphComboBox);
-    view->graphComboBox = graphComboBox;
-    gtk_main();
-
-
+    view->initFileName = parseArgs(argc, argv, view);
+    if(view->initFileName)
+	view->initFile=1;
 
+    if(view->guiMode==GUI_FULLSCREEN)
+	cb_glutinit(0,0,800,600,32,75,1,&argc,argv,view->optArg);
+    else
+	windowedMode(argc, argv);
 #ifdef G_OS_WIN32
     g_free(package_prefix);
     g_free(package_data_dir);
