@@ -1,18 +1,15 @@
-/* $Id: tvnodes.h,v 1.8 2009/10/09 18:28:17 erg Exp $ $Revision: 1.8 $ */
+/* $Id: tvnodes.h,v 1.12 2011/01/25 16:30:47 ellson Exp $ $Revision: 1.12 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #ifndef TVNODES_H
 #define TVNODES_H
@@ -103,6 +100,7 @@ extern "C" {
 	int initialized;
 	int general_purpose_flag;	//dont forget to to set it back
     } tv_nodes;
+/*
     extern tv_nodes TV_Nodes;
 
 
@@ -127,9 +125,11 @@ extern "C" {
     int tv_unselect_all(void);
     int tv_highligh_all(void);
     int tv_unhighligh_all(void);
+*/
     int tv_show_all(void);
     int tv_hide_all(void);
-    int tv_save_as(void);
+    int tv_save_as(int);
+    void setup_tree (Agraph_t* g);
 
 #ifdef __cplusplus
 }				/* end extern "C" */
