@@ -1,18 +1,15 @@
-/* $Id: viewport.c,v 1.105 2009/12/04 21:08:05 arif Exp $ $Revision: 1.105 $ */
+/* $Id: viewport.c,v 1.127 2011/04/15 21:06:43 erg Exp $ $Revision: 1.127 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 #ifdef _WIN32
 #include <windows.h>
 #include <io.h>
@@ -27,7 +24,8 @@
 #include "gui.h"
 #include "menucallbacks.h"
 #include "string.h"
-#include "topview.h"
+#include "glcompui.h"
+/* #include "topview.h" */
 #include "gltemplate.h"
 #include "colorprocs.h"
 #include "memory.h"
@@ -35,7 +33,7 @@
 #include "md5.h"
 #include "arcball.h"
 #include "hotkeymap.h"
-
+#include "topviewfuncs.h"
 
 
   /* Forward declarations */
@@ -44,6 +42,10 @@ static int init_object_custom_data(Agraph_t * graph, void *obj);
 static void refresh_borders(Agraph_t * g);
 #endif
 
+static colorschemaset *create_color_theme(int themeid);
+static md5_byte_t *get_md5_key(Agraph_t * graph);
+
+
 #define countof( array ) ( sizeof( array )/sizeof( array[0] ) )
 
 ViewInfo *view;
@@ -75,11 +77,13 @@ static Dtdisc_t qDisc = {
 #endif
 
 
-void clear_viewport(ViewInfo * view)
+static void clear_viewport(ViewInfo * view)
 {
     /*free topview if there is one */
     if (view->activeGraph >= 0)
-	cleartopview(view->Topview);
+    {
+	freeSmGraph(view->g[view->activeGraph],view->Topview);
+    }
     if (view->graphCount)
 	agclose(view->g[view->activeGraph]);
 //      init_viewport(view);
@@ -111,7 +115,7 @@ static void *get_glut_font(int ind)
     }
 
 }
-void fill_key(md5_byte_t * b, md5_byte_t * data)
+static void fill_key(md5_byte_t * b, md5_byte_t * data)
 {
     int ind = 0;
     for (ind = 0; ind < 16; ind++) {
@@ -119,6 +123,8 @@ void fill_key(md5_byte_t * b, md5_byte_t * data)
     }
 
 }
+
+#if TEST_FOR_CHANGE
 static int compare_keys(md5_byte_t * b1, md5_byte_t * b2)
 {
     /*1 keys are equal */
@@ -133,12 +139,17 @@ static int compare_keys(md5_byte_t * b1, md5_byte_t * b2)
     }
     return eq;
 }
-
+#endif
 
 int close_graph(ViewInfo * view, int graphid)
 {
     if (view->activeGraph < 0)
 	return 1;
+#if TEST_FOR_CHANGE
+    /* This test should only be done if the user has something significant, not just
+     * setting some smyrna control, which then becomes a changed attribute. In addition,
+     * it might be good to allow a user to express a preference for the service.
+     */
     fill_key(view->final_key, get_md5_key(view->g[graphid]));
     if (!compare_keys(view->final_key, view->orig_key))
 	view->Topview->Graphdata.Modified = 1;
@@ -160,6 +171,7 @@ int close_graph(ViewInfo * view, int graphid)
 	    break;
 	}
     }
+#endif
     clear_viewport(view);
     return 1;
 
@@ -180,6 +192,7 @@ void set_viewport_settings_from_template(ViewInfo * view, Agraph_t * g)
     char *buf;
     colorxlate(get_attribute_value("bordercolor", view, g), &cl,
 	       RGBA_DOUBLE);
+    /* glEnable(GL_POINT_SMOOTH); */
     view->borderColor.R = (float) cl.u.RGBA[0];
     view->borderColor.G = (float) cl.u.RGBA[1];
     view->borderColor.B = (float) cl.u.RGBA[2];
@@ -286,7 +299,10 @@ void set_viewport_settings_from_template(ViewInfo * view, Agraph_t * g)
 	     ("defaultfisheyemagnifierdistort", view, g));
     view->drawnodes = atoi(get_attribute_value("drawnodes", view, g));
     view->drawedges = atoi(get_attribute_value("drawedges", view, g));
-    view->drawlabels = atoi(get_attribute_value("drawlabels", view, g));
+    view->drawnodelabels=atoi(get_attribute_value("labelshownodes", view, g));
+    view->drawedgelabels=atoi(get_attribute_value("labelshowedges", view, g));
+    view->nodeScale=atof(get_attribute_value("nodesize", view, g))*.30;
+
     view->FontSizeConst = 0;	//this will be calculated later in topview.c while calculating optimum font size
 
     view->glutfont =
@@ -310,9 +326,9 @@ void set_viewport_settings_from_template(ViewInfo * view, Agraph_t * g)
     view->labelnumberofnodes =
 	atof(get_attribute_value("labelnumberofnodes", view, g));
     view->labelshownodes =
-	atoi(get_attribute_value("shownodelabels", view, g));
+	atoi(get_attribute_value("labelshownodes", view, g));
     view->labelshowedges =
-	atoi(get_attribute_value("showedgelabels", view, g));
+	atoi(get_attribute_value("labelshowedges", view, g));
     view->colschms =
 	create_color_theme(atoi
 			   (get_attribute_value("colortheme", view, g)));
@@ -326,7 +342,7 @@ void set_viewport_settings_from_template(ViewInfo * view, Agraph_t * g)
 static gboolean gl_main_expose(gpointer data)
 {
     if (view->activeGraph >= 0) {
-	if (view->Topview->animate == 1)
+	if (view->Topview->fisheyeParams.animate == 1)
 	    expose_event(view->drawing_area, NULL, NULL);
 	return 1;
     }
@@ -457,32 +473,27 @@ void init_viewport(ViewInfo * view)
     view->mouse.down = 0;
     view->activeGraph = -1;
     view->SignalBlock = 0;
-    view->Selection.Active = 0;
-    view->Selection.SelectionColor.R = 0.5;
-    view->Selection.SelectionColor.G = (float) 0.2;
-    view->Selection.SelectionColor.B = 1;
-    view->Selection.SelectionColor.A = 1;
-    view->Selection.Anti = 0;
     view->Topview = GNEW(topview);
-    view->Topview->fs = 0;
+    view->Topview->fisheyeParams.fs = 0;
     view->Topview->xDot=NULL;
 
     /* init topfish parameters */
-    view->Topview->parms.level.num_fine_nodes = 10;
-    view->Topview->parms.level.coarsening_rate = 2.5;
-    view->Topview->parms.hier.dist2_limit = 1;
-    view->Topview->parms.hier.min_nvtxs = 20;
-    view->Topview->parms.repos.rescale = Polar;
-    view->Topview->parms.repos.width =
+    view->Topview->fisheyeParams.level.num_fine_nodes = 10;
+    view->Topview->fisheyeParams.level.coarsening_rate = 2.5;
+    view->Topview->fisheyeParams.hier.dist2_limit = 1;
+    view->Topview->fisheyeParams.hier.min_nvtxs = 20;
+    view->Topview->fisheyeParams.repos.rescale = Polar;
+    view->Topview->fisheyeParams.repos.width =
 	(int) (view->bdxRight - view->bdxLeft);
-    view->Topview->parms.repos.height =
+    view->Topview->fisheyeParams.repos.height =
 	(int) (view->bdyTop - view->bdyBottom);
-    view->Topview->parms.repos.margin = 0;
-    view->Topview->parms.repos.graphSize = 100;
-    view->Topview->parms.repos.distortion = 1.0;
+    view->Topview->fisheyeParams.repos.margin = 0;
+    view->Topview->fisheyeParams.repos.graphSize = 100;
+    view->Topview->fisheyeParams.repos.distortion = 1.0;
     /*create timer */
     view->timer = g_timer_new();
     view->timer2 = g_timer_new();
+    view->timer3 = g_timer_new();
 
     g_timer_stop(view->timer);
     view->active_frame = 0;
@@ -510,8 +521,12 @@ void init_viewport(ViewInfo * view)
     view->refresh.visibility=1;
     view->refresh.nodesize=1;
     view->edgerendertype=0;
-    /*add default camera */
-    //create fontset
+    if(view->guiMode!=GUI_FULLSCREEN)
+	view->guiMode=GUI_WINDOWED;
+
+    /*create glcomp menu system */
+    view->widgets = glcreate_gl_topview_menu();
+
 }
 
 
@@ -604,10 +619,11 @@ static Agraph_t *loadGraph(char *filename)
     /* If no position info, run layout with -Txdot
      */
     if (!agattr(g, AGNODE, "pos", NULL)) {
-	g_print("There is no position info in %s\n", filename);
+	g_print("There is no position info in graph %s in %s\n", agnameof(g), filename);
+	agclose (g);
 	return 0;
     }
-    free(view->Topview->Graphdata.GraphFileName);
+//    free(view->Topview->Graphdata.GraphFileName);
     view->Topview->Graphdata.GraphFileName = strdup(filename);
     return g;
 }
@@ -632,6 +648,46 @@ int add_graph_to_viewport_from_file(char *fileName)
     return add_graph_to_viewport(graph, fileName);
 }
 
+/* updateRecord:
+ * Update fields which may be added dynamically.
+ */
+void updateRecord (Agraph_t* g)
+{
+    GN_size(g) = agattr (g, AGNODE, "size", 0);
+    GN_visible(g) = agattr (g, AGNODE, "visible", 0);
+    GN_selected(g) = agattr (g, AGNODE, "selected", 0);
+    GN_labelattribute(g) = agattr (g, AGNODE, "nodelabelattribute", 0);
+
+    GE_pos(g)=agattr(g,AGEDGE,"pos",0);
+    GE_visible(g) = agattr (g, AGEDGE, "visible", 0);
+    GE_selected(g) = agattr (g, AGEDGE, "selected", 0);
+    GE_labelattribute(g) = agattr (g, AGEDGE, "edgelabelattribute", 0);
+}
+
+/* graphRecord:
+ * add graphRec to graph if necessary.
+ * update fields of graphRec.
+ * We assume the graph has attributes nodelabelattribute, edgelabelattribute,
+ * nodelabelcolor and edgelabelcolor from template.dot.
+ * We assume nodes have pos attributes. 
+ * Only size, visible, selected and edge pos may or may not be defined.
+ */
+static void
+graphRecord (Agraph_t* g)
+{
+    agbindrec(g, "graphRec", sizeof(graphRec), 1);
+
+    GG_nodelabelcolor(g) = agattr (g, AGRAPH, "nodelabelcolor", 0);
+    GG_edgelabelcolor(g) = agattr (g, AGRAPH, "edgelabelcolor", 0);
+    GG_labelattribute(g) = agattr (g, AGRAPH, "nodelabelattribute", 0);
+    GG_elabelattribute(g) = agattr (g, AGRAPH, "edgelabelattribute", 0);
+
+    GN_pos(g) = agattr (g, AGNODE, "pos", 0);
+
+
+    updateRecord (g);
+}
+
 void refreshViewport(int doClear)
 {
     Agraph_t *graph = view->g[view->activeGraph];
@@ -641,12 +697,14 @@ void refreshViewport(int doClear)
     view->refresh.selection=1;
     view->refresh.visibility=1;
     load_settings_from_graph(graph);
-    update_graph_from_settings(graph);
-    set_viewport_settings_from_template(view, graph);
-    if (doClear)
-	cleartopview(view->Topview);
 
-    update_topview(graph, view->Topview, 1);
+    if(view->guiMode!=GUI_FULLSCREEN)
+	update_graph_from_settings(graph);
+    set_viewport_settings_from_template(view, graph);
+    graphRecord(graph);
+    initSmGraph(graph,view->Topview);
+
+//    update_topview(graph, view->Topview, 1);
     fill_key(view->orig_key, get_md5_key(graph));
     expose_event(view->drawing_area, NULL, NULL);
 }
@@ -677,7 +735,7 @@ int add_graph_to_viewport(Agraph_t * graph, char *id)
 }
 void switch_graph(int graphId)
 {
-    if (graphId >= view->graphCount)
+    if ((graphId >= view->graphCount) || (graphId < 0))
 	return;			/*wrong entry */
     else
 	activate(graphId, 0);
@@ -703,20 +761,20 @@ int add_new_graph_to_viewport(void)
 static md5_byte_t md5_digest[16];
 static md5_state_t pms;
 
-int append_to_md5(void *chan, const char *str)
+static int append_to_md5(void *chan, const char *str)
 {
     md5_append(&pms, (unsigned char *) str, (int) strlen(str));
     return 1;
 
 }
-int flush_md5(void *chan)
+static int flush_md5(void *chan)
 {
     md5_finish(&pms, md5_digest);
     return 1;
 }
 
 
-md5_byte_t *get_md5_key(Agraph_t * graph)
+static md5_byte_t *get_md5_key(Agraph_t * graph)
 {
     Agiodisc_t *xio;
     Agiodisc_t a;
@@ -767,7 +825,8 @@ int save_graph_with_file_name(Agraph_t * graph, char *fileName)
 int save_graph(void)
 {
     //check if there is an active graph
-    if (view->activeGraph > -1) {
+    if (view->activeGraph > -1) 
+    {
 	//check if active graph has a file name
 	if (view->Topview->Graphdata.GraphFileName) {
 	    return save_graph_with_file_name(view->g[view->activeGraph],
@@ -775,8 +834,8 @@ int save_graph(void)
 					     GraphFileName);
 	} else
 	    return save_as_graph();
+        fill_key(view->orig_key, get_md5_key(view->g[view->activeGraph]));
     }
-    fill_key(view->orig_key, get_md5_key(view->g[view->activeGraph]));
     return 1;
 
 }
@@ -817,13 +876,10 @@ int save_as_graph(void)
 }
 
 
-/* init_object_custom_data:
- * creates a custom_object_data
- */
-
+#ifdef UNUSED
 /* move_node:
  */
-void movenode(void *obj, float dx, float dy)
+static void movenode(void *obj, float dx, float dy)
 {
     char buf[512];
     double x, y;
@@ -836,7 +892,6 @@ void movenode(void *obj, float dx, float dy)
     }
 }
 
-#ifdef UNUSED
 static char *move_xdot(void *obj, xdot * x, int dx, int dy, int dz)
 {
     int i = 0;
@@ -1005,6 +1060,7 @@ void glexpose(void)
     expose_event(view->drawing_area, NULL, NULL);
 }
 
+#if 0
 /*following code does not do what i like it to do*/
 /*I liked to have a please wait window on the screen all i got was the outer borders of the window
 GTK requires a custom widget expose function 
@@ -1021,23 +1077,25 @@ void please_dont_wait(void)
 {
     gtk_widget_hide(glade_xml_get_widget(xml, "frmWait"));
 }
+#endif
 
 float interpol(float minv, float maxv, float minc, float maxc, float x)
 {
     return ((x - minv) * (maxc - minc) / (maxv - minv) + minc);
 }
+
 void getcolorfromschema(colorschemaset * sc, float l, float maxl,
 			glCompColor * c)
 {
     int ind;
-    /* float cuml=0.00; */
-    float percl = l / maxl * 100.00;
-    for (ind = 0; ind < sc->schemacount; ind++) {
-	if (percl < sc->s[ind].perc)
-	    break;
-    }
+    float percl = l / maxl;
 
-    if (sc->s[ind].smooth) {
+    if (sc->smooth) {
+	/* For smooth schemas, s[0].perc = 0, so we start with ind=1 */
+	for (ind = 1; ind < sc->schemacount-1; ind++) {
+	    if (percl < sc->s[ind].perc)
+		break;
+	}
 	c->R =
 	    interpol(sc->s[ind - 1].perc, sc->s[ind].perc,
 		     sc->s[ind - 1].c.R, sc->s[ind].c.R, percl);
@@ -1047,128 +1105,103 @@ void getcolorfromschema(colorschemaset * sc, float l, float maxl,
 	c->B =
 	    interpol(sc->s[ind - 1].perc, sc->s[ind].perc,
 		     sc->s[ind - 1].c.B, sc->s[ind].c.B, percl);
-	c->A = 1;
-    } else {
+    }
+    else {
+	for (ind = 0; ind < sc->schemacount-1; ind++) {
+	    if (percl < sc->s[ind].perc)
+		break;
+	}
 	c->R = sc->s[ind].c.R;
 	c->G = sc->s[ind].c.G;
 	c->B = sc->s[ind].c.B;
-	c->A = 1;
     }
+
+    c->A = 1;
 }
-static void set_color_theme_color(colorschemaset * sc, char **colorstr,
-				  int colorcnt, int smooth)
+
+/* set_color_theme_color:
+ * Convert colors as strings to RGB
+ */
+static void set_color_theme_color(colorschemaset * sc, char **colorstr, int smooth)
 {
-    int ind = 0;
+    int ind;
+    int colorcnt = sc->schemacount;
     gvcolor_t cl;
     float av_perc;
-    av_perc = 100.00 / (float) (colorcnt - 1);
-    for (; ind < colorcnt; ind++) {
-	colorxlate(colorstr[ind], &cl, RGBA_DOUBLE);
-	sc->s[ind].c.R = cl.u.RGBA[0];
-	sc->s[ind].c.G = cl.u.RGBA[1];
-	sc->s[ind].c.B = cl.u.RGBA[2];
-	sc->s[ind].c.A = cl.u.RGBA[3];
-	sc->s[ind].perc = ind * av_perc;
-	sc->s[ind].smooth = smooth;
+
+    sc->smooth = smooth;
+    if (smooth) {
+	av_perc = 1.0 / (float) (colorcnt-1);
+	for (ind = 0; ind < colorcnt; ind++) {
+	    colorxlate(colorstr[ind], &cl, RGBA_DOUBLE);
+	    sc->s[ind].c.R = cl.u.RGBA[0];
+	    sc->s[ind].c.G = cl.u.RGBA[1];
+	    sc->s[ind].c.B = cl.u.RGBA[2];
+	    sc->s[ind].c.A = cl.u.RGBA[3];
+	    sc->s[ind].perc = ind * av_perc;
+	}
+    }
+    else {
+	av_perc = 1.0 / (float) (colorcnt);
+	for (ind = 0; ind < colorcnt; ind++) {
+	    colorxlate(colorstr[ind], &cl, RGBA_DOUBLE);
+	    sc->s[ind].c.R = cl.u.RGBA[0];
+	    sc->s[ind].c.G = cl.u.RGBA[1];
+	    sc->s[ind].c.B = cl.u.RGBA[2];
+	    sc->s[ind].c.A = cl.u.RGBA[3];
+	    sc->s[ind].perc = (ind+1) * av_perc;
+	}
     }
-
-
-
-
-
 }
 
-/*typedef struct{
-	float perc;
-	glCompColor c;
-	int smooth;
-
-}colorschema;
-
-typedef struct{
-	int schemacount;
-	colorschema* s;
-}colorschemaset; */
-
-void clear_color_theme(colorschemaset * cs)
+static void clear_color_theme(colorschemaset * cs)
 {
     free(cs->s);
     free(cs);
 }
 
-
-
-colorschemaset *create_color_theme(int themeid)
-{
+static char *deep_blue[] = {
+    "#C8CBED", "#9297D3", "#0000FF", "#2C2E41"
+};
+static char *pastel[] = {
+    "#EBBE29", "#D58C4A", "#74AE09", "#893C49"
+};
+static char *magma[] = {
+    "#E0061E", "#F0F143", "#95192B", "#EB712F"
+};
+static char *rain_forest[] = {
+    "#1E6A10", "#2ABE0E", "#AEDD39", "#5EE88B"
+};
+#define CSZ(x) (sizeof(x)/sizeof(char*))
+typedef struct {
+    int cnt;
     char **colors;
-    colorschemaset *s = malloc(sizeof(colorschemaset));
+} colordata;
+static colordata palette[] = {
+    {CSZ(deep_blue), deep_blue},
+    {CSZ(pastel), pastel},
+    {CSZ(magma), magma},
+    {CSZ(rain_forest), rain_forest},
+};
+#define NUM_SCHEMES (sizeof(palette)/sizeof(colordata))
 
+static colorschemaset *create_color_theme(int themeid)
+{
+    colorschemaset *s;
+
+    if ((themeid < 0) || (NUM_SCHEMES <= themeid)) {
+	fprintf (stderr, "colorschemaset: illegal themeid %d\n", themeid);
+	return view->colschms;
+    }
+
+    s = NEW(colorschemaset);
     if (view->colschms)
 	clear_color_theme(view->colschms);
-    s->schemacount = 4;
-    s->s = malloc(sizeof(colorschema) * 4);
 
+    s->schemacount = palette[themeid].cnt;
+    s->s = N_NEW(s->schemacount,colorschema);
+    set_color_theme_color(s, palette[themeid].colors, 1);
 
-    colors = malloc(sizeof(char *) * 4);
-
-
-    switch (themeid) {
-    case 0:			//deep blue
-
-	colors[0] = strdup("#C8CBED");
-	colors[1] = strdup("#9297D3");
-	colors[2] = strdup("#blue");
-	colors[3] = strdup("#2C2E41");
-	set_color_theme_color(s, colors, s->schemacount, 1);
-	break;
-    case 1:			//all pastel
-	colors[0] = strdup("#EBBE29");
-	colors[1] = strdup("#D58C4A");
-	colors[2] = strdup("#74AE09");
-	colors[3] = strdup("#893C49");
-	set_color_theme_color(s, colors, s->schemacount, 1);
-	break;
-    case 2:			//magma
-	colors[0] = strdup("#E0061E");
-	colors[1] = strdup("#F0F143");
-	colors[2] = strdup("#95192B");
-	colors[3] = strdup("#EB712F");
-	set_color_theme_color(s, colors, s->schemacount, 1);
-	break;
-    case 3:			//rain forest
-	colors[0] = strdup("#1E6A10");
-	colors[1] = strdup("#2ABE0E");
-	colors[2] = strdup("#AEDD39");
-	colors[3] = strdup("#5EE88B");
-	set_color_theme_color(s, colors, s->schemacount, 1);
-	break;
-    }
-    free(colors[0]);
-    free(colors[1]);
-    free(colors[2]);
-    free(colors[3]);
-    free(colors);
     return s;
 }
 
-
-void test_color_pallete(void)
-{
-    int ind = 0;
-    float xGAP = 5;
-    float yGAP = 80;
-    float x = 50;
-    float y = 50;
-    glCompColor c;
-    for (ind = 0; ind < 350; ind++) {
-	getcolorfromschema(view->colschms, ind, 350, &c);
-	x = ind * xGAP;
-	glBegin(GL_POLYGON);
-	glColor3f(c.R, c.G, c.B);
-	glVertex3f(x, y, 0.0);
-	glVertex3f(x + xGAP, y, 0.0);
-	glVertex3f(x + xGAP, y + yGAP, 0.0);
-	glVertex3f(x, y + yGAP, 0.0);
-	glEnd();
-    }
-}
