@@ -1,18 +1,15 @@
-/* $Id: viewport.h,v 1.31 2009/10/15 17:21:19 arif Exp $ $Revision: 1.31 $ */
+/* $Id: viewport.h,v 1.34 2011/01/25 16:30:47 ellson Exp $ $Revision: 1.34 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 //view data structure
 #ifndef VIEWPORT_H
@@ -29,7 +26,15 @@ extern "C" {
 
     void init_viewport(ViewInfo * view);
     void set_viewport_settings_from_template(ViewInfo * view, Agraph_t *);
+#if 0
     void clear_viewport(ViewInfo * view);
+    colorschemaset *create_color_theme(int themeid);
+    md5_byte_t *get_md5_key(Agraph_t * graph);
+    void fill_key(md5_byte_t * b, md5_byte_t * data);
+    void movenode(void *n, float dx, float dy);
+    void please_dont_wait(void);
+    void please_wait(void);
+#endif
     void switch_graph(int);
     void refreshViewport(int doClear);
     int add_graph_to_viewport_from_file(char *fileName);
@@ -41,16 +46,11 @@ extern "C" {
 
     int do_graph_layout(Agraph_t * graph, int Engine, int keeppos);
 
-    void movenode(void *n, float dx, float dy);
     void glexpose(void);
     void move_nodes(Agraph_t * g);
-    void please_wait(void);
-    void please_dont_wait(void);
-    extern md5_byte_t *get_md5_key(Agraph_t * graph);
-    void fill_key(md5_byte_t * b, md5_byte_t * data);
-    colorschemaset *create_color_theme(int themeid);
     extern void getcolorfromschema(colorschemaset * sc, float l,
 				   float maxl, glCompColor * c);
+    void updateRecord (Agraph_t* g);
 
 
     /* helper functions */
