@@ -1,17 +1,15 @@
+/* $Id: viewportcamera.c,v 1.17 2011/01/25 16:30:47 ellson Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include "viewportcamera.h"
 #include "gui.h"
@@ -35,7 +33,7 @@ static void viewport_update_camera_indexes(ViewInfo * view)
     }
 }
 
-viewport_camera *add_camera_to_viewport(ViewInfo * view)
+static viewport_camera *add_camera_to_viewport(ViewInfo * view)
 {
     view->camera_count++;
     view->cameras =
@@ -46,7 +44,8 @@ viewport_camera *add_camera_to_viewport(ViewInfo * view)
     return view->cameras[view->camera_count - 1];
 }
 
-void set_camera_x_y(viewport_camera * c)
+#if 0
+static void set_camera_x_y(viewport_camera * c)
 {
 /*    c->x =
 	c->r * cos((float) DEG2RAD * c->anglexy) * sin((float) DEG2RAD *
@@ -57,29 +56,29 @@ void set_camera_x_y(viewport_camera * c)
 	view->pany;
     c->z = c->r * cos(DEG2RAD * c->anglexyz);*/
 }
-
 int delete_camera_from_viewport(ViewInfo * view, viewport_camera * c)
 {
     int ind;
     int found = 0;
-    for (ind = 0; ind < view->camera_count; ind++) 
-	{
-		if ((view->cameras[ind] == c) && found == 0)
-		    found = 1;
-		if ((found == 1) && (ind < (view->camera_count - 1)))
-			view->cameras[ind] = view->cameras[ind + 1];
+    for (ind = 0; ind < view->camera_count; ind++) {
+	if ((view->cameras[ind] == c) && found == 0)
+	    found = 1;
+	if ((found == 1) && (ind < (view->camera_count - 1)))
+	    view->cameras[ind] = view->cameras[ind + 1];
     }
-    if (found) 
-	{
-		free(c);
-		view->camera_count--;
-		view->cameras =RALLOC(view->camera_count, view->cameras, viewport_camera *);
-		viewport_update_camera_indexes(view);
-		view->active_camera--;
-		return 1;
+    if (found) {
+	free(c);
+	view->camera_count--;
+	view->cameras =
+	    RALLOC(view->camera_count, view->cameras, viewport_camera *);
+	viewport_update_camera_indexes(view);
+	view->active_camera--;
+	return 1;
     }
     return 0;
 }
+#endif
+#if 0
 int activate_viewport_camera(ViewInfo * view, int cam_index)
 {
     if (cam_index < view->camera_count) {
@@ -88,7 +87,6 @@ int activate_viewport_camera(ViewInfo * view, int cam_index)
     } else
 	return 0;
 }
-
 int refresh_viewport_camera(ViewInfo * view)
 {
     if (view->active_camera >= 0) {
@@ -101,6 +99,7 @@ int refresh_viewport_camera(ViewInfo * view)
     } else
 	return 0;
 }
+#endif
 
 void menu_click_add_camera(void *p)
 {
@@ -125,153 +124,22 @@ void menu_click_add_camera(void *p)
 
     c->r = view->zoom * -1;
 //      set_camera_x_y(c);
-    attach_camera_widget(view);
-
-
+//    attach_camera_widget(view);
 }
 
-int blocksignal = 0;
-void menu_click_2d(void *p)
+#ifdef UNUSED
+static int blocksignal = 0;
+static void menu_click_2d(void *p)
 {
     view->active_camera = -1;
 }
 
-void menu_click_camera_select(void *p)
+static void menu_click_camera_select(void *p)
 {
     view->active_camera = ((glCompButton *) p)->data;
 }
 
-
-void menu_click_camera_remove(void *p)
-{
-    delete_camera_from_viewport(view,
-				view->cameras[(int) ((glCompButton *) p)->
-					      data]);
-    attach_camera_widget(view);
-
-}
-void menu_click_camera_edit(void *p)
-{
-    show_camera_settings(view->cameras[(int) ((glCompButton *) p)->data]
-	);
-}
-
-
-void attach_camera_widget(ViewInfo * view)
-{
-
-#define PANEL_PADDING			5
-#define	CAMERA_BUTTON_HEIGHT	25
-#define	CAMERA_BUTTON_WIDTH		75
-
-
-    int ind, ind2;
-	GLfloat x, y;
-    char buf[256];
-    glCompPanel *p;
-    glCompButton *b;
-	glCompSet *s = view->widgets;
-    int p_height;
-    /*first we need to get rid of the old menu */
-    for (ind = 0; ind < s->panelcount; ind++) 
-	{
-		if (s->panels[ind]->data == 3) 
-		{
-		    /*remove buttons in the panel */
-		    for (ind2 = 0; ind2 < s->buttoncount; ind2++) 
-			{
-				if (s->buttons[ind2]->panel == s->panels[ind]) 
-				{
-					glCompSetRemoveButton(s, s->buttons[ind2]);
-					ind2--;
-				}
-			}
-			/*remove panel itself */
-			glCompSetRemovePanel(s, s->panels[ind]);
-			break;
-		}
-    }
-
-
-
-
-    /*calculate height of panel */
-    p_height =
-	2 * PANEL_PADDING + view->camera_count * (CAMERA_BUTTON_HEIGHT +
-						  PANEL_PADDING) +
-	CAMERA_BUTTON_HEIGHT;
-
-
-    /*container for camera buttons */
-    p = glCompPanelNew((GLfloat) 25, (GLfloat) 75,
-		       (GLfloat) 4 * PANEL_PADDING +
-		       3 * CAMERA_BUTTON_WIDTH, (GLfloat) p_height,scientific_y);
-    p->data = 3;
-    glCompSetAddPanel(s, p);
-
-    b = glCompButtonNew((GLfloat) PANEL_PADDING, (GLfloat) PANEL_PADDING,
-			(GLfloat) CAMERA_BUTTON_WIDTH,
-			(GLfloat) CAMERA_BUTTON_HEIGHT, "ADD", '\0', 0, 0,scientific_y);
-    b->panel = p;
-    b->groupid = 0;
-    b->customptr = view;
-    glCompSetAddButton(s, b);
-    b->callbackfunc = menu_click_add_camera;
-
-    b = glCompButtonNew((GLfloat) PANEL_PADDING * 2 +
-			(GLfloat) CAMERA_BUTTON_WIDTH,
-			(GLfloat) PANEL_PADDING,
-			(GLfloat) CAMERA_BUTTON_WIDTH,
-			(GLfloat) CAMERA_BUTTON_HEIGHT, "2D", '\0', 0, 0,scientific_y);
-    b->panel = p;
-    b->groupid = 4;		//4 is assigned to all camera buttons 
-    b->customptr = view;
-    glCompSetAddButton(s, b);
-    b->callbackfunc = menu_click_2d;
-
-    for (ind = 0; ind < view->camera_count; ind++) 
-	{
-		y = p->height - ((GLfloat) PANEL_PADDING +
-				 (GLfloat)ind * ((GLfloat) CAMERA_BUTTON_HEIGHT +
-					(GLfloat) PANEL_PADDING)) -
-			(GLfloat)CAMERA_BUTTON_HEIGHT;
-		x = PANEL_PADDING;
-		sprintf(buf, "CAM%i", ind + 1);
-		b = glCompButtonNew((GLfloat)x, (GLfloat)y, (GLfloat) CAMERA_BUTTON_WIDTH,
-				    (GLfloat) CAMERA_BUTTON_HEIGHT, buf, '\0', 0,
-				    0,scientific_y);
-		b->panel = p;
-		b->groupid = 4;		//4 is assigned to all camera buttons 
-		b->data = ind;		//assign camera id to custom data to use single call back
-		b->customptr = view;
-		glCompSetAddButton(s, b);
-		b->callbackfunc = menu_click_camera_select;
-
-		x = PANEL_PADDING * 2 + CAMERA_BUTTON_WIDTH;
-		b = glCompButtonNew((GLfloat)x,(GLfloat) y, (GLfloat) CAMERA_BUTTON_WIDTH,
-			    (GLfloat) CAMERA_BUTTON_HEIGHT, "Remove", '\0',
-			    0, 0,scientific_y);
-		b->panel = p;
-		b->groupid = 0;
-		b->data = ind;		//assign camera id to custom data to use single call back
-		b->customptr = view;
-		glCompSetAddButton(s, b);
-		b->callbackfunc = menu_click_camera_remove;
-
-		x = PANEL_PADDING * 3 + CAMERA_BUTTON_WIDTH * 2;
-		b = glCompButtonNew((GLfloat) x, (GLfloat) y,
-			    (GLfloat) CAMERA_BUTTON_WIDTH,
-			    (GLfloat) CAMERA_BUTTON_HEIGHT, "Edit", '\0',
-			    0, 0,scientific_y);
-		b->panel = p;
-		b->groupid = 0;
-		b->data = ind;		//assign camera id to custom data to use single call back
-		b->customptr = view;
-		glCompSetAddButton(s, b);
-		b->callbackfunc = menu_click_camera_edit;
-    }
-}
-int show_camera_settings(viewport_camera * c)
+static int show_camera_settings(viewport_camera * c)
 {
 
     char buf[50];
@@ -331,6 +199,128 @@ int show_camera_settings(viewport_camera * c)
 
 }
 
+static void menu_click_camera_edit(void *p)
+{
+    show_camera_settings(view->cameras[(int) ((glCompButton *) p)->data]
+	);
+}
+
+void attach_camera_widget(ViewInfo * view)
+{
+
+#define PANEL_PADDING			5
+#define	CAMERA_BUTTON_HEIGHT	25
+#define	CAMERA_BUTTON_WIDTH		75
+
+
+    int ind, ind2;
+    GLfloat x, y;
+    char buf[256];
+    glCompPanel *p;
+    glCompButton *b;
+    glCompSet *s = view->widgets;
+    int p_height;
+    /*first we need to get rid of the old menu */
+    for (ind = 0; ind < s->panelcount; ind++) {
+	if (s->panels[ind]->data == 3) {
+	    /*remove buttons in the panel */
+	    for (ind2 = 0; ind2 < s->buttoncount; ind2++) {
+		if (s->buttons[ind2]->panel == s->panels[ind]) {
+		    glCompSetRemoveButton(s, s->buttons[ind2]);
+		    ind2--;
+		}
+	    }
+	    /*remove panel itself */
+	    glCompSetRemovePanel(s, s->panels[ind]);
+	    break;
+	}
+    }
+
+
+
+
+    /*calculate height of panel */
+    p_height =
+	2 * PANEL_PADDING + view->camera_count * (CAMERA_BUTTON_HEIGHT +
+						  PANEL_PADDING) +
+	CAMERA_BUTTON_HEIGHT;
+
+
+    /*container for camera buttons */
+    p = glCompPanelNew((GLfloat) 25, (GLfloat) 75,
+		       (GLfloat) 4 * PANEL_PADDING +
+		       3 * CAMERA_BUTTON_WIDTH, (GLfloat) p_height,
+		       scientific_y);
+    p->data = 3;
+    glCompSetAddPanel(s, p);
+
+    b = glCompButtonNew((GLfloat) PANEL_PADDING, (GLfloat) PANEL_PADDING,
+			(GLfloat) CAMERA_BUTTON_WIDTH,
+			(GLfloat) CAMERA_BUTTON_HEIGHT, "ADD", '\0', 0, 0,
+			scientific_y);
+    b->panel = p;
+    b->groupid = 0;
+    b->customptr = view;
+    glCompSetAddButton(s, b);
+    b->callbackfunc = menu_click_add_camera;
+
+    b = glCompButtonNew((GLfloat) PANEL_PADDING * 2 +
+			(GLfloat) CAMERA_BUTTON_WIDTH,
+			(GLfloat) PANEL_PADDING,
+			(GLfloat) CAMERA_BUTTON_WIDTH,
+			(GLfloat) CAMERA_BUTTON_HEIGHT, "2D", '\0', 0, 0,
+			scientific_y);
+    b->panel = p;
+    b->groupid = 4;		//4 is assigned to all camera buttons 
+    b->customptr = view;
+    glCompSetAddButton(s, b);
+    b->callbackfunc = menu_click_2d;
+
+    for (ind = 0; ind < view->camera_count; ind++) {
+	y = p->height - ((GLfloat) PANEL_PADDING +
+			 (GLfloat) ind * ((GLfloat) CAMERA_BUTTON_HEIGHT +
+					  (GLfloat) PANEL_PADDING)) -
+	    (GLfloat) CAMERA_BUTTON_HEIGHT;
+	x = PANEL_PADDING;
+	sprintf(buf, "CAM%i", ind + 1);
+	b = glCompButtonNew((GLfloat) x, (GLfloat) y,
+			    (GLfloat) CAMERA_BUTTON_WIDTH,
+			    (GLfloat) CAMERA_BUTTON_HEIGHT, buf, '\0', 0,
+			    0, scientific_y);
+	b->panel = p;
+	b->groupid = 4;		//4 is assigned to all camera buttons 
+	b->data = ind;		//assign camera id to custom data to use single call back
+	b->customptr = view;
+	glCompSetAddButton(s, b);
+	b->callbackfunc = menu_click_camera_select;
+
+	x = PANEL_PADDING * 2 + CAMERA_BUTTON_WIDTH;
+	b = glCompButtonNew((GLfloat) x, (GLfloat) y,
+			    (GLfloat) CAMERA_BUTTON_WIDTH,
+			    (GLfloat) CAMERA_BUTTON_HEIGHT, "Remove", '\0',
+			    0, 0, scientific_y);
+	b->panel = p;
+	b->groupid = 0;
+	b->data = ind;		//assign camera id to custom data to use single call back
+	b->customptr = view;
+	glCompSetAddButton(s, b);
+	b->callbackfunc = menu_click_camera_remove;
+
+	x = PANEL_PADDING * 3 + CAMERA_BUTTON_WIDTH * 2;
+	b = glCompButtonNew((GLfloat) x, (GLfloat) y,
+			    (GLfloat) CAMERA_BUTTON_WIDTH,
+			    (GLfloat) CAMERA_BUTTON_HEIGHT, "Edit", '\0',
+			    0, 0, scientific_y);
+	b->panel = p;
+	b->groupid = 0;
+	b->data = ind;		//assign camera id to custom data to use single call back
+	b->customptr = view;
+	glCompSetAddButton(s, b);
+	b->callbackfunc = menu_click_camera_edit;
+    }
+}
+#endif
+#if 0
 int save_camera_settings(viewport_camera * c)
 {
     c->x = (float) gtk_spin_button_get_value((GtkSpinButton *)
@@ -376,7 +366,8 @@ int save_camera_settings(viewport_camera * c)
 
 }
 
-void dlgcameraokbutton_clicked_cb(GtkWidget * widget, gpointer user_data) {
+void dlgcameraokbutton_clicked_cb(GtkWidget * widget, gpointer user_data)
+{
     gtk_widget_hide(glade_xml_get_widget(xml, "dlgCamera"));
     save_camera_settings(view->selected_camera);
 }
@@ -385,3 +376,4 @@ void dlgcameracancelbutton_clicked_cb
     (GtkWidget * widget, gpointer user_data) {
     gtk_widget_hide(glade_xml_get_widget(xml, "dlgCamera"));
 }
+#endif
