@@ -1,18 +1,15 @@
-/* $Id: bcomps.c,v 1.10 2010/01/08 21:28:39 erg Exp $ $Revision: 1.10 $ */
+/* $Id: bcomps.c,v 1.13 2011/01/25 16:30:47 ellson Exp $ $Revision: 1.13 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 /*
@@ -36,6 +33,13 @@
 #include <stdlib.h>
 #include "cgraph.h"
 
+
+#ifdef WIN32 /*dependencies*/
+    #pragma comment( lib, "cgraph.lib" )
+    #pragma comment( lib, "ingraphs.lib" )
+#endif
+
+
 typedef struct {
     Agrec_t h;
     Agraph_t *next;
@@ -102,14 +106,17 @@ static char *blockName(char *gname, int d)
     static int bufsz;
     int sz;
 
-    sz = strlen(gname) + 32;
+    sz = strlen(gname) + 128;
     if (sz > bufsz) {
 	if (buf)
 	    free(buf);
 	buf = (char *) malloc(sz);
     }
 
-    sprintf(buf, "%s_bcc_%d", gname, d);
+    if (*gname == '%') /* anonymous graph */
+	sprintf(buf, "_%s_bcc_%d", gname, d);
+    else
+	sprintf(buf, "%s_bcc_%d", gname, d);
     return buf;
 }
 
