@@ -1,18 +1,15 @@
-/* $Id: ccomps.c,v 1.19 2010/01/08 21:28:39 erg Exp $ $Revision: 1.19 $ */
+/* $Id: ccomps.c,v 1.24 2011/04/29 18:46:20 erg Exp $ $Revision: 1.24 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 /*
@@ -29,6 +26,7 @@
 #include "cgraph.h"
 
 #define N_NEW(n,t)       (t*)malloc((n)*sizeof(t))
+#define NEW(t)           (t*)malloc(sizeof(t))
 
 typedef struct {
     Agrec_t h;
@@ -70,10 +68,12 @@ typedef struct {
 #define SILENT   2
 #define EXTRACT  3
 
+char* Cmd;
 char **Files;
 int verbose;
 int printMode = INTERNAL;
 int useClusters = 0;
+int doEdges = 1;		/* induce edges */
 int doAll = 1;			/* induce subgraphs */
 char *suffix = 0;
 char *outfile = 0;
@@ -81,15 +81,18 @@ char *path = 0;
 int sufcnt = 0;
 int sorted = 0;
 int sortIndex = 0;
+int sortFinal;
 int x_index = -1;
+int x_final = -1;  /* require 0 <= x_index <= x_final or x_final= -1 */ 
 char *x_node;
 
 static char *useString =
-    "Usage: ccomps [-svnCx?] [-X[#]v] [-o<out template>] <files>\n\
+    "Usage: ccomps [-svenCx?] [-X[#]s[-f]] [-o<out template>] <files>\n\
   -s - silent\n\
   -x - external\n\
   -X - extract component\n\
   -C - use clusters\n\
+  -e - do not induce edges\n\
   -n - do not induce subgraphs\n\
   -v - verbose\n\
   -o - output file template\n\
@@ -131,9 +134,11 @@ static int isCluster(Agraph_t * g)
 static void init(int argc, char *argv[])
 {
     int c;
+    char* endp;
 
+    Cmd = argv[0];
     opterr = 0;
-    while ((c = getopt(argc, argv, ":zo:xCX:nsv")) != -1) {
+    while ((c = getopt(argc, argv, ":zo:xCX:nesv")) != -1) {
 	switch (c) {
 	case 'o':
 	    outfile = optarg;
@@ -142,6 +147,9 @@ static void init(int argc, char *argv[])
 	case 'C':
 	    useClusters = 1;
 	    break;
+	case 'e':
+	    doEdges = 0;
+	    break;
 	case 'n':
 	    doAll = 0;
 	    break;
@@ -155,8 +163,28 @@ static void init(int argc, char *argv[])
 	    if (*optarg == '#') {
 		char *p = optarg + 1;
 		if (isdigit(*p)) {
-		    x_index = atoi(p);
+		    x_index = (int)strtol (p, &endp, 10);
 		    printMode = EXTRACT;
+		    if (*endp == '-') {
+			p = endp + 1;
+			if (isdigit(*p)) {
+			    x_final = atoi (p);
+			    if (x_final < x_index) {
+				printMode = INTERNAL;
+				fprintf(stderr,
+				    "ccomps: final index %d < start index %d in -X%s flag - ignored\n",
+				    x_final, x_index, optarg);
+			    }
+			}
+			else if (*p) {
+			    printMode = INTERNAL;
+			    fprintf(stderr,
+				"ccomps: number expected in -X%s flag - ignored\n",
+				optarg);
+			}
+		    }
+		    else
+			x_final = x_index;
 		} else
 		    fprintf(stderr,
 			    "ccomps: number expected in -X%s flag - ignored\n",
@@ -188,6 +216,7 @@ static void init(int argc, char *argv[])
 	if ((printMode == EXTRACT) && (x_index >= 0)) {
 	    printMode = INTERNAL;
 	    sortIndex = x_index;
+	    sortFinal = x_final;
 	}
 	else if (printMode == EXTERNAL) {
 	    sortIndex = -1;
@@ -200,19 +229,90 @@ static void init(int argc, char *argv[])
 	Files = argv;
 }
 
-static int dfs(Agraph_t * g, Agnode_t * n, Agraph_t * out, int cnt)
+typedef struct blk_t {
+    Agnode_t **data;
+    Agnode_t **endp;
+    struct blk_t *prev;
+    struct blk_t *next;
+} blk_t;
+
+typedef struct {
+    blk_t *fstblk;
+    blk_t *curblk;
+    Agnode_t **curp;
+} stk_t;
+
+
+#define SMALLBUF 1024
+#define BIGBUF 1000000
+
+static Agnode_t *base[SMALLBUF];
+static blk_t Blk;
+static stk_t Stk;
+
+static void initStk()
+{
+    Blk.data = base;
+    Blk.endp = Blk.data + SMALLBUF;
+    Stk.curblk = Stk.fstblk = &Blk;
+    Stk.curp = Stk.curblk->data;
+}
+
+static void push(Agnode_t * np)
+{
+    if (Stk.curp == Stk.curblk->endp) {
+	if (Stk.curblk->next == NULL) {
+	    blk_t *bp = NEW(blk_t);
+	    if (bp == 0) {
+		fprintf(stderr, "gc: Out of memory\n");
+		exit(1);
+	    }
+	    bp->prev = Stk.curblk;
+	    bp->next = NULL;
+	    bp->data = N_NEW(BIGBUF, Agnode_t *);
+	    if (bp->data == 0) {
+		fprintf(stderr, "%s: Out of memory\n", Cmd);
+		exit(1);
+	    }
+	    bp->endp = bp->data + BIGBUF;
+	    Stk.curblk->next = bp;
+	}
+	Stk.curblk = Stk.curblk->next;
+	Stk.curp = Stk.curblk->data;
+    }
+    ND_mark(np) = -1;
+    *Stk.curp++ = np;
+}
+
+static Agnode_t *pop()
+{
+    if (Stk.curp == Stk.curblk->data) {
+	if (Stk.curblk == Stk.fstblk)
+	    return 0;
+	Stk.curblk = Stk.curblk->prev;
+	Stk.curp = Stk.curblk->endp;
+    }
+    Stk.curp--;
+    return *Stk.curp;
+}
+
+static int dfs(Agraph_t * g, Agnode_t * n, Agraph_t * out)
 {
     Agedge_t *e;
     Agnode_t *other;
+    int cnt = 0;
 
-    ND_mark(n) = 1;
-    cnt++;
-    agsubnode(out, n, 1);
-    for (e = agfstedge(g, n); e; e = agnxtedge(g, e, n)) {
-	if ((other = agtail(e)) == n)
-	    other = aghead(e);
-	if (ND_mark(other) == 0)
-	    cnt = dfs(g, other, out, cnt);
+    push(n);
+    while ((n = pop())) {
+	ND_mark(n) = 1;
+	cnt++;
+	agsubnode(out, n, 1);
+	for (e = agfstedge(g, n); e; e = agnxtedge(g, e, n)) {
+	    if ((other = agtail(e)) == n)
+		other = aghead(e);
+	    if (ND_mark(other) == 0)
+		push (other);
+	}
     }
     return cnt;
 }
@@ -324,7 +424,7 @@ static Agraph_t *projectG(Agraph_t * subg, Agraph_t * g, int inCluster)
 	proj = agsubg(g, agnameof(subg), 1);
     }
     if (proj) {
-	nodeInduce(proj, subg);
+	if (doEdges) nodeInduce(proj, subg);
 	agcopyattr(subg, proj);
     }
 
@@ -466,7 +566,7 @@ printSorted (Agraph_t* root, int c_cnt)
 {
     Agraph_t** ccs = N_NEW(c_cnt, Agraph_t*);
     Agraph_t* subg;
-    int i = 0;
+    int i = 0, endi;
 
     for (subg = agfstsubg(root); subg; subg = agnxtsubg(subg)) {
 	if (GD_cc_subg(subg))
@@ -482,10 +582,16 @@ printSorted (Agraph_t* root, int c_cnt)
 		sortIndex, agnameof(root));
 	    return;
 	}
-	subg = ccs[sortIndex];
-	if (doAll)
-	    subGInduce(root, subg);
-	gwrite(subg);
+	if (sortFinal >= sortIndex)
+	    endi = sortFinal;
+	else
+	    endi = c_cnt-1;
+        for (i = sortIndex; i <= endi ; i++) {
+	    subg = ccs[i];
+	    if (doAll)
+		subGInduce(root, subg);
+	    gwrite(subg);
+	}
     }
     else for (i = 0; i < c_cnt; i++) {
 	subg = ccs[i];
@@ -499,7 +605,7 @@ printSorted (Agraph_t* root, int c_cnt)
 /* processClusters:
  * Return 0 if graph is connected.
  */
-static int processClusters(Agraph_t * g)
+static int processClusters(Agraph_t * g, char* graphName)
 {
     Agraph_t *dg;
     long n_cnt, c_cnt, e_cnt;
@@ -508,6 +614,7 @@ static int processClusters(Agraph_t * g)
     Agnode_t *n;
     Agraph_t *dout;
     Agnode_t *dn;
+    int extracted = 0;
 
     dg = deriveGraph(g);
 
@@ -518,16 +625,19 @@ static int processClusters(Agraph_t * g)
 		    x_node, agnameof(g));
 	    return 1;
 	}
-	name = getBuf(sizeof(PFX1) + strlen(agnameof(g)));
-	sprintf(name, PFX1, agnameof(g));
+	name = getBuf(sizeof(PFX1) + strlen(graphName));
+	sprintf(name, PFX1, graphName);
 	dout = agsubg(dg, name, 1);
 	out = agsubg(g, name, 1);
 	aginit(out, AGRAPH, "graphinfo", sizeof(Agraphinfo_t), TRUE);
 	GD_cc_subg(out) = 1;
 	dn = ND_dn(n);
-	n_cnt = dfs(dg, dn, dout, 0);
+	n_cnt = dfs(dg, dn, dout);
 	unionNodes(dout, out);
-	e_cnt = nodeInduce(out, out->root);
+	if (doEdges)
+	    e_cnt = nodeInduce(out, out->root);
+	else
+	    e_cnt = 0;
 	if (doAll)
 	    subGInduce(g, out);
 	gwrite(out);
@@ -540,25 +650,30 @@ static int processClusters(Agraph_t * g)
     for (dn = agfstnode(dg); dn; dn = agnxtnode(dg, dn)) {
 	if (ND_mark(dn))
 	    continue;
-	name = getBuf(sizeof(PFX2) + strlen(agnameof(g)) + 32);
-	sprintf(name, "%s_component_%ld", agnameof(g), c_cnt);
+	name = getBuf(sizeof(PFX2) + strlen(graphName) + 32);
+	sprintf(name, PFX2, graphName, c_cnt);
 	dout = agsubg(dg, name, 1);
 	out = agsubg(g, name, 1);
 	aginit(out, AGRAPH, "graphinfo", sizeof(Agraphinfo_t), TRUE);
 	GD_cc_subg(out) = 1;
-	n_cnt = dfs(dg, dn, dout, 0);
+	n_cnt = dfs(dg, dn, dout);
 	unionNodes(dout, out);
-	e_cnt = nodeInduce(out, out->root);
+	if (doEdges)
+	    e_cnt = nodeInduce(out, out->root);
+	else
+	    e_cnt = 0;
 	if (printMode == EXTERNAL) {
 	    if (doAll)
 		subGInduce(g, out);
 	    gwrite(out);
 	} else if (printMode == EXTRACT) {
-	    if (x_index == c_cnt) {
+	    if (x_index <= c_cnt) {
+		extracted = 1;
 		if (doAll)
 		    subGInduce(g, out);
 		gwrite(out);
-		return 0;
+		if (c_cnt == x_final)
+		    return 0;
 	    }
 	}
 	if (printMode != INTERNAL)
@@ -569,7 +684,7 @@ static int processClusters(Agraph_t * g)
 		    c_cnt, n_cnt, e_cnt);
 	c_cnt++;
     }
-    if (printMode == EXTRACT) {
+    if ((printMode == EXTRACT) && !extracted)  {
 	fprintf(stderr,
 		"ccomps: component %d not found in graph %s - ignored\n",
 		x_index, agnameof(g));
@@ -604,18 +719,20 @@ bindGraphinfo (Agraph_t * g)
 /* process:
  * Return 0 if graph is connected.
  */
-static int process(Agraph_t * g)
+static int process(Agraph_t * g, char* graphName)
 {
     long n_cnt, c_cnt, e_cnt;
     char *name;
     Agraph_t *out;
     Agnode_t *n;
+    int extracted = 0;
 
     aginit(g, AGNODE, "nodeinfo", sizeof(Agnodeinfo_t), TRUE);
     bindGraphinfo (g);
+    initStk();
 
     if (useClusters)
-	return processClusters(g);
+	return processClusters(g, graphName);
 
     if (x_node) {
 	n = agfindnode(g, x_node);
@@ -625,13 +742,16 @@ static int process(Agraph_t * g)
 		    x_node, agnameof(g));
 	    return 1;
 	}
-	name = getBuf(sizeof(PFX1) + strlen(agnameof(g)));
-	sprintf(name, PFX1, agnameof(g));
+	name = getBuf(sizeof(PFX1) + strlen(graphName));
+	sprintf(name, PFX1, graphName);
 	out = agsubg(g, name, 1);
 	aginit(out, AGRAPH, "graphinfo", sizeof(Agraphinfo_t), TRUE);
 	GD_cc_subg(out) = 1;
-	n_cnt = dfs(g, n, out, 0);
-	e_cnt = nodeInduce(out, out->root);
+	n_cnt = dfs(g, n, out);
+	if (doEdges)
+	    e_cnt = nodeInduce(out, out->root);
+	else
+	    e_cnt = 0;
 	if (doAll)
 	    subGInduce(g, out);
 	gwrite(out);
@@ -644,23 +764,28 @@ static int process(Agraph_t * g)
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	if (ND_mark(n))
 	    continue;
-	name = getBuf(sizeof(PFX2) + strlen(agnameof(g)) + 32);
-	sprintf(name, "%s_component_%ld", agnameof(g), c_cnt);
+	name = getBuf(sizeof(PFX2) + strlen(graphName) + 32);
+	sprintf(name, PFX2, graphName, c_cnt);
 	out = agsubg(g, name, 1);
 	aginit(out, AGRAPH, "graphinfo", sizeof(Agraphinfo_t), TRUE);
 	GD_cc_subg(out) = 1;
-	n_cnt = dfs(g, n, out, 0);
-	e_cnt = nodeInduce(out, out->root);
+	n_cnt = dfs(g, n, out);
+	if (doEdges)
+	    e_cnt = nodeInduce(out, out->root);
+	else
+	    e_cnt = 0;
 	if (printMode == EXTERNAL) {
 	    if (doAll)
 		subGInduce(g, out);
 	    gwrite(out);
 	} else if (printMode == EXTRACT) {
-	    if (x_index == c_cnt) {
+	    if (x_index <= c_cnt) {
+		extracted = 1;
 		if (doAll)
 		    subGInduce(g, out);
 		gwrite(out);
-		return 0;
+		if (c_cnt == x_final)
+		    return 0;
 	    }
 	}
 	if (printMode != INTERNAL)
@@ -670,7 +795,7 @@ static int process(Agraph_t * g)
 		    c_cnt, n_cnt, e_cnt);
 	c_cnt++;
     }
-    if (printMode == EXTRACT) {
+    if ((printMode == EXTRACT) && !extracted) {
 	fprintf(stderr,
 		"ccomps: component %d not found in graph %s - ignored\n",
 		x_index, agnameof(g));
@@ -693,6 +818,37 @@ static Agraph_t *gread(FILE * fp)
     return agread(fp, (Agdisc_t *) 0);
 }
 
+/* chkGraphName:
+ * If the graph is anonymous, its name starts with '%'.
+ * If we use this as the prefix for subgraphs, they will not be
+ * emitted in agwrite() because cgraph assumes these were anonymous
+ * structural subgraphs all of whose properties are attached directly
+ * to the nodes and edges involved.
+ *
+ * This function checks for an initial '%' and if found, prepends '_'
+ * the the graph name.
+ * NB: static buffer is used.
+ */
+static char*
+chkGraphName (Agraph_t* g)
+{
+    static char* buf = NULL;
+    static int buflen = 0;
+    char* s = agnameof(g);
+    int len;
+
+    if (*s != '%') return s;
+    len = strlen(s) + 2;   /* plus '\0' and '_' */
+    if (len > buflen) {
+	buf = realloc (buf, len);
+	buflen = len;
+    }
+    buf[0] = '_';
+    strcpy (buf+1, s);
+
+    return buf;
+}
+
 int main(int argc, char *argv[])
 {
     Agraph_t *g;
@@ -702,7 +858,7 @@ int main(int argc, char *argv[])
     newIngraph(&ig, Files, gread);
 
     while ((g = nextGraph(&ig)) != 0) {
-	r += process(g);
+	r += process(g, chkGraphName(g));
 	agclose(g);
     }
 
