@@ -1,18 +1,22 @@
-/* $Id: dijkstra.c,v 1.12 2010/01/08 21:28:39 erg Exp $ $Revision: 1.12 $ */
+/* $Id: dijkstra.c,v 1.15 2011/04/18 21:32:17 erg Exp $ $Revision: 1.15 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
+
+#ifdef WIN32 /*dependencies*/
+    #pragma comment( lib, "cgraph.lib" )
+    #pragma comment( lib, "ingraphs.lib" )
+    #pragma comment( lib, "cdt.lib" )
+
+#endif
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -229,7 +233,7 @@ void dijkstra(Dict_t * Q, Agraph_t * G, Agnode_t * n)
 }
 
 static char *useString =
-    "Usage: dijkstra [-a?] <node> [<file> <node> <file>]\n\
+    "Usage: dijkstra [-ap?] <node> [<file> <node> <file>]\n\
   -a - for nodes in a different component, set dist very large\n\
   -p - attach shortest path info\n\
   -? - print usage\n\
