@@ -1,9 +1,13 @@
-/* $Id: gml2gv.h,v 1.1 2009/07/08 21:00:58 erg Exp $Revision: */
+/* $Id: gml2gv.h,v 1.3 2011/04/18 21:52:48 erg Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
 #include <stdio.h>
 #include <cgraph.h>
 
+#ifdef WIN32
+#define strdup(x) _strdup(x)
+#endif
+
 typedef struct {
     Dtlink_t link;
     unsigned short kind;
@@ -43,4 +47,4 @@ extern void gmllexeof(void);
 extern void gmlerror(char *);
 extern int gmlerrors(void);
 extern void initgmlscan (FILE*);
-extern Agraph_t* gml_to_gv (FILE*, int, int*);
+extern Agraph_t* gml_to_gv (char*, FILE*, int, int*);
