@@ -1,23 +1,25 @@
-/* $Id: gvgen.c,v 1.7 2010/01/08 21:28:39 erg Exp $Revision: */
+/* $Id: gvgen.c,v 1.10 2011/02/10 02:43:41 erg Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 /*
  * Written by Emden Gansner
  */
 
+#ifdef WIN32 /*dependencies*/
+    #pragma comment( lib, "cgraph.lib" )
+    #pragma comment( lib, "ingraphs.lib" )
+#endif
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -49,6 +51,8 @@ typedef struct {
     int foldVal;
     int directed;
     FILE *outfile;
+    char* pfx;
+    char* name;
 } opts_t;
 
 static char *cmd;
@@ -79,6 +83,8 @@ static char *Usage = "Usage: %s [-dV?] [options]\n\
  -h<x>         : hypercube \n\
  -k<x>         : complete \n\
  -b<x,y>       : complete bipartite\n\
+ -n<prefix>    : use <prefix> in node names (\"\")\n\
+ -N<name>      : use <name> for the graph (\"\")\n\
  -o<outfile>   : put output in <outfile> (stdout)\n\
  -p<x>         : path \n\
  -s<x>         : star\n\
@@ -175,7 +181,7 @@ static char* setFold(char *s, opts_t* opts)
     return next;
 }
 
-static char *optList = ":c:C:dg:G:h:k:b:o:p:s:S:t:T:Vw:";
+static char *optList = ":n:N:c:C:dg:G:h:k:b:o:p:s:S:t:T:Vw:";
 
 static GraphType init(int argc, char *argv[], opts_t* opts)
 {
@@ -222,6 +228,12 @@ static GraphType init(int argc, char *argv[], opts_t* opts)
 	    if (setTwo(optarg, opts))
 		errexit(c);
 	    break;
+	case 'n':
+	    opts->pfx = optarg;
+	    break;
+	case 'N':
+	    opts->name = optarg;
+	    break;
 	case 'o':
 	    opts->outfile = openFile(optarg, "w");
 	    break;
@@ -285,24 +297,27 @@ static opts_t opts;
 static void dirfn (int t, int h)
 {
     if (h > 0)
-	fprintf (opts.outfile, "  %d -> %d\n", t, h);
+	fprintf (opts.outfile, "  %s%d -> %s%d\n", opts.pfx, t, opts.pfx, h);
     else
-	fprintf (opts.outfile, "  %d\n", t);
+	fprintf (opts.outfile, "  %s%d\n", opts.pfx, t);
 }
 
 static void undirfn (int t, int h)
 {
     if (h > 0)
-	fprintf (opts.outfile, "  %d -- %d\n", t, h);
+	fprintf (opts.outfile, "  %s%d -- %s%d\n", opts.pfx, t, opts.pfx, h);
     else
-	fprintf (opts.outfile, "  %d\n", t);
+	fprintf (opts.outfile, "  %s%d\n", opts.pfx, t);
 }
 
 int main(int argc, char *argv[])
 {
-    GraphType graphType = init(argc, argv, &opts);
+    GraphType graphType;
     edgefn ef;
 
+    opts.pfx = "";
+    opts.name = "";
+    graphType = init(argc, argv, &opts);
     if (opts.directed) {
 	fprintf(opts.outfile, "digraph {\n");
 	ef = dirfn;
