@@ -1,24 +1,23 @@
-/* $Id: gvpack.c,v 1.35 2010/01/08 21:28:39 erg Exp $ $Revision: 1.35 $ */
+/* $Id: gvpack.c,v 1.41 2011/01/25 16:30:47 ellson Exp $ $Revision: 1.41 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 /*
  * Written by Emden R. Gansner
  */
 
+
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -40,6 +39,28 @@
 extern Agdict_t *agdictof(void *);
 #endif
 
+
+#ifdef WIN32 /*dependencies*/
+#ifdef WITH_CGRAPH
+    #pragma comment( lib, "cgraph.lib" )
+#else
+    #pragma comment( lib, "graph.lib" )
+#endif
+    #pragma comment( lib, "gvc.lib" )
+    #pragma comment( lib, "ingraphs.lib" )
+    #pragma comment( lib, "neatogen.lib" )
+    #pragma comment( lib, "pathplan.lib" )
+    #pragma comment( lib, "vpsc.lib" )
+    #pragma comment( lib, "sparse.lib" )
+    #pragma comment( lib, "gts.lib" )
+    #pragma comment( lib, "glib-2.0.lib" )
+    #pragma comment( lib, "cdt.lib" )
+    #pragma comment( lib, "gvplugin_neato_layout.lib" )
+
+
+#endif
+
+
 /* gvpack:
  * Input consists of graphs in dot format.
  * The graphs should have pos, width and height set for nodes, 
@@ -300,8 +321,17 @@ static void init_graph(Agraph_t * g, boolean fill, GVC_t* gvc)
     }
     Ndim = GD_ndim(g) = 2;
     init_node_edge(g);
-    if (fill && init_nop(g, 0)) {
-	exit(1);
+    if (fill) {
+	int ret = init_nop(g,0);
+	if (ret) {
+	    if (ret < 0)
+		fprintf(stderr, "Error loading layout info from graph %s\n",
+		    agnameof(g));
+	    else if (ret > 0)
+		fprintf(stderr, "gvpack does not support backgrounds as found in graph %s\n",
+		    agnameof(g));
+	    exit(1);
+	}
     }
 }
 
