@@ -1,18 +1,15 @@
-/* $Id: gxl2gv.c,v 1.7 2009/06/03 01:56:55 ellson Exp $ $Revision: 1.7 $ */
+/* $Id: gxl2gv.c,v 1.9 2011/01/25 16:30:47 ellson Exp $ $Revision: 1.9 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 #include    "convert.h"
@@ -21,6 +18,15 @@
 #include    <expat.h>
 #include    <ctype.h>
 
+#ifdef WIN32 //*dependencies
+    #pragma comment( lib, "cgraph.lib" )
+    #pragma comment( lib, "cdt.lib" )
+    #pragma comment( lib, "ingraphs.lib" )
+    #pragma comment( lib, "gvc.lib" )
+    #pragma comment( lib, "expat.lib" )
+#endif
+
+
 #ifndef XML_STATUS_ERROR
 #define XML_STATUS_ERROR 0
 #endif
