@@ -1,27 +1,26 @@
-/* $Id: mm2gv.c,v 1.10 2010/01/13 19:37:22 erg Exp $Revision:  */
+/* $Id: mm2gv.c,v 1.16 2011/02/28 16:10:06 erg Exp $Revision:  */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#define STANDALONE
 #include "cgraph.h"
-#include "arith.h"
+/* #include "arith.h" */
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <math.h>
 #include <assert.h>
 #include "mmio.h"
@@ -38,10 +37,15 @@
 #define FREE free
 #define test_flag(a, flag) ((a)&(flag))
 #define real double
-#define NEW(t)       (t*)MALLOC(sizeof(t))
-#define N_NEW(n,t)   (t*)MALLOC((n)*sizeof(t))
 #define BUFS         1024
 
+#ifdef WIN32 //*dependencies
+    #pragma comment( lib, "cgraph.lib" )
+    #pragma comment( lib, "ingraphs.lib" )
+    #pragma comment( lib, "gvc.lib" )
+    #pragma comment( lib, "sparse.lib" )
+#endif
+
 
 typedef struct {
     Agrec_t h;
@@ -52,18 +56,6 @@ typedef struct {
 
 static char *cmd;
 
-static real distance(real * x, int dim, int i, int j)
-{
-    int k;
-    real dist = 0.;
-    for (k = 0; k < dim; k++)
-	dist +=
-	    (x[i * dim + k] - x[j * dim + k]) * (x[i * dim + k] -
-						 x[j * dim + k]);
-    dist = sqrt(dist);
-    return dist;
-}
-
 static real Hue2RGB(real v1, real v2, real H)
 {
     if (H < 0.0)
@@ -239,20 +231,6 @@ SparseMatrix_import_dot(Agraph_t * g, int dim, real ** label_sizes,
 }
 #endif
 
-static char *strip_dir(char *s)
-{
-    int i, first = TRUE;
-    for (i = strlen(s); i >= 0; i--) {
-	if (first && s[i] == '.') {	/* get rid of .mtx */
-	    s[i] = '\0';
-	    first = FALSE;
-	}
-	if (s[i] == '/')
-	    return (char *) &(s[i + 1]);
-    }
-    return s;
-}
-
 static Agraph_t *makeDotGraph(SparseMatrix A, char *name, int dim,
 			      real * x, int with_color, int with_label, int with_val)
 {
@@ -469,7 +447,7 @@ int main(int argc, char *argv[])
 {
     Agraph_t *g = 0;
     SparseMatrix A = NULL;
-    int dim;
+    int dim=0;
     parms_t pv;
 
     /* ======================= set parameters ==================== */
@@ -486,10 +464,11 @@ int main(int argc, char *argv[])
 
     A = SparseMatrix_import_matrix_market(pv.inf, FORMAT_CSR);
     if (!A) {
+	fprintf (stderr, "Unable to read input file \"%s\"\n", pv.infile); 
 	usage(1);
     }
 
-    A = SparseMatrix_to_square_matrix(A);
+    A = SparseMatrix_to_square_matrix(A, BIPARTITE_PATTERN_UNSYM);
 
     if (!A) {
 	fprintf(stderr, "cannot import from file %s\n", pv.infile);
