@@ -1,18 +1,15 @@
-/* $Id: tred.c,v 1.12 2010/01/08 21:28:39 erg Exp $ $Revision: 1.12 $ */
+/* $Id: tred.c,v 1.14 2011/01/25 16:30:47 ellson Exp $ $Revision: 1.14 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 /*
@@ -54,6 +51,11 @@ char **Files;
 char *CmdName;
 #define MARK(n)  (((Agnodeinfo_t*)(n->base.data))->mark)
 
+#ifdef WIN32 //*dependencies
+    #pragma comment( lib, "cgraph.lib" )
+    #pragma comment( lib, "ingraphs.lib" )
+#endif
+
 static int dfs(Agnode_t * n, Agedge_t * link, int warn)
 {
     Agedge_t *e;
