@@ -68,10 +68,11 @@
 /* Copy the first part of user declarations.  */
 
 /* Line 189 of yacc.c  */
-#line 17 "../../cmd/tools/gmlparse.y"
+#line 14 "../../cmd/tools/gmlparse.y"
 
 #include <stdlib.h>
 #include <stddef.h>
+#include <string.h>
 #include <arith.h>
 #include <gml2gv.h>
 #include <agxbuf.h>
@@ -331,7 +332,7 @@ setDir (char* d)
 
 
 /* Line 189 of yacc.c  */
-#line 335 "y.tab.c"
+#line 336 "y.tab.c"
 
 /* Enabling traces.  */
 #ifndef YYDEBUG
@@ -434,7 +435,7 @@ typedef union YYSTYPE
 {
 
 /* Line 214 of yacc.c  */
-#line 277 "../../cmd/tools/gmlparse.y"
+#line 275 "../../cmd/tools/gmlparse.y"
 
     int i;
     char *str;
@@ -446,7 +447,7 @@ typedef union YYSTYPE
 
 
 /* Line 214 of yacc.c  */
-#line 450 "y.tab.c"
+#line 451 "y.tab.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -458,7 +459,7 @@ typedef union YYSTYPE
 
 
 /* Line 264 of yacc.c  */
-#line 462 "y.tab.c"
+#line 463 "y.tab.c"
 
 #ifdef short
 # undef short
@@ -764,13 +765,13 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   300,   300,   301,   302,   305,   308,   311,   312,   315,
-     316,   319,   320,   321,   322,   329,   330,   333,   333,   336,
-     337,   340,   341,   344,   344,   347,   348,   351,   352,   353,
-     356,   356,   359,   360,   363,   364,   367,   368,   369,   370,
-     371,   372,   373,   374,   375,   376,   377,   378,   379,   380,
-     381,   382,   383,   384,   385,   386,   387,   388,   389,   390,
-     391
+       0,   298,   298,   299,   300,   303,   306,   309,   310,   313,
+     314,   317,   318,   319,   320,   327,   328,   331,   331,   334,
+     335,   338,   339,   342,   342,   345,   346,   349,   350,   351,
+     354,   354,   357,   358,   361,   362,   365,   366,   367,   368,
+     369,   370,   371,   372,   373,   374,   375,   376,   377,   378,
+     379,   380,   381,   382,   383,   384,   385,   386,   387,   388,
+     389
 };
 #endif
 
@@ -1760,42 +1761,42 @@ yyreduce:
         case 2:
 
 /* Line 1455 of yacc.c  */
-#line 300 "../../cmd/tools/gmlparse.y"
+#line 298 "../../cmd/tools/gmlparse.y"
     {gmllexeof(); if (G->parent) popG(); }
     break;
 
   case 3:
 
 /* Line 1455 of yacc.c  */
-#line 301 "../../cmd/tools/gmlparse.y"
+#line 299 "../../cmd/tools/gmlparse.y"
     { cleanup(); YYABORT; }
     break;
 
   case 5:
 
 /* Line 1455 of yacc.c  */
-#line 305 "../../cmd/tools/gmlparse.y"
+#line 303 "../../cmd/tools/gmlparse.y"
     { pushG(); }
     break;
 
   case 11:
 
 /* Line 1455 of yacc.c  */
-#line 319 "../../cmd/tools/gmlparse.y"
+#line 317 "../../cmd/tools/gmlparse.y"
     { dtinsert (G->nodelist, (yyvsp[(1) - (1)].np)); }
     break;
 
   case 12:
 
 /* Line 1455 of yacc.c  */
-#line 320 "../../cmd/tools/gmlparse.y"
+#line 318 "../../cmd/tools/gmlparse.y"
     { dtinsert (G->edgelist, (yyvsp[(1) - (1)].ep)); }
     break;
 
   case 14:
 
 /* Line 1455 of yacc.c  */
-#line 322 "../../cmd/tools/gmlparse.y"
+#line 320 "../../cmd/tools/gmlparse.y"
     { 
 		if (setDir((yyvsp[(2) - (2)].str))) { 
 		    yyerror("mixed directed and undirected graphs"); 
@@ -1808,287 +1809,287 @@ yyreduce:
   case 15:
 
 /* Line 1455 of yacc.c  */
-#line 329 "../../cmd/tools/gmlparse.y"
+#line 327 "../../cmd/tools/gmlparse.y"
     {/* FIX */}
     break;
 
   case 16:
 
 /* Line 1455 of yacc.c  */
-#line 330 "../../cmd/tools/gmlparse.y"
+#line 328 "../../cmd/tools/gmlparse.y"
     { dtinsert (G->attrlist, (yyvsp[(1) - (1)].ap)); }
     break;
 
   case 17:
 
 /* Line 1455 of yacc.c  */
-#line 333 "../../cmd/tools/gmlparse.y"
+#line 331 "../../cmd/tools/gmlparse.y"
     { N = mkNode(); }
     break;
 
   case 18:
 
 /* Line 1455 of yacc.c  */
-#line 333 "../../cmd/tools/gmlparse.y"
+#line 331 "../../cmd/tools/gmlparse.y"
     { (yyval.np) = N; N = NULL; }
     break;
 
   case 21:
 
 /* Line 1455 of yacc.c  */
-#line 340 "../../cmd/tools/gmlparse.y"
+#line 338 "../../cmd/tools/gmlparse.y"
     { N->id = (yyvsp[(2) - (2)].str); }
     break;
 
   case 22:
 
 /* Line 1455 of yacc.c  */
-#line 341 "../../cmd/tools/gmlparse.y"
+#line 339 "../../cmd/tools/gmlparse.y"
     { dtinsert (N->attrlist, (yyvsp[(1) - (1)].ap)); }
     break;
 
   case 23:
 
 /* Line 1455 of yacc.c  */
-#line 344 "../../cmd/tools/gmlparse.y"
+#line 342 "../../cmd/tools/gmlparse.y"
     { E = mkEdge(); }
     break;
 
   case 24:
 
 /* Line 1455 of yacc.c  */
-#line 344 "../../cmd/tools/gmlparse.y"
+#line 342 "../../cmd/tools/gmlparse.y"
     { (yyval.ep) = E; E = NULL; }
     break;
 
   case 27:
 
 /* Line 1455 of yacc.c  */
-#line 351 "../../cmd/tools/gmlparse.y"
+#line 349 "../../cmd/tools/gmlparse.y"
     { E->source = (yyvsp[(2) - (2)].str); }
     break;
 
   case 28:
 
 /* Line 1455 of yacc.c  */
-#line 352 "../../cmd/tools/gmlparse.y"
+#line 350 "../../cmd/tools/gmlparse.y"
     { E->target = (yyvsp[(2) - (2)].str); }
     break;
 
   case 29:
 
 /* Line 1455 of yacc.c  */
-#line 353 "../../cmd/tools/gmlparse.y"
+#line 351 "../../cmd/tools/gmlparse.y"
     { dtinsert (E->attrlist, (yyvsp[(1) - (1)].ap)); }
     break;
 
   case 30:
 
 /* Line 1455 of yacc.c  */
-#line 356 "../../cmd/tools/gmlparse.y"
+#line 354 "../../cmd/tools/gmlparse.y"
     {pushAlist(); }
     break;
 
   case 31:
 
 /* Line 1455 of yacc.c  */
-#line 356 "../../cmd/tools/gmlparse.y"
+#line 354 "../../cmd/tools/gmlparse.y"
     { (yyval.list) = popAlist(); }
     break;
 
   case 34:
 
 /* Line 1455 of yacc.c  */
-#line 363 "../../cmd/tools/gmlparse.y"
+#line 361 "../../cmd/tools/gmlparse.y"
     { dtinsert (L, (yyvsp[(2) - (2)].ap)); }
     break;
 
   case 35:
 
 /* Line 1455 of yacc.c  */
-#line 364 "../../cmd/tools/gmlparse.y"
+#line 362 "../../cmd/tools/gmlparse.y"
     { dtinsert (L, (yyvsp[(1) - (1)].ap)); }
     break;
 
   case 36:
 
 /* Line 1455 of yacc.c  */
-#line 367 "../../cmd/tools/gmlparse.y"
+#line 365 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr ((yyvsp[(1) - (2)].str), 0, INTEGER, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 37:
 
 /* Line 1455 of yacc.c  */
-#line 368 "../../cmd/tools/gmlparse.y"
+#line 366 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr ((yyvsp[(1) - (2)].str), 0, REAL, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 38:
 
 /* Line 1455 of yacc.c  */
-#line 369 "../../cmd/tools/gmlparse.y"
+#line 367 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr ((yyvsp[(1) - (2)].str), 0, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 39:
 
 /* Line 1455 of yacc.c  */
-#line 370 "../../cmd/tools/gmlparse.y"
+#line 368 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr ((yyvsp[(1) - (2)].str), 0, LIST, 0, (yyvsp[(2) - (2)].list)); }
     break;
 
   case 40:
 
 /* Line 1455 of yacc.c  */
-#line 371 "../../cmd/tools/gmlparse.y"
+#line 369 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, XVAL, REAL, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 41:
 
 /* Line 1455 of yacc.c  */
-#line 372 "../../cmd/tools/gmlparse.y"
+#line 370 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, YVAL, REAL, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 42:
 
 /* Line 1455 of yacc.c  */
-#line 373 "../../cmd/tools/gmlparse.y"
+#line 371 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, WVAL, REAL, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 43:
 
 /* Line 1455 of yacc.c  */
-#line 374 "../../cmd/tools/gmlparse.y"
+#line 372 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, HVAL, REAL, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 44:
 
 /* Line 1455 of yacc.c  */
-#line 375 "../../cmd/tools/gmlparse.y"
+#line 373 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, LABEL, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 45:
 
 /* Line 1455 of yacc.c  */
-#line 376 "../../cmd/tools/gmlparse.y"
+#line 374 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, GRAPHICS, LIST, 0, (yyvsp[(2) - (2)].list)); }
     break;
 
   case 46:
 
 /* Line 1455 of yacc.c  */
-#line 377 "../../cmd/tools/gmlparse.y"
+#line 375 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, LABELGRAPHICS, LIST, 0, (yyvsp[(2) - (2)].list)); }
     break;
 
   case 47:
 
 /* Line 1455 of yacc.c  */
-#line 378 "../../cmd/tools/gmlparse.y"
+#line 376 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, TYPE, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 48:
 
 /* Line 1455 of yacc.c  */
-#line 379 "../../cmd/tools/gmlparse.y"
+#line 377 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, FILL, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 49:
 
 /* Line 1455 of yacc.c  */
-#line 380 "../../cmd/tools/gmlparse.y"
+#line 378 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, OUTLINE, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 50:
 
 /* Line 1455 of yacc.c  */
-#line 381 "../../cmd/tools/gmlparse.y"
+#line 379 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, OUTLINESTYLE, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 51:
 
 /* Line 1455 of yacc.c  */
-#line 382 "../../cmd/tools/gmlparse.y"
+#line 380 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, OUTLINEWIDTH, INTEGER, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 52:
 
 /* Line 1455 of yacc.c  */
-#line 383 "../../cmd/tools/gmlparse.y"
+#line 381 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, OUTLINEWIDTH, INTEGER, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 53:
 
 /* Line 1455 of yacc.c  */
-#line 384 "../../cmd/tools/gmlparse.y"
+#line 382 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, STYLE, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 54:
 
 /* Line 1455 of yacc.c  */
-#line 385 "../../cmd/tools/gmlparse.y"
+#line 383 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, STYLE, LIST, 0, (yyvsp[(2) - (2)].list)); }
     break;
 
   case 55:
 
 /* Line 1455 of yacc.c  */
-#line 386 "../../cmd/tools/gmlparse.y"
+#line 384 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, LINE, LIST, 0, (yyvsp[(2) - (2)].list)); }
     break;
 
   case 56:
 
 /* Line 1455 of yacc.c  */
-#line 387 "../../cmd/tools/gmlparse.y"
+#line 385 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, POINT, LIST, 0, (yyvsp[(2) - (2)].list)); }
     break;
 
   case 57:
 
 /* Line 1455 of yacc.c  */
-#line 388 "../../cmd/tools/gmlparse.y"
+#line 386 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, TEXT, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 58:
 
 /* Line 1455 of yacc.c  */
-#line 389 "../../cmd/tools/gmlparse.y"
+#line 387 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, FONTNAME, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 59:
 
 /* Line 1455 of yacc.c  */
-#line 390 "../../cmd/tools/gmlparse.y"
+#line 388 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, FONTNAME, INTEGER, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 60:
 
 /* Line 1455 of yacc.c  */
-#line 391 "../../cmd/tools/gmlparse.y"
+#line 389 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, COLOR, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
 
 
 /* Line 1455 of yacc.c  */
-#line 2092 "y.tab.c"
+#line 2093 "y.tab.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2300,7 +2301,7 @@ yyreturn:
 
 
 /* Line 1675 of yacc.c  */
-#line 394 "../../cmd/tools/gmlparse.y"
+#line 392 "../../cmd/tools/gmlparse.y"
 
 
 static void
@@ -2641,7 +2642,7 @@ addAttrs (Agobj_t* obj, Dt_t* alist, agxbuf* xb, agxbuf* unk)
 }
 
 static Agraph_t*
-mkGraph (gmlgraph* G, Agraph_t* parent, agxbuf* xb, agxbuf* unk)
+mkGraph (gmlgraph* G, Agraph_t* parent, char* name, agxbuf* xb, agxbuf* unk)
 {
     Agraph_t* g;
     Agnode_t* n;
@@ -2655,9 +2656,9 @@ mkGraph (gmlgraph* G, Agraph_t* parent, agxbuf* xb, agxbuf* unk)
 	g = agsubg (parent, NULL, 1);
     }
     else if (G->directed >= 1)
-	g = agopen ("", Agdirected, 0);
+	g = agopen (name, Agdirected, 0);
     else
-	g = agopen ("", Agundirected, 0);
+	g = agopen (name, Agundirected, 0);
 
     if (!parent && L) {
 	addAttrs ((Agobj_t*)g, L, xb, unk);
@@ -2686,7 +2687,7 @@ mkGraph (gmlgraph* G, Agraph_t* parent, agxbuf* xb, agxbuf* unk)
 	addAttrs ((Agobj_t*)e, ep->attrlist, xb, unk);
     }
     for (gp = dtfirst(G->graphlist); gp; gp = dtnext (G->graphlist, gp)) {
-	mkGraph (gp, g, xb, unk);
+	mkGraph (gp, g, NULL, xb, unk);
     }
 
     addAttrs ((Agobj_t*)g, G->attrlist, xb, unk);
@@ -2695,7 +2696,7 @@ mkGraph (gmlgraph* G, Agraph_t* parent, agxbuf* xb, agxbuf* unk)
 }
 
 Agraph_t*
-gml_to_gv (FILE* fp, int cnt, int* errors)
+gml_to_gv (char* name, FILE* fp, int cnt, int* errors)
 {
     Agraph_t* g;
     agxbuf xb;
@@ -2721,7 +2722,7 @@ gml_to_gv (FILE* fp, int cnt, int* errors)
     else {
 	agxbinit (&xb, BUFSIZ, buf);
 	agxbinit (&unk, BUFSIZ, unknownb);
-	g = mkGraph (G, NULL, &xb, &unk);
+	g = mkGraph (G, NULL, name, &xb, &unk);
 	agxbfree (&xb);
     }
 
