@@ -1,18 +1,15 @@
-/* $Id: diffimg.c,v 1.14 2009/01/23 23:33:05 arif Exp $ $Revision: 1.14 $ */
+/* $Id: diffimg.c,v 1.18 2011/01/25 16:30:47 ellson Exp $ $Revision: 1.18 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 /*
  * This program generates an image where each pixel is the
@@ -26,6 +23,15 @@
  * John Ellson <ellson@research.att.com>
  */
 
+
+
+#ifdef WIN32 /*dependencies*/
+    #pragma comment( lib, "gd.lib" )
+    #pragma comment( lib, "png.lib" )
+    #pragma comment( lib, "gvc.lib" )
+#endif
+
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
