@@ -1,18 +1,15 @@
-/* $Id: prune.c,v 1.7 2009/12/29 18:58:23 erg Exp $ $Revision: 1.7 $ */
+/* $Id: prune.c,v 1.9 2011/01/25 16:30:47 ellson Exp $ $Revision: 1.9 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -36,6 +33,13 @@
 #include "ingraphs.h"
 #include "generic_list.h"
 
+
+#ifdef WIN32 //*dependencies
+    #pragma comment( lib, "cgraph.lib" )
+    #pragma comment( lib, "ingraphs.lib" )
+#endif
+
+
 /* structure to hold an attribute specified on the commandline */
 typedef struct strattr_s {
     char *n;
