@@ -1,18 +1,15 @@
-/* $Id: agxbuf.h,v 1.3 2009/06/03 01:10:51 ellson Exp $ $Revision: 1.3 $ */
+/* $Id: agxbuf.h,v 1.5 2011/02/26 20:02:10 erg Exp $ $Revision: 1.5 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #ifdef __cplusplus
 extern "C" {
@@ -41,12 +38,12 @@ extern "C" {
 /* agxbput_n:
  * Append string s of length n into xb
  */
-    extern int agxbput_n(agxbuf * xb, char *s, unsigned int n);
+    extern int agxbput_n(agxbuf * xb, const char *s, unsigned int n);
 
 /* agxbput:
  * Append string s into xb
  */
-    extern int agxbput(agxbuf * xb, char *s);
+    extern int agxbput(agxbuf * xb, const char *s);
 
 /* agxbfree:
  * Free any malloced resources.
