@@ -1,18 +1,15 @@
-/* $Id: cgraph.h,v 1.16 2009/07/10 21:10:32 erg Exp $ $Revision: 1.16 $ */
+/* $Id: cgraph.h,v 1.19 2011/03/03 01:09:42 erg Exp $ $Revision: 1.19 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #ifndef ATT_GRAPH_H
 #define ATT_GRAPH_H
@@ -391,13 +388,15 @@ extern void aginternalmapclearlocalnames(Agraph_t * g);
 
 /* error handling */
 typedef enum { AGWARN, AGERR, AGMAX, AGPREV } agerrlevel_t;
-extern agerrlevel_t agerrno;
-extern void agseterr(agerrlevel_t);
+typedef int (*agusererrf) (char*);
+extern agerrlevel_t agseterr(agerrlevel_t);
 extern char *aglasterr(void);
 extern int agerr(agerrlevel_t level, char *fmt, ...);
 extern void agerrorf(char *fmt, ...);
 extern void agwarningf(char *fmt, ...);
 extern int agerrors(void);
+extern int agreseterrors(void);
+extern agusererrf agseterrf(agusererrf);
 
 /* data access macros */
 /* this assumes that e[0] is out and e[1] is inedge, see edgepair in edge.c  */
