@@ -1,18 +1,15 @@
-/* $Id: edge.c,v 1.17 2009/06/03 01:10:51 ellson Exp $ $Revision: 1.17 $ */
+/* $Id: edge.c,v 1.21 2011/01/25 16:30:47 ellson Exp $ $Revision: 1.21 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include <cghdr.h>
 
@@ -31,9 +28,11 @@ Agedge_t *agfstout(Agraph_t * g, Agnode_t * n)
     Agedge_t *e = NILedge;
 
     sn = agsubrep(g, n);
-    dtrestore(g->e_seq, sn->out_seq);
-    e = (Agedge_t *) dtfirst(g->e_seq);
-    sn->out_seq = dtextract(g->e_seq);
+    if (sn) {
+		dtrestore(g->e_seq, sn->out_seq);
+		e = (Agedge_t *) dtfirst(g->e_seq);
+		sn->out_seq = dtextract(g->e_seq);
+	}
     return e;
 }
 
@@ -42,13 +41,15 @@ Agedge_t *agnxtout(Agraph_t * g, Agedge_t * e)
 {
     Agnode_t *n;
     Agsubnode_t *sn;
-    Agedge_t *f;
+    Agedge_t *f = NILedge;
 
     n = AGTAIL(e);
     sn = agsubrep(g, n);
-    dtrestore(g->e_seq, sn->out_seq);
-    f = (Agedge_t *) dtnext(g->e_seq, e);
-    sn->out_seq = dtextract(g->e_seq);
+    if (sn) {
+		dtrestore(g->e_seq, sn->out_seq);
+		f = (Agedge_t *) dtnext(g->e_seq, e);
+		sn->out_seq = dtextract(g->e_seq);
+	}
     return f;
 }
 
@@ -58,9 +59,11 @@ Agedge_t *agfstin(Agraph_t * g, Agnode_t * n)
     Agedge_t *e = NILedge;
 
     sn = agsubrep(g, n);
-    dtrestore(g->e_seq, sn->in_seq);
-    e = (Agedge_t *) dtfirst(g->e_seq);
-    sn->in_seq = dtextract(g->e_seq);
+	if (sn) {
+		dtrestore(g->e_seq, sn->in_seq);
+		e = (Agedge_t *) dtfirst(g->e_seq);
+		sn->in_seq = dtextract(g->e_seq);
+	}
     return e;
 }
 
@@ -68,14 +71,16 @@ Agedge_t *agnxtin(Agraph_t * g, Agedge_t * e)
 {
     Agnode_t *n;
     Agsubnode_t *sn;
-    Agedge_t *f;
+    Agedge_t *f = NILedge;
 
     n = AGHEAD(e);
     sn = agsubrep(g, n);
-    dtrestore(g->e_seq, sn->in_seq);
-    f = (Agedge_t *) dtnext(g->e_seq, e);
-    sn->in_seq = dtextract(g->e_seq);
-    return f;
+	if (sn) {
+		dtrestore(g->e_seq, sn->in_seq);
+		f = (Agedge_t *) dtnext(g->e_seq, e);
+		sn->in_seq = dtextract(g->e_seq);
+	}
+	return f;
 }
 
 Agedge_t *agfstedge(Agraph_t * g, Agnode_t * n)
@@ -153,8 +158,11 @@ Agsubnode_t *agsubrep(Agraph_t * g, Agnode_t * n)
 {
     Agsubnode_t *sn, template;
 
-    template.node = n;
-    sn = dtsearch(g->n_id, &template);
+	if (g == n->root) sn = &(n->mainsub);
+	else {
+			template.node = n;
+			sn = dtsearch(g->n_id, &template);
+	}
     return sn;
 }
 
@@ -167,8 +175,10 @@ static void ins(Dict_t * d, Dtlink_t ** set, Agedge_t * e)
 
 static void del(Dict_t * d, Dtlink_t ** set, Agedge_t * e)
 {
+    void *x;
     dtrestore(d, *set);
-    dtdelete(d, e);
+    x = dtdelete(d, e);
+    assert(x);
     *set = dtextract(d);
 }
 
@@ -390,41 +400,41 @@ Agedge_t *agsubedge(Agraph_t * g, Agedge_t * e, int cflag)
 /* edge comparison.  OBJTYPE(e) == 0 means ID is a wildcard. */
 int agedgeidcmpf(Dict_t * d, void *arg_e0, void *arg_e1, Dtdisc_t * disc)
 {
-    int rv;
+    long v;
     Agedge_t *e0, *e1;
 
     NOTUSED(d);
     e0 = arg_e0;
     e1 = arg_e1;
     NOTUSED(disc);
-    rv = AGID(e0->node) - AGID(e1->node);
-    if (rv == 0) {		/* same node */
+    v = AGID(e0->node) - AGID(e1->node);
+    if (v == 0) {		/* same node */
 	if ((AGTYPE(e0) == 0) || (AGTYPE(e1) == 0))
-	    rv = 0;
+	    v = 0;
 	else
-	    rv = AGID(e0) - AGID(e1);
+	    v = AGID(e0) - AGID(e1);
     }
-    return rv;
+    return ((v==0)?0:(v<0?-1:1));
 }
 
 /* edge comparison.  OBJTYPE(e) == 0 means ID is a wildcard. */
 int agedgeseqcmpf(Dict_t * d, void *arg_e0, void *arg_e1, Dtdisc_t * disc)
 {
-    int rv;
+    long v;
     Agedge_t *e0, *e1;
 
     NOTUSED(d);
     e0 = arg_e0;
     e1 = arg_e1;
     NOTUSED(disc);
-    rv = AGID(e0->node) - AGID(e1->node);
-    if (rv == 0) {		/* same node */
+    v = AGID(e0->node) - AGID(e1->node);
+    if (v == 0) {		/* same node */
 	if ((AGTYPE(e0) == 0) || (AGTYPE(e1) == 0))
-	    rv = 0;
+	    v = 0;
 	else
-	    rv = AGSEQ(e0) - AGSEQ(e1);
+	    v = AGSEQ(e0) - AGSEQ(e1);
     }
-    return rv;
+    return ((v==0)?0:(v<0?-1:1));
 }
 
 Dtdisc_t Ag_mainedge_seq_disc = {
