@@ -1,18 +1,15 @@
-/* $Id: graph.c,v 1.8 2009/07/11 15:38:51 erg Exp $ $Revision: 1.8 $ */
+/* $Id: graph.c,v 1.11 2011/01/25 16:30:47 ellson Exp $ $Revision: 1.11 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #define EXTERN
 #include <cghdr.h>
@@ -229,25 +226,31 @@ int agdegree(Agraph_t * g, Agnode_t * n, int want_in, int want_out)
     int rv = 0;
 
     sn = agsubrep(g, n);
-    if (want_out) rv += cnt(g->e_seq,&(sn->out_seq));
-    if (want_in) rv += cnt(g->e_seq,&(sn->in_seq));
+    if (sn) {
+	if (want_out) rv += cnt(g->e_seq,&(sn->out_seq));
+	if (want_in) rv += cnt(g->e_seq,&(sn->in_seq));
+    }
 	return rv;
 }
 
 int agraphidcmpf(Dict_t * d, void *arg0, void *arg1, Dtdisc_t * disc)
 {
+    long	v;
     Agraph_t *sg0, *sg1;
     sg0 = (Agraph_t *) arg0;
     sg1 = (Agraph_t *) arg1;
-    return (AGID(sg0) - AGID(sg1));
+    v = (AGID(sg0) - AGID(sg1));
+    return ((v==0)?0:(v<0?-1:1));
 }
 
 int agraphseqcmpf(Dict_t * d, void *arg0, void *arg1, Dtdisc_t * disc)
 {
+    long	v;
     Agraph_t *sg0, *sg1;
     sg0 = (Agraph_t *) arg0;
     sg1 = (Agraph_t *) arg1;
-    return (AGSEQ(sg0) - AGSEQ(sg1));
+    v = (AGSEQ(sg0) - AGSEQ(sg1));
+    return ((v==0)?0:(v<0?-1:1));
 }
 
 Dtdisc_t Ag_subgraph_id_disc = {
@@ -270,3 +273,11 @@ Agdesc_t Agundirected = { 0, 0, 0, 1 };
 Agdesc_t Agstrictundirected = { 0, 1, 0, 1 };
 
 Agdisc_t AgDefaultDisc = { &AgMemDisc, &AgIdDisc, &AgIoDisc };
+
+
+#include <stdio.h>
+void scndump(Agraph_t *g, char *file)
+{
+	FILE * f = fopen(file,"w");
+	if (f) {agwrite(g,f); fclose(f);}
+}
