@@ -1,18 +1,15 @@
-/* $Id: io.c,v 1.2 2008/04/25 17:14:54 arif Exp $ $Revision: 1.2 $ */
+/* $Id: io.c,v 1.6 2011/02/19 17:39:49 erg Exp $ $Revision: 1.6 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include <stdio.h>
 #include <cghdr.h>
@@ -76,7 +73,7 @@ static int iofread(void *chan, char *buf, int bufsize)
 }
 
 /* default IO methods */
-static int ioputstr(void *chan, char *str)
+static int ioputstr(void *chan, const char *str)
 {
     return fputs(str, (FILE *) chan);
 }
