@@ -1,25 +1,24 @@
-/* $Id: obj.c,v 1.6 2009/06/03 01:10:51 ellson Exp $ $Revision: 1.6 $ */
+/* $Id: obj.c,v 1.8 2011/02/19 20:20:11 erg Exp $ $Revision: 1.8 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include <cghdr.h>
 
 int agdelete(Agraph_t * g, void *obj)
 {
-    if ((AGTYPE((Agobj_t *) obj) == AGRAPH) && (g != agparent(obj)))
+    if ((AGTYPE((Agobj_t *) obj) == AGRAPH) && (g != agparent(obj))) {
 	agerr(AGERR, "agdelete on wrong graph");
+	return FAILURE;
+    }
 
     switch (AGTYPE((Agobj_t *) obj)) {
     case AGNODE:
