@@ -1,18 +1,15 @@
-/* $Id: rec.c,v 1.4 2010/01/19 02:22:54 north Exp $ $Revision: 1.4 $ */
+/* $Id: rec.c,v 1.8 2011/01/25 16:30:47 ellson Exp $ $Revision: 1.8 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include	<cghdr.h>
 
@@ -198,21 +195,22 @@ void agclean(Agraph_t * g, char *graphdata, char *nodedata, char *edgedata)
 }
 #endif
 
-void aginit(Agraph_t * g, int kind, char *rec_name, int rec_size, int mtf)
+void aginit(Agraph_t * g, int kind, char *rec_name, int arg_rec_size, int mtf)
 {
     Agnode_t *n;
     Agedge_t *e;
     Agraph_t *s;
-	int		 rec;
+	int		 rec_size;
+	int		 recur;	/* if recursive on subgraphs */
 
+	if (arg_rec_size < 0) {recur = 1; rec_size = -arg_rec_size;}
+	else {recur = 0; rec_size= arg_rec_size;}
     switch (kind) {
     case AGRAPH:
-	rec = (rec_size < 0);
-	if (rec) rec_size = -rec_size;
 	agbindrec(g, rec_name, rec_size, mtf);
-	if (rec)
+	if (recur)
 		for (s = agfstsubg(g); s; s = agnxtsubg(s))
-			aginit(s,kind,rec_name,rec_size,mtf);
+			aginit(s,kind,rec_name,arg_rec_size,mtf);
 	break;
     case AGNODE:
     case AGOUTEDGE:
