@@ -1,18 +1,15 @@
-/* $Id: write.c,v 1.20 2009/06/03 01:10:51 ellson Exp $ $Revision: 1.20 $ */
+/* $Id: write.c,v 1.23 2011/01/25 16:30:47 ellson Exp $ $Revision: 1.23 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include <stdio.h>		/* need sprintf() */
 #include <ctype.h>
@@ -60,6 +57,8 @@ static int strcasecmp(const char *s1, const char *s2)
 }
 #endif
 
+#define is_number_char(c) (isdigit(c) || ((c) == '.'))
+
 /* _agstrcanon:
  * Canonicalize ordinary strings. 
  * Assumes buf is large enough to hold output.
@@ -71,6 +70,7 @@ static char *_agstrcanon(char *arg, char *buf)
     int cnt = 0;
     int needs_quotes = FALSE;
     int maybe_num;
+    int backslash_pending = FALSE;
     static const char *tokenlist[]	/* must agree with scan.l */
 	= { "node", "edge", "strict", "graph", "digraph", "subgraph",
 	NIL(char *)
@@ -83,7 +83,7 @@ static char *_agstrcanon(char *arg, char *buf)
     p = buf;
     *p++ = '\"';
     uc = *(unsigned char *) s++;
-    maybe_num = (isdigit(uc) || (uc == '.'));
+    maybe_num = is_number_char(uc);
     while (uc) {
 	if (uc == '\"') {
 	    *p++ = '\\';
@@ -91,17 +91,28 @@ static char *_agstrcanon(char *arg, char *buf)
 	} else {
 	    if (!ISALNUM(uc))
 		needs_quotes = TRUE;
-	    else if (maybe_num && (!isdigit(uc) && (uc != '.')))
+	    else if (maybe_num && !is_number_char(uc))
 		needs_quotes = TRUE;
 	}
 	*p++ = (char) uc;
 	uc = *(unsigned char *) s++;
 	cnt++;
-	if (cnt >= MAX_OUTPUTLINE) {
-	    *p++ = '\\';
-	    *p++ = '\n';
-	    needs_quotes = TRUE;
+	
+        if (uc && backslash_pending && !((is_number_char(p[-1]) || isalpha(p[-1]) || (p[-1] == '\\')) && (is_number_char(uc) || isalpha(uc)))) {
+            *p++ = '\\';
+            *p++ = '\n';
+            needs_quotes = TRUE;
+            backslash_pending = FALSE;
 	    cnt = 0;
+        } else if (uc && (cnt >= MAX_OUTPUTLINE)) {
+            if (!((is_number_char(p[-1]) || isalpha(p[-1]) || (p[-1] == '\\')) && (is_number_char(uc) || isalpha(uc)))) {
+	        *p++ = '\\';
+    	        *p++ = '\n';
+	        needs_quotes = TRUE;
+		cnt = 0;
+            } else {
+                backslash_pending = TRUE;
+            }
 	}
     }
     *p++ = '\"';
