@@ -1,18 +1,15 @@
-/* $Id: blocktree.c,v 1.9 2009/08/17 21:04:11 erg Exp $ $Revision: 1.9 $ */
+/* $Id: blocktree.c,v 1.11 2011/01/25 16:30:47 ellson Exp $ $Revision: 1.11 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 #include "blocktree.h"
@@ -80,6 +77,20 @@ pop (estack* s)
 }
 
 
+/* dfs:
+ *
+ * Current scheme adds articulation point to first non-trivial child
+ * block. If none exists, it will be added to its parent's block, if
+ * non-trivial, or else given its own block.
+ *
+ * FIX:
+ * This should be modified to:
+ *  - allow user to specify which block gets a node, perhaps on per-node basis.
+ *  - if an articulation point is not used in one of its non-trivial blocks,
+ *    dummy edges should be added to preserve biconnectivity
+ *  - turn on user-supplied blocks.
+ *  - Post-process to move articulation point to largest block
+ */
 static void dfs(Agraph_t * g, Agnode_t * u, circ_state * state, int isRoot, estack* stk)
 {
     Agedge_t *e;
@@ -96,7 +107,7 @@ static void dfs(Agraph_t * g, Agnode_t * u, circ_state * state, int isRoot, esta
 	    if (!EDGEORDER(e)) EDGEORDER(e) = 1;
 	}
 
-        if (VAL(v) == 0) {
+        if (VAL(v) == 0) {   /* Since VAL(root) == 0, it gets treated as artificial cut point */
 	    PARENT(v) = u;
             push(stk, e);
             dfs(g, v, state, 0, stk);
@@ -118,7 +129,7 @@ static void dfs(Agraph_t * g, Agnode_t * u, circ_state * state, int isRoot, esta
 		    }
                 } while (ep != e);
 		if (block) {	/* If block != NULL, it's not empty */
-		    if (blockSize (block) > 1)
+		    if (!BLOCK(u) && blockSize (block) > 1)
 			addNode(block, u);
 		    if (isRoot && (BLOCK(u) == block))
 			insertBlock(&state->bl, block);
