@@ -1,31 +1,26 @@
-/* $Id: circular.h,v 1.2 2008/10/23 16:17:06 ellson Exp $ $Revision: 1.2 $ */
+/* $Id: circular.h,v 1.6 2011/01/25 16:30:48 ellson Exp $ $Revision: 1.6 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #ifndef CIRCULAR_H
 #define CIRCULAR_H
 
 #include "render.h"
 #include "block.h"
-#include "stack.h"
 
 typedef struct {
     blocklist_t bl;
     int orderCount;
     int blockCount;
-    nstack_t *bcstack;
     attrsym_t *N_artpos;
     attrsym_t *N_root;
     char *rootname;
@@ -77,12 +72,14 @@ typedef struct {
 
 typedef struct {
     int order;
+    Agedge_t* next;
 } edata;
 
 #define NDATA(n) ((ndata*)(ND_alg(n)))
 #define DNODE(n)	(NDATA(n)->dnode)
 
 #define EDGEDATA(e)  ((edata*)(ED_alg(e)))
+#define ENEXT(e)     (EDGEDATA(e)->next)
 #define EDGEORDER(e) (EDGEDATA(e)->order)
 
 #define DATA(n) ((cdata*)(ND_alg(n)))
@@ -104,28 +101,24 @@ typedef struct {
 #define PSI(n) (DATA(n)->u.f.psi)
 
 #define VISITED_F   (1 << 0)
-#define BCDONE_F    (1 << 1)
 #define ONSTACK_F   (1 << 2)
 #define PARENT_F    (1 << 3)
 #define PATH_F      (1 << 4)
 #define NEIGHBOR_F  (1 << 5)
 
 #define VISITED(n) (FLAGS(n)&VISITED_F)
-#define BCDONE(n)	 (FLAGS(n)&BCDONE_F)
 #define ONSTACK(n)	 (FLAGS(n)&ONSTACK_F)
 #define ISPARENT(n)	 (FLAGS(n)&PARENT_F)
 #define ONPATH(n)	 (FLAGS(n)&PATH_F)
 #define NEIGHBOR(n)	 (FLAGS(n)&NEIGHBOR_F)
 
 #define SET_VISITED(n) (FLAGS(n) |= VISITED_F)
-#define SET_BCDONE(n)	 (FLAGS(n) |= BCDONE_F)
 #define SET_ONSTACK(n)	 (FLAGS(n) |= ONSTACK_F)
 #define SET_PARENT(n)	 (FLAGS(n) |= PARENT_F)
 #define SET_ONPATH(n)	 (FLAGS(n) |= PATH_F)
 #define SET_NEIGHBOR(n)	 (FLAGS(n) |= NEIGHBOR_F)
 
 #define UNSET_VISITED(n) (FLAGS(n) &= ~VISITED_F)
-#define UNSET_BCDONE(n)	 (FLAGS(n) &= ~BCDONE_F)
 #define UNSET_ONSTACK(n)	 (FLAGS(n) &= ~ONSTACK_F)
 #define UNSET_NEIGHBOR(n)	 (FLAGS(n) &= ~NEIGHBOR_F)
 
