@@ -1,18 +1,15 @@
-/* $Id: circularinit.c,v 1.23 2009/09/04 17:47:42 erg Exp $ $Revision: 1.23 $ */
+/* $Id: circularinit.c,v 1.26 2011/02/15 16:27:53 erg Exp $ $Revision: 1.26 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 /*
@@ -92,8 +89,10 @@ static node_t *makeDerivedNode(graph_t * dg, char *name, int isNode,
     ND_alg(n) = (void *) NEW(cdata);
     if (isNode) {
 	ND_pos(n) = N_NEW(Ndim, double);
+#if 0
 	ND_xsize(n) = ND_xsize((node_t *) orig);
 	ND_ysize(n) = ND_ysize((node_t *) orig);
+#endif
 	ORIGN(n) = (node_t *) orig;
     } else
 	ORIGG(n) = (graph_t *) orig;
@@ -283,6 +282,7 @@ void circo_cleanup(graph_t * g)
 
     closeDerivedGraph((graph_t*)GD_alg(g));	/* delete derived graph */
 
+    free (ND_alg(n));
     for (; n; n = agnxtnode(g, n)) {
 	for (e = agfstout(g, n); e; e = agnxtout(g, e)) {
 	    gv_cleanup_edge(e);
