@@ -1,18 +1,15 @@
-/* $Id: geomprocs.h,v 1.22 2009/06/03 01:10:52 ellson Exp $ $Revision: 1.22 $ */
+/* $Id: geomprocs.h,v 1.24 2011/04/19 15:38:23 arif Exp $ $Revision: 1.24 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 /* geometric functions (e.g. on points and boxes) with application to, but
  * no specific dependance on graphs */
@@ -27,19 +24,13 @@ extern "C" {
 
 #include "geom.h"
 
+#ifdef WIN32
 #ifdef GVDLL
 #define extern __declspec(dllexport)
 #else
-#define extern
-#endif
-	
-/*visual studio*/
-#ifdef WIN32_DLL
-#ifndef GVC_EXPORTS
 #define extern __declspec(dllimport)
 #endif
-#endif
-/*end visual studio*/
+#endif	
 
 extern box mkbox(point p, point q);
 extern boxf mkboxf(pointf p, pointf q);
