@@ -1,18 +1,15 @@
-/* $Id: globals.h,v 1.41 2009/01/21 16:47:00 arif Exp $ $Revision: 1.41 $ */
+/* $Id: globals.h,v 1.47 2011/02/01 22:29:03 erg Exp $ $Revision: 1.47 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 /* this is to get the following win32 DLL junk to work.
  * if ever tempted to remove this, first please read:
@@ -72,12 +69,6 @@ extern "C" {
     EXTERN char *specificItems;
     EXTERN char *Gvfilepath;	/* Path of files allowed in 'shapefile' attrib  (also ps libs) */
 
-#ifdef WITH_CODEGENS
-    EXTERN int Output_lang;	/* POSTSCRIPT, DOT, etc. */
-    EXTERN FILE *Output_file;
-    EXTERN int Obj;
-#endif
-
     EXTERN unsigned char Verbose;
     EXTERN boolean Reduce, MemTest;
     EXTERN char *HTTPServerEnVar;
@@ -103,7 +94,7 @@ extern "C" {
 	*G_selectedpencolor, *G_selectedfillcolor,
 	*G_visitedpencolor, *G_visitedfillcolor,
 	*G_deletedpencolor, *G_deletedfillcolor,
-	*G_peripheries, *G_penwidth;
+	*G_ordering, *G_peripheries, *G_penwidth;
     EXTERN attrsym_t
 	*N_height, *N_width, *N_shape, *N_color, *N_fillcolor,
 	*N_activepencolor, *N_activefillcolor,
@@ -111,8 +102,8 @@ extern "C" {
 	*N_visitedpencolor, *N_visitedfillcolor,
 	*N_deletedpencolor, *N_deletedfillcolor,
 	*N_fontsize, *N_fontname, *N_fontcolor,
-	*N_label, *N_nojustify, *N_style, *N_showboxes,
-	*N_sides, *N_peripheries, *N_orientation,
+	*N_label, *N_xlabel, *N_nojustify, *N_style, *N_showboxes,
+	*N_sides, *N_peripheries, *N_ordering, *N_orientation,
 	*N_skew, *N_distortion, *N_fixed, *N_imagescale, *N_layer,
 	*N_group, *N_comment, *N_vertices, *N_z,
 	*N_penwidth;
@@ -123,7 +114,7 @@ extern "C" {
 	*E_visitedpencolor, *E_visitedfillcolor,
 	*E_deletedpencolor, *E_deletedfillcolor,
 	*E_fontsize, *E_fontname, *E_fontcolor,
-	*E_label, *E_dir, *E_style, *E_decorate,
+	*E_label, *E_xlabel, *E_dir, *E_style, *E_decorate,
 	*E_showboxes, *E_arrowsz, *E_constr, *E_layer,
 	*E_comment, *E_label_float,
 	*E_samehead, *E_sametail,
