@@ -1,24 +1,23 @@
-/* $Id: labels.c,v 1.68 2009/07/30 22:00:39 erg Exp $ $Revision: 1.68 $ */
+/* $Id: labels.c,v 1.75 2011/03/31 14:10:07 erg Exp $ $Revision: 1.75 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 #include "render.h"
 #include "htmltable.h"
 #include <limits.h>
 
+static char *strdup_and_subst_obj0 (char *str, void *obj, int escBackslash);
+
 static void storeline(graph_t *g, textlabel_t *lp, char *line, char terminator)
 {
     pointf size;
@@ -168,7 +167,10 @@ textlabel_t *make_label(void *obj, char *str, int kind, double fontsize, char *f
     }
     else {
         assert(kind == LT_NONE);
-	rv->text = strdup_and_subst_obj(str, obj);
+	/* This call just processes the graph object based escape sequences. The formatting escape
+         * sequences (\n, \l, \r) are processed in make_simple_label. That call also replaces \\ with \.
+         */
+	rv->text = strdup_and_subst_obj0(str, obj, 0);
         switch (rv->charset) {
 	case CHAR_LATIN1:
 	    s = latin1ToUTF8(rv->text);
@@ -184,15 +186,27 @@ textlabel_t *make_label(void *obj, char *str, int kind, double fontsize, char *f
     return rv;
 }
 
-void free_textpara(textpara_t * tl)
+/* free_textpara:
+ * Free resources related to textpara_t.
+ * tl is an array of cnt textpara_t's.
+ * It is also assumed that the text stored in the str field
+ * is all stored in one large buffer shared by all of the textpara_t,
+ * so only the first one needs to free its tlp->str.
+ */
+void free_textpara(textpara_t * tl, int cnt)
 {
-    if (tl) {
-	if (tl->str)
-	    free(tl->str);
-	if (tl->layout && tl->free_layout)
-	    tl->free_layout (tl->layout);
-	free(tl);
+    int i;
+    textpara_t* tlp = tl;
+
+    if (!tl) return;
+    for (i = 0; i < cnt; i++) { 
+	if ((i == 0) && tlp->str)
+	    free(tlp->str);
+	if (tlp->layout && tlp->free_layout)
+	    tlp->free_layout (tlp->layout);
+	tlp++;
     }
+    free(tl);
 }
 
 void free_label(textlabel_t * p)
@@ -202,7 +216,7 @@ void free_label(textlabel_t * p)
 	if (p->html) {
 	    free_html_label(p->u.html, 1);
 	} else {
-	    free_textpara(p->u.txt.para);
+	    free_textpara(p->u.txt.para, p->u.txt.nparas);
 	}
 	free(p);
     }
@@ -220,6 +234,7 @@ void emit_label(GVJ_t * job, emit_state_t emit_state, textlabel_t * lp)
 
     if (lp->html) {
 	emit_html_label(job, lp->u.html, lp);
+	obj->emit_state = old_emit_state;
 	return;
     }
 
@@ -266,7 +281,13 @@ void emit_label(GVJ_t * job, emit_state_t emit_state, textlabel_t * lp)
     obj->emit_state = old_emit_state;
 }
 
-char *strdup_and_subst_obj(char *str, void *obj)
+/* strdup_and_subst_obj0:
+ * Replace various escape sequences with the name of the associated
+ * graph object. A double backslash \\ can be used to avoid a replacement.
+ * If escBackslash is true, convert \\ to \; else leave alone. All other dyads 
+ * of the form \. are passed through unchanged.
+ */
+static char *strdup_and_subst_obj0 (char *str, void *obj, int escBackslash)
 {
     char c, *s, *p, *t, *newstr;
     char *tp_str = "", *hp_str = "";
@@ -276,6 +297,7 @@ char *strdup_and_subst_obj(char *str, void *obj)
 	h_len = 2, t_len = 2, l_len = 2,
 	tp_len = 0, hp_len = 0;
     int newlen = 0;
+    int isEdge = 0;
     textlabel_t *tl;
     port pt;
 
@@ -306,6 +328,7 @@ char *strdup_and_subst_obj(char *str, void *obj)
 	    }
 	    break;
 	case AGEDGE:
+	    isEdge = 1;
 	    g_str = agnameof(agroot(agraphof(agtail(((edge_t *)obj)))));
 	    g_len = strlen(g_str);
 	    t_str = agnameof(agtail(((edge_t *)obj)));
@@ -358,6 +381,12 @@ char *strdup_and_subst_obj(char *str, void *obj)
 	    case 'L':
 		newlen += l_len;
 		break; 
+	    case '\\':
+		if (escBackslash) {
+		    newlen += 1;
+		    break; 
+		}
+		/* Fall through */
 	    default:  /* leave other escape sequences unmodified, e.g. \n \l \r */
 		newlen += 2;
 	    }
@@ -379,16 +408,18 @@ char *strdup_and_subst_obj(char *str, void *obj)
 		for (t = n_str; (*p = *t++); p++);
 		break;
 	    case 'E':
-		for (t = t_str; (*p = *t++); p++);
-		if (tp_len) {
-		    *p++ = ':';
-		    for (t = tp_str; (*p = *t++); p++);
-		}
-		for (t = e_str; (*p = *t++); p++);
-		for (t = h_str; (*p = *t++); p++);
-		if (hp_len) {
-		    *p++ = ':';
-		    for (t = hp_str; (*p = *t++); p++);
+		if (isEdge) {
+		    for (t = t_str; (*p = *t++); p++);
+		    if (tp_len) {
+			*p++ = ':';
+			for (t = tp_str; (*p = *t++); p++);
+		    }
+		    for (t = e_str; (*p = *t++); p++);
+		    for (t = h_str; (*p = *t++); p++);
+		    if (hp_len) {
+			*p++ = ':';
+			for (t = hp_str; (*p = *t++); p++);
+		    }
 		}
 		break;
 	    case 'T':
@@ -400,6 +431,12 @@ char *strdup_and_subst_obj(char *str, void *obj)
 	    case 'L':
 		for (t = l_str; (*p = *t++); p++);
 		break;
+	    case '\\':
+		if (escBackslash) {
+		    *p++ = '\\';
+		    break; 
+		}
+		/* Fall through */
 	    default:  /* leave other escape sequences unmodified, e.g. \n \l \r */
 		*p++ = '\\';
 		*p++ = c;
@@ -413,6 +450,14 @@ char *strdup_and_subst_obj(char *str, void *obj)
     return newstr;
 }
 
+/* strdup_and_subst_obj:
+ * Processes graph object escape sequences; also collapses \\ to \.
+ */
+char *strdup_and_subst_obj(char *str, void *obj)
+{
+    return strdup_and_subst_obj0 (str, obj, 1);
+}
+
 /* return true if *s points to &[A-Za-z]*;      (e.g. &Ccedil; )
  *                          or &#[0-9]*;        (e.g. &#38; )
  *                          or &#x[0-9a-fA-F]*; (e.g. &#x6C34; )
