@@ -1,18 +1,15 @@
-/* $Id: utils.c,v 1.125 2010/01/05 17:22:24 arif Exp $ $Revision: 1.125 $ */
+/* $Id: utils.c,v 1.136 2011/02/15 16:30:02 erg Exp $ $Revision: 1.136 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include "render.h"
 #include "agxbuf.h"
@@ -21,9 +18,13 @@
 #include "logic.h"
 #include "gvc.h"
 
+#ifdef WIN32
+#include "libltdl/lt_system.h"
+#endif
 #ifndef WIN32
 #include <unistd.h>
 #endif
+#include <ctype.h>
 
 /*
  *  a queue of nodes
@@ -304,24 +305,44 @@ char *Fgets(FILE * fp)
 
 /* safefile:
  * Check to make sure it is okay to read in files.
- * For normal uses, it is a no-op.
- * If the application has set HTTPServerEnVar, this indicates
- * it is web-active. In this case, it requires that the Gvfilepath
- * variable be set. This gives the legal directory
- * from which files may be read. The filename returned is thus
+ * For normal uses, it is a no-op, and returns the input.
+ * It returns NULL if the filename is trivial.
+ *
+ * If the application has set the SERVER_NAME environment variable, 
+ * this indicates it is web-active. In this case, it requires that the GV_FILE_PATH
+ * environment variable be set. This gives the legal directories
+ * from which files may be read. safefile then derives the rightmost component
+ * of filename, where components are separated by a slash, backslash or colon, 
+ * It then checks for the existence of a file consisting of a directory from 
+ * GV_FILE_PATH followed by the rightmost component of filename. It returns the
+ * first such found, or NULL otherwise.
+ * The filename returned is thus
  * Gvfilepath concatenated with the last component of filename,
- * where a component is determined by a slack, backslash or colon
+ * where a component is determined by a slash, backslash or colon
  * character.  
- * If the argument contains one of these characters, the user is
+ *
+ * If filename contains multiple components, the user is
  * warned, once, that everything to the left is ignored.
- * As coded now, Gvfilepath must end in a slash character, or
- * equivalent.
- * Returns NULL if the argument is trivial.
+ *
+ * N.B. safefile uses a fixed buffer, so functions using it should use the
+ * value immediately or make a copy.
  */
+#ifdef WIN32
+#define DIRSEP "\\"
+#define PATHSEP ";"
+#else
+#define DIRSEP "/"
+#define PATHSEP ":"
+#endif
+
 const char *safefile(const char *filename)
 {
     static boolean onetime = TRUE;
+    static boolean firsttime = TRUE;
     static char *safefilename = NULL;
+    static int maxdirlen;
+    static char** dirs;
+    char** dp;
     const char *str, *p;
 
     if (!filename || !filename[0])
@@ -335,21 +356,26 @@ const char *safefile(const char *filename)
 	if (!Gvfilepath) {
 	    if (onetime) {
 		agerr(AGWARN,
-		      "file loading is disabled because the environment contains: %s\n"
-		      "and there is no GV_FILE_PATH variable.\n",
+		      "file loading is disabled because the environment contains SERVER_NAME=\"%s\"n"
+		      "and there is no GV_FILE_PATH variable set.\n",
 		      HTTPServerEnVar);
 		onetime = FALSE;
 	    }
 	    return NULL;
 	}
+	if (firsttime) {
+	    int cnt = 0;
+	    char* s = strdup (Gvfilepath);
+	    char* dir;
+	    for (dir = strtok (s, PATHSEP); dir; dir = strtok (NULL, PATHSEP)) {
+		dirs = ALLOC (cnt+2,dirs,char*);
+		dirs[cnt++] = dir;
+		maxdirlen = MAX(maxdirlen, strlen (dir));
+	    }
+	    dirs[cnt] = NULL;
+	    firsttime = FALSE;
+	}
 
-	/* allocate a buffer that we are sure is big enough
-         * +1 for null character.
-         */
-	safefilename = realloc(safefilename,
-			       (strlen(Gvfilepath) + strlen(filename) + 1));
-
-	strcpy(safefilename, Gvfilepath);
 	str = filename;
 	if ((p = strrchr(str, '/')))
 	    str = ++p;
@@ -357,20 +383,31 @@ const char *safefile(const char *filename)
 	    str = ++p;
 	if ((p = strrchr(str, ':')))
 	    str = ++p;
-	strcat(safefilename, str);
 
 	if (onetime && str != filename) {
 	    agerr(AGWARN, "Path provided to file: \"%s\" has been ignored"
-		  " because files are only permitted to be loaded from the \"%s\""
-		  " directory when running in an http server.\n", filename,
-		  Gvfilepath);
+		  " because files are only permitted to be loaded from the directories in \"%s\""
+		  " when running in an http server.\n", filename, Gvfilepath);
 	    onetime = FALSE;
 	}
 
-	return safefilename;
+	/* allocate a buffer that we are sure is big enough
+         * +1 for null character.
+         * +1 for directory separator character.
+         */
+	safefilename = realloc(safefilename,
+			       (maxdirlen + strlen(str) + 2));
+
+	for (dp = dirs; *dp; dp++) {
+	    sprintf (safefilename, "%s%s%s", *dp, DIRSEP, str);
+	    if (access (safefilename, R_OK) == 0)
+		return safefilename;
+	}
+	return NULL;
     }
-    /* else, not in server, use original filename without modification. */
-    return filename;
+	/* else, not in server, use original filename without modification. */
+    else
+	return filename;
 }
 
 int maptoken(char *p, char **name, int *val)
@@ -384,10 +421,10 @@ int maptoken(char *p, char **name, int *val)
     return val[i];
 }
 
-boolean mapbool(char *p)
+boolean mapBool(char *p, boolean dflt)
 {
-    if (p == NULL)
-	return FALSE;
+    if (!p || (*p == '\0'))
+	return dflt;
     if (!strcasecmp(p, "false"))
 	return FALSE;
     if (!strcasecmp(p, "no"))
@@ -396,7 +433,15 @@ boolean mapbool(char *p)
 	return TRUE;
     if (!strcasecmp(p, "yes"))
 	return TRUE;
-    return atoi(p);
+    if (isdigit(*p))
+	return atoi(p);
+    else
+	return dflt;
+}
+
+boolean mapbool(char *p)
+{
+    return mapBool (p, FALSE);
 }
 
 pointf dotneato_closest(splines * spl, pointf pt)
@@ -547,7 +592,7 @@ struct fontinfo {
     char *fontcolor;
 };
 
-void common_init_node_opt(node_t * n, int shape_init_flag)
+void common_init_node(node_t * n)
 {
     struct fontinfo fi;
     char *str;
@@ -579,11 +624,7 @@ void common_init_node_opt(node_t * n, int shape_init_flag)
     }
 
     ND_showboxes(n) = late_int(n, N_showboxes, 0, 0);
-    if (shape_init_flag) ND_shape(n)->fns->initfn(n);
-}
-
-void common_init_node(node_t * n) {
-    common_init_node_opt(n,TRUE);
+    ND_shape(n)->fns->initfn(n);
 }
 
 static void initFontEdgeAttr(edge_t * e, struct fontinfo *fi)
@@ -807,8 +848,8 @@ void compute_bb(graph_t * g)
     bb.UR = pointfof(-INT_MAX, -INT_MAX);
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	ptf = coord(n);
-	s2.x = ND_xsize(n) / 2. + 1;
-	s2.y = ND_ysize(n) / 2. + 1;
+	s2.x = ND_xsize(n) / 2.0;
+	s2.y = ND_ysize(n) / 2.0;
 	b.LL = sub_pointf(ptf, s2);
 	b.UR = add_pointf(ptf, s2);
 
@@ -843,6 +884,11 @@ void compute_bb(graph_t * g)
     GD_bb(g) = bb;
 }
 
+int is_a_cluster (Agraph_t* g)
+{
+    return ((g == g->root) || (!strncasecmp(agnameof(g), "cluster", 7)));
+}
+
 /* setAttr:
  * Sets object's name attribute to the given value.
  * Creates the attribute if not already set.
@@ -1736,7 +1782,7 @@ void setEdgeType (graph_t* g, int dflt)
 
 
 #include <string.h>
-#include <ctype.h>
+//#include <ctype.h>
 
 
 int strcasecmp(const char *s1, const char *s2)
@@ -1757,7 +1803,7 @@ int strcasecmp(const char *s1, const char *s2)
 #ifndef WIN32_STATIC
 #ifndef HAVE_STRNCASECMP
 #include <string.h>
-#include <ctype.h>
+//#include <ctype.h>
 
 int strncasecmp(const char *s1, const char *s2, unsigned int n)
 {
@@ -1822,17 +1868,17 @@ void gv_cleanup_node(node_t * n)
 
 void gv_nodesize(node_t * n, boolean flip)
 {
-    int w;
+    double w;
 
     if (flip) {
-        w = ND_xsize(n) = POINTS(ND_height(n));
+        w = INCH2PS(ND_height(n));
         ND_lw(n) = ND_rw(n) = w / 2;
-        ND_ht(n) = ND_ysize(n) = POINTS(ND_width(n));
+        ND_ht(n) = INCH2PS(ND_width(n));
     } 
     else {
-        w = ND_xsize(n) = POINTS(ND_width(n));
+        w = INCH2PS(ND_width(n));
         ND_lw(n) = ND_rw(n) = w / 2;
-        ND_ht(n) = ND_ysize(n) = POINTS(ND_height(n));
+        ND_ht(n) = INCH2PS(ND_height(n));
     }
 }
 
@@ -1853,3 +1899,13 @@ void fix_fc(void)
     }
 }
 #endif
+
+#ifndef HAVE_DRAND48
+double drand48(void)
+{
+    double d;
+    d = rand();
+    d = d / RAND_MAX;
+    return d;
+}
+#endif
