@@ -1,18 +1,15 @@
-/* $Id: utils.h,v 1.38 2009/10/16 15:47:47 erg Exp $ $Revision: 1.38 $ */
+/* $Id: utils.h,v 1.41 2011/02/15 16:30:02 erg Exp $ $Revision: 1.41 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #ifndef _UTILS_H
 #define _UTILS_H 1
@@ -59,7 +56,6 @@ extern "C" {
     extern void epsf_emit_body(GVJ_t *job, usershape_t *us);
     extern void epsf_define(GVJ_t * job);
     extern void undoClusterEdges(graph_t * g);
-	extern void common_init_node_opt(node_t * n, int shape_init_flag);
 #ifndef WITH_CGRAPH
     extern attrsym_t* safe_dcl(graph_t*, void*, char*, char*,
              attrsym_t * (*fun) (Agraph_t *, char *, char *));
@@ -82,6 +78,7 @@ extern "C" {
     extern char *Fgets(FILE * fp);
     extern const char *safefile(const char *filename);
 
+    extern boolean mapBool(char *, boolean);
     extern boolean mapbool(char *);
     extern int maptoken(char *, char **, int *);
 
@@ -110,6 +107,7 @@ extern "C" {
     extern Agsym_t *setAttr(graph_t*, void*, char*name, char *value, Agsym_t*);
     extern void setEdgeType (graph_t* g, int dflt);
     extern int edgeType (char* s, int dflt);
+    extern int is_a_cluster (Agraph_t* g);
 
     /* from postproc.c */ 
     extern void gv_nodesize(Agnode_t * n, boolean flip);
