@@ -1,18 +1,15 @@
-/* $Id: dotsplines.c,v 1.62 2008/12/07 22:14:08 erg Exp $ $Revision: 1.62 $ */
+/* $Id: dotsplines.c,v 1.73 2011/02/06 00:19:45 erg Exp $ $Revision: 1.73 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 /*
@@ -208,6 +205,54 @@ static void edge_normalize(graph_t * g)
     }
 }
 
+/* resetRW:
+ * In position, each node has its rw stored in mval and,
+ * if a node is part of a loop, rw may be increased to
+ * reflect the loops and associated labels. We restore
+ * the original value here. 
+ */
+static void
+resetRW (graph_t * g)
+{
+    node_t* n;
+
+    for (n = agfstnode(g); n; n = agnxtnode(g,n)) {
+	if (ND_other(n).list) {
+	    double tmp = ND_rw(n);
+	    ND_rw(n) = ND_mval(n);
+	    ND_mval(n) = tmp;
+	}
+    }
+}
+
+/* setEdgeLabelPos:
+ * Set edge label position information for regular and non-adjacent flat edges.
+ * Dot has allocated space and position for these labels. This info will be
+ * used when routing orthogonal edges.
+ */
+static void
+setEdgeLabelPos (graph_t * g)
+{
+    node_t* n;
+    textlabel_t* l;
+
+    /* place regular edge labels */
+    for (n = GD_nlist(g); n; n = ND_next(n)) {
+	if (ND_node_type(n) == VIRTUAL) {
+	    if (ND_alg(n)) {   // label of non-adjacent flat edge
+		edge_t* fe = (edge_t*)ND_alg(n);
+		assert ((l = ED_label(fe)));
+		l->pos = ND_coord(n);
+		l->set = TRUE;
+	    }
+	    else if ((l = ND_label(n))) {// label of regular edge
+		place_vnlabel(n);
+	    }
+	    updateBB(g, l);
+	}
+    }
+}
+
 /* _dot_splines:
  * Main spline routing code.
  * The normalize parameter allows this function to be called by the
@@ -224,15 +269,21 @@ static void _dot_splines(graph_t * g, int normalize)
     path *P;
     spline_info_t sd;
 #ifndef WITH_CGRAPH
-    int et = EDGE_TYPE(g->root);
+    int et = EDGE_TYPE(g);
 #else /* WITH_CGRAPH */
-    int et = EDGE_TYPE(agroot(g));
+    int et = EDGE_TYPE(g);
 #endif /* WITH_CGRAPH */
 
     if (et == ET_NONE) return; 
 #ifdef ORTHO
     if (et == ET_ORTHO) {
-	orthoEdges (g, 0);
+	resetRW (g);
+	if (GD_has_labels(g) & EDGE_LABEL) {
+	    setEdgeLabelPos (g);
+	    orthoEdges (g, 1);
+	}
+	else
+	    orthoEdges (g, 0);
 	goto finish;
     } 
 #endif
@@ -266,6 +317,7 @@ static void _dot_splines(graph_t * g, int normalize)
 		edge_t* fe = (edge_t*)ND_alg(n);
 		assert (ED_label(fe));
 		ED_label(fe)->pos = ND_coord(n);
+		ED_label(fe)->set = TRUE;
 	    }
 	    if ((ND_node_type(n) != NORMAL) &&
 		(sinfo.splineMerge(n) == FALSE))
@@ -470,6 +522,7 @@ place_vnlabel(node_t * n)
     width = GD_flip(agraphof(n)) ? dimen.y : dimen.x;
     ED_label(e)->pos.x = ND_coord(n).x + width / 2.0;
     ED_label(e)->pos.y = ND_coord(n).y;
+    ED_label(e)->set = TRUE;
 }
 
 static void 
@@ -650,9 +703,18 @@ cloneGraph (graph_t* g)
 #endif /* WITH_CGRAPH */
     }
 
-#ifdef WITH_CGRAPH
-
+#ifndef WITH_CGRAPH
+    if (!agfindattr(auxg->proto->e, "headport"))
+	agedgeattr (auxg, "headport", "");
+    if (!agfindattr(auxg->proto->e, "tailport"))
+	agedgeattr (auxg, "tailport", "");
+#else /* WITH_CGRAPH */
+    if (!agattr(auxg,AGEDGE, "headport", NULL))
+	agattr(auxg,AGEDGE, "headport", "");
+    if (!agattr(auxg,AGEDGE, "tailport", NULL))
+	agattr(auxg,AGEDGE, "tailport", "");
 #endif /* WITH_CGRAPH */
+
     attr_state.E_constr = E_constr;
     attr_state.E_samehead = E_samehead;
     attr_state.E_sametail = E_sametail;
@@ -736,8 +798,16 @@ cloneEdge (graph_t* g, node_t* tn, node_t* hn, edge_t* orig)
 #else /* WITH_CGRAPH */
     edge_t* e = agedge(g, tn, hn,NULL,1);
 #endif /* WITH_CGRAPH */
-    for (; ED_edge_type(orig) != NORMAL; orig = ED_to_orig(orig));
+    /* for (; ED_edge_type(orig) != NORMAL; orig = ED_to_orig(orig)); */
     agcopyattr (orig, e);
+/*
+    if (orig->tail != ND_alg(tn)) {
+	char* hdport = agget (orig, HEAD_ID);
+	char* tlport = agget (orig, TAIL_ID);
+	agset (e, TAIL_ID, (hdport ? hdport : ""));
+	agset (e, HEAD_ID, (tlport ? tlport : ""));
+    }
+*/
 
     return e;
 }
@@ -756,6 +826,209 @@ transformf (pointf p, pointf del, int flip)
     return add_pointf(p, del);
 }
 
+/* edgelblcmpfn:
+ * lexicographically order edges by
+ *  - has label
+ *  - label is wider
+ *  - label is higher
+ */
+static int edgelblcmpfn(edge_t** ptr0, edge_t** ptr1)
+{
+    edge_t *e0, *e1;
+    pointf sz0, sz1;
+
+    e0 = (edge_t *) * ptr0;
+    e1 = (edge_t *) * ptr1;
+
+    if (ED_label(e0)) {
+	if (ED_label(e1)) {
+	    sz0 = ED_label(e0)->dimen;
+	    sz1 = ED_label(e1)->dimen;
+	    if (sz0.x > sz1.x) return -1;
+	    else if (sz0.x < sz1.x) return 1;
+	    else if (sz0.y > sz1.y) return -1;
+	    else if (sz0.y < sz1.y) return 1;
+	    else return 0;
+	}
+	else
+	    return -1;
+    }
+    else if (ED_label(e1)) {
+ 	return 1;
+    }
+    else
+ 	return 0;
+}
+
+#define LBL_SPACE  6  /* space between labels, in points */
+
+/* makeSimpleFlatLabels:
+ * This handles the second simplest case for flat edges between
+ * two adjacent nodes. We still invoke a dot on a rotated problem
+ * to handle edges with ports. This usually works, but fails for
+ * records because of their weird nature.
+ */
+static void
+makeSimpleFlatLabels (node_t* tn, node_t* hn, edge_t** edges, int ind, int cnt, int et, int n_lbls)
+{
+    pointf *ps;
+    Ppoly_t poly;
+    int pn;
+    edge_t* e = edges[ind];
+    pointf points[10], tp, hp;
+    int i, pointn;
+    double leftend, rightend, ctrx, ctry, miny, maxy;
+    double uminx, umaxx;
+    double lminx, lmaxx;
+
+    edge_t** earray = N_NEW(cnt, edge_t*);
+
+    for (i = 0; i < cnt; i++) {
+	earray[i] = edges[ind + i];
+    }
+
+    qsort (earray, cnt, sizeof(edge_t*), (qsort_cmpf) edgelblcmpfn);
+
+    tp = add_pointf(ND_coord(tn), ED_tail_port(e).p);
+    hp = add_pointf(ND_coord(hn), ED_head_port(e).p);
+
+    leftend = tp.x+ND_rw(tn);
+    rightend = hp.x-ND_lw(hn);
+    ctrx = (leftend + rightend)/2.0;
+    
+    /* do first edge */
+    pointn = 0;
+    points[pointn++] = tp;
+    points[pointn++] = tp;
+    points[pointn++] = hp;
+    points[pointn++] = hp;
+#ifndef WITH_CGRAPH
+    clip_and_install(e, e->head, points, pointn, &sinfo);
+#else /* WITH_CGRAPH */
+    clip_and_install(e, aghead(e), points, pointn, &sinfo);
+#endif /* WITH_CGRAPH */
+    ED_label(e)->pos.x = ctrx;
+    ED_label(e)->pos.y = tp.y + (ED_label(e)->dimen.y+LBL_SPACE)/2.0;
+    ED_label(e)->set = TRUE;
+
+    miny = tp.y + LBL_SPACE/2.0;
+    maxy = miny + ED_label(e)->dimen.y;
+    uminx = ctrx - (ED_label(e)->dimen.x)/2.0;
+    umaxx = ctrx + (ED_label(e)->dimen.x)/2.0;
+
+    for (i = 1; i < n_lbls; i++) {
+	e = edges[ind + i];
+	if (i%2) {  /* down */
+	    if (i == 1) {
+		lminx = ctrx - (ED_label(e)->dimen.x)/2.0;
+		lmaxx = ctrx + (ED_label(e)->dimen.x)/2.0;
+	    }
+	    miny -= LBL_SPACE + ED_label(e)->dimen.y;
+	    points[0] = tp;
+	    points[1].x = tp.x;
+	    points[1].y = miny - LBL_SPACE;
+	    points[2].x = hp.x;
+	    points[2].y = points[1].y;
+	    points[3] = hp;
+	    points[4].x = lmaxx;
+	    points[4].y = hp.y;
+	    points[5].x = lmaxx;
+	    points[5].y = miny;
+	    points[6].x = lminx;
+	    points[6].y = miny;
+	    points[7].x = lminx;
+	    points[7].y = tp.y;
+	    ctry = miny + (ED_label(e)->dimen.y)/2.0;
+	}
+	else {   /* up */
+	    points[0] = tp;
+	    points[1].x = uminx;
+	    points[1].y = tp.y;
+	    points[2].x = uminx;
+	    points[2].y = maxy;
+	    points[3].x = umaxx;
+	    points[3].y = maxy;
+	    points[4].x = umaxx;
+	    points[4].y = hp.y;
+	    points[5].x = hp.x;
+	    points[5].y = hp.y;
+	    points[6].x = hp.x;
+	    points[6].y = maxy + LBL_SPACE;
+	    points[7].x = tp.x;
+	    points[7].y = maxy + LBL_SPACE;
+	    ctry =  maxy + (ED_label(e)->dimen.y)/2.0 + LBL_SPACE;
+	    maxy += ED_label(e)->dimen.y + LBL_SPACE;
+	}
+	poly.pn = 8;
+	poly.ps = (Ppoint_t*)points;
+	ps = simpleSplineRoute (tp, hp, poly, &pn, et == ET_PLINE);
+	if (pn == 0) return;
+	ED_label(e)->pos.x = ctrx;
+	ED_label(e)->pos.y = ctry;
+	ED_label(e)->set = TRUE;
+#ifndef WITH_CGRAPH
+	clip_and_install(e, e->head, ps, pn, &sinfo);
+#else /* WITH_CGRAPH */
+	clip_and_install(e, aghead(e), ps, pn, &sinfo);
+#endif /* WITH_CGRAPH */
+    }
+
+    /* edges with no labels */
+    for (; i < cnt; i++) {
+	e = edges[ind + i];
+	if (i%2) {  /* down */
+	    if (i == 1) {
+		lminx = (2*leftend + rightend)/3.0;
+		lmaxx = (leftend + 2*rightend)/3.0;
+	    }
+	    miny -= LBL_SPACE;
+	    points[0] = tp;
+	    points[1].x = tp.x;
+	    points[1].y = miny - LBL_SPACE;
+	    points[2].x = hp.x;
+	    points[2].y = points[1].y;
+	    points[3] = hp;
+	    points[4].x = lmaxx;
+	    points[4].y = hp.y;
+	    points[5].x = lmaxx;
+	    points[5].y = miny;
+	    points[6].x = lminx;
+	    points[6].y = miny;
+	    points[7].x = lminx;
+	    points[7].y = tp.y;
+	}
+	else {   /* up */
+	    points[0] = tp;
+	    points[1].x = uminx;
+	    points[1].y = tp.y;
+	    points[2].x = uminx;
+	    points[2].y = maxy;
+	    points[3].x = umaxx;
+	    points[3].y = maxy;
+	    points[4].x = umaxx;
+	    points[4].y = hp.y;
+	    points[5].x = hp.x;
+	    points[5].y = hp.y;
+	    points[6].x = hp.x;
+	    points[6].y = maxy + LBL_SPACE;
+	    points[7].x = tp.x;
+	    points[7].y = maxy + LBL_SPACE;
+	    maxy += + LBL_SPACE;
+	}
+	poly.pn = 8;
+	poly.ps = (Ppoint_t*)points;
+	ps = simpleSplineRoute (tp, hp, poly, &pn, et == ET_PLINE);
+	if (pn == 0) return;
+#ifndef WITH_CGRAPH
+	clip_and_install(e, e->head, ps, pn, &sinfo);
+#else /* WITH_CGRAPH */
+	clip_and_install(e, aghead(e), ps, pn, &sinfo);
+#endif /* WITH_CGRAPH */
+    }
+   
+    free (earray);
+}
+
 /* makeSimpleFlat:
  */
 static void
@@ -805,6 +1078,7 @@ makeSimpleFlat (node_t* tn, node_t* hn, edge_t** edges, int ind, int cnt, int et
 /* make_flat_adj_edges:
  * In the simple case, with no labels or ports, this creates a simple
  * spindle of splines.
+ * If there are only labels, cobble something together.
  * Otherwise, we run dot recursively on the 2 nodes and the edges, 
  * essentially using rankdir=LR, to get the needed spline info.
  */
@@ -833,9 +1107,15 @@ make_flat_adj_edges(path* P, edge_t** edges, int ind, int cnt, edge_t* e0,
 	if (ED_tail_port(e).defined || ED_head_port(e).defined) ports = 1;
     }
 
-    /* flat edges without ports and labels can go straight left to right */
-    if ((labels == 0) && (ports == 0)) {
-	makeSimpleFlat (tn, hn, edges, ind, cnt, et);
+    if (ports == 0) {
+	/* flat edges without ports and labels can go straight left to right */
+	if (labels == 0) {
+	    makeSimpleFlat (tn, hn, edges, ind, cnt, et);
+	}
+	/* flat edges without ports but with labels take more work */
+	else {
+	    makeSimpleFlatLabels (tn, hn, edges, ind, cnt, et, labels);
+	}
 	return;
     }
 
@@ -860,12 +1140,13 @@ make_flat_adj_edges(path* P, edge_t** edges, int ind, int cnt, edge_t* e0,
     auxh = cloneNode(auxg, hn, GD_flip(g)); 
     for (i = 0; i < cnt; i++) {
 	e = edges[ind + i];
+	for (; ED_edge_type(e) != NORMAL; e = ED_to_orig(e));
 	if (agtail(e) == tn)
 	    auxe = cloneEdge (auxg, auxt, auxh, e);
 	else
 	    auxe = cloneEdge (auxg, auxh, auxt, e);
 	ED_alg(e) = auxe;
-	if (!hvye && !ED_tail_port(e0).defined && !ED_head_port(e0).defined) {
+	if (!hvye && !ED_tail_port(e).defined && !ED_head_port(e).defined) {
 	    hvye = auxe;
 	    ED_alg(hvye) = e;
 	}
@@ -922,22 +1203,15 @@ make_flat_adj_edges(path* P, edge_t** edges, int ind, int cnt, edge_t* e0,
 	bezier* bz;
 
 	e = edges[ind + i];
+	for (; ED_edge_type(e) != NORMAL; e = ED_to_orig(e));
 	auxe = (edge_t*)ED_alg(e);
 	if ((auxe == hvye) & !ED_alg(auxe)) continue; /* pseudo-edge */
 	auxbz = ED_spl(auxe)->list;
 	bz = new_spline(e, auxbz->size);
-	if (GD_flip(g)) {
-	    bz->sflag = auxbz->eflag;
-	    bz->sp = transformf(auxbz->ep, del, 1);
-	    bz->eflag = auxbz->sflag;
-	    bz->ep = transformf(auxbz->sp, del, 1);
-	}
-	else {
-	    bz->sflag = auxbz->sflag;
-	    bz->sp = transformf(auxbz->sp, del, 0);
-	    bz->eflag = auxbz->eflag;
-	    bz->ep = transformf(auxbz->ep, del, 0);
-	}
+	bz->sflag = auxbz->sflag;
+	bz->sp = transformf(auxbz->sp, del, GD_flip(g));
+	bz->eflag = auxbz->eflag;
+	bz->ep = transformf(auxbz->ep, del, GD_flip(g));
 	for (j = 0; j <  auxbz->size; ) {
 	    pointf cp[4];
 	    cp[0] = bz->list[j] = transformf(auxbz->list[j], del, GD_flip(g));
@@ -953,6 +1227,7 @@ make_flat_adj_edges(path* P, edge_t** edges, int ind, int cnt, edge_t* e0,
         }
 	if (ED_label(e)) {
 	    ED_label(e)->pos = transformf(ED_label(auxe)->pos, del, GD_flip(g));
+	    ED_label(e)->set = TRUE;
 	    updateBB(g, ED_label(e));
 	}
     }
@@ -1021,6 +1296,7 @@ make_flat_labeled_edge(spline_info_t* sp, path* P, edge_t* e, int et)
     for (f = ED_to_virt(e); ED_to_virt(f); f = ED_to_virt(f));
     ln = agtail(f);
     ED_label(e)->pos = ND_coord(ln);
+    ED_label(e)->set = TRUE;
 
     if (et == ET_LINE) {
 	pointf startp, endp, lp;
@@ -1087,7 +1363,8 @@ make_flat_bottom_edges(spline_info_t* sp, path * P, edge_t ** edges, int
 	ind, int cnt, edge_t* e, int splines)
 {
     node_t *tn, *hn;
-    int j, i, stepx, stepy, vspace, r;
+    int j, i, r;
+    double stepx, stepy, vspace;
     rank_t* nextr;
     int pn;
     pointf *ps;
@@ -1106,7 +1383,7 @@ make_flat_bottom_edges(spline_info_t* sp, path * P, edge_t ** edges, int
     else {
 	vspace = GD_ranksep(g);
     }
-    stepx = sp->Multisep / (cnt+1); 
+    stepx = ((double)(sp->Multisep)) / (cnt+1); 
     stepy = vspace / (cnt+1);
 
     makeBottomFlatEnd (sp, P, tn, e, &tend, TRUE);
@@ -1163,7 +1440,8 @@ make_flat_edge(spline_info_t* sp, path * P, edge_t ** edges, int ind, int cnt, i
 {
     node_t *tn, *hn;
     edge_t fwdedge, *e;
-    int j, i, stepx, stepy, vspace, r;
+    int j, i, r;
+    double stepx, stepy, vspace;
     int tside, hside, pn;
     pointf *ps;
     pathend_t tend, hend;
@@ -1212,7 +1490,7 @@ make_flat_edge(spline_info_t* sp, path * P, edge_t ** edges, int ind, int cnt, i
     else {
 	vspace = GD_ranksep(g);
     }
-    stepx = sp->Multisep / (cnt+1); 
+    stepx = ((double)sp->Multisep) / (cnt+1); 
     stepy = vspace / (cnt+1);
 
     makeFlatEnd (sp, P, tn, e, &tend, TRUE);
@@ -1347,6 +1625,8 @@ makeLineEdge(edge_t* fe, pointf* points, node_t** hp)
     return pn;
 }
 
+#define NUMPTS 2000
+
 /* make_regular_edge:
  */
 static void
@@ -1359,9 +1639,18 @@ make_regular_edge(spline_info_t* sp, path * P, edge_t ** edges, int ind, int cnt
     pathend_t tend, hend;
     boxf b;
     int boxn, sl, si, smode, i, j, dx, pn, hackflag, longedge;
-    pointf pointfs[1000], pointfs2[1000];
+    static pointf* pointfs;
+    static pointf* pointfs2;
+    static int numpts;
+    static int numpts2;
     int pointn;
 
+    if (!pointfs) {
+	pointfs = N_GNEW(NUMPTS, pointf);
+   	pointfs2 = N_GNEW(NUMPTS, pointf);
+	numpts = NUMPTS;
+	numpts2 = NUMPTS;
+    }
     sl = 0;
     e = edges[ind];
     g = agraphof(agtail(e));
@@ -1468,6 +1757,14 @@ make_regular_edge(spline_info_t* sp, path * P, edge_t ** edges, int ind, int cnt
 	    }
 	    if (pn == 0)
 	        return;
+	
+	    if (pointn + pn > numpts) {
+                /* This should be enough to include 3 extra points added by
+                 * straight_path below.
+                 */
+		numpts = 2*(pointn+pn); 
+		pointfs = RALLOC(numpts, pointfs, pointf);
+	    }
 	    for (i = 0; i < pn; i++) {
 		pointfs[pointn++] = ps[i];
 	    }
@@ -1511,6 +1808,10 @@ make_regular_edge(spline_info_t* sp, path * P, edge_t ** edges, int ind, int cnt
         }
 	if (pn == 0)
 	    return;
+	if (pointn + pn > numpts) {
+	    numpts = 2*(pointn+pn); 
+	    pointfs = RALLOC(numpts, pointfs, pointf);
+	}
 	for (i = 0; i < pn; i++) {
 	    pointfs[pointn++] = ps[i];
 	}
@@ -1527,6 +1828,11 @@ make_regular_edge(spline_info_t* sp, path * P, edge_t ** edges, int ind, int cnt
     dx = sp->Multisep * (cnt - 1) / 2;
     for (i = 1; i < pointn - 1; i++)
 	pointfs[i].x -= dx;
+
+    if (numpts > numpts2) {
+	numpts2 = numpts; 
+	pointfs2 = RALLOC(numpts2, pointfs2, pointf);
+    }
     for (i = 0; i < pointn; i++)
 	pointfs2[i] = pointfs[i];
     clip_and_install(fe, hn, pointfs2, pointn, &sinfo);
