@@ -1,18 +1,15 @@
-/* $Id: mincross.c,v 1.19 2009/06/03 01:10:52 ellson Exp $ $Revision: 1.19 $ */
+/* $Id: mincross.c,v 1.23 2011/02/04 18:36:12 erg Exp $ $Revision: 1.23 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 /* 
@@ -147,57 +144,89 @@ static int betweenclust(edge_t * e)
     return (ND_clust(agtail(e)) != ND_clust(aghead(e)));
 }
 
-static void do_ordering(graph_t * g, int outflag)
+static void do_ordering_node (graph_t * g, node_t* n, int outflag)
 {
     int i, ne;
-    node_t *n, *u, *v;
+    node_t *u, *v;
     edge_t *e, *f, *fe;
     edge_t **sortlist = TE_list;
 
-    for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
-	if (ND_clust(n))
-	    continue;
+    if (ND_clust(n))
+	return;
+    if (outflag) {
+	for (i = ne = 0; (e = ND_out(n).list[i]); i++)
+	    if (!betweenclust(e))
+		sortlist[ne++] = e;
+    } else {
+	for (i = ne = 0; (e = ND_in(n).list[i]); i++)
+	    if (!betweenclust(e))
+		sortlist[ne++] = e;
+    }
+    if (ne <= 1)
+	return;
+    /* write null terminator at end of list.
+       requires +1 in TE_list alloccation */
+    sortlist[ne] = 0;
+    qsort(sortlist, ne, sizeof(sortlist[0]), (qsort_cmpf) edgeidcmpf);
+    for (ne = 1; (f = sortlist[ne]); ne++) {
+	e = sortlist[ne - 1];
 	if (outflag) {
-	    for (i = ne = 0; (e = ND_out(n).list[i]); i++)
-		if (!betweenclust(e))
-		    sortlist[ne++] = e;
+	    u = aghead(e);
+	    v = aghead(f);
 	} else {
-	    for (i = ne = 0; (e = ND_in(n).list[i]); i++)
-		if (!betweenclust(e))
-		    sortlist[ne++] = e;
+	    u = agtail(e);
+	    v = agtail(f);
 	}
-	if (ne <= 1)
-	    continue;
-	/* write null terminator at end of list.
-	   requires +1 in TE_list alloccation */
-	sortlist[ne] = 0;
-	qsort(sortlist, ne, sizeof(sortlist[0]), (qsort_cmpf) edgeidcmpf);
-	for (ne = 1; (f = sortlist[ne]); ne++) {
-	    e = sortlist[ne - 1];
-	    if (outflag) {
-		u = aghead(e);
-		v = aghead(f);
-	    } else {
-		u = agtail(e);
-		v = agtail(f);
-	    }
-	    if (find_flat_edge(u, v))
-		continue;
-	    fe = new_virtual_edge(u, v, NULL);
-	    ED_edge_type(fe) = FLATORDER;
-	    flat_edge(g, fe);
+	if (find_flat_edge(u, v))
+	    return;
+	fe = new_virtual_edge(u, v, NULL);
+	ED_edge_type(fe) = FLATORDER;
+	flat_edge(g, fe);
+    }
+}
+
+static void do_ordering(graph_t * g, int outflag)
+{
+    /* Order all nodes in graph */
+    node_t *n;
+
+    for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
+	do_ordering_node (g, n, outflag);
+    }
+}
+
+static void do_ordering_for_nodes(graph_t * g)
+{
+    /* Order nodes which have the "ordered" attribute */
+    node_t *n;
+    const char *ordering;
+
+    for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
+	if ((ordering = late_string(n, N_ordering, NULL))) {
+	    if (streq(ordering, "out"))
+		do_ordering_node(g, n, TRUE);
+	    else if (streq(ordering, "in"))
+		do_ordering_node(g, n, FALSE);
+	    else if (ordering[0])
+		agerr(AGERR, "ordering '%s' not recognized for node '%s'.\n", ordering, agnameof(n));
 	}
     }
 }
 
 /* ordered_edges:
  * handle case where graph specifies edge ordering
+ * If the graph does not have an ordering attribute, we then
+ * check for nodes having the attribute.
+ * Note that, in this implementation, the value of G_ordering
+ * dominates the value of N_ordering.
  */
 static void ordered_edges(graph_t * g)
 {
     char *ordering;
 
-    if ((ordering = agget(g, "ordering"))) {
+    if (!G_ordering && !N_ordering)
+	return;
+    if ((ordering = late_string(g, G_ordering, NULL))) {
 	if (streq(ordering, "out"))
 	    do_ordering(g, TRUE);
 	else if (streq(ordering, "in"))
@@ -207,8 +236,8 @@ static void ordered_edges(graph_t * g)
     }
     else
     {
-	/* search meta-graph to find subgraphs that may be ordered */
 #ifndef WITH_CGRAPH
+	/* search meta-graph to find subgraphs that may be ordered */
 	graph_t *mg, *subg;
 	node_t *mm, *mn;
 	edge_t *me;
@@ -218,15 +247,16 @@ static void ordered_edges(graph_t * g)
 	for (me = agfstout(mg, mm); me; me = agnxtout(mg, me)) {
 	    mn = me->head;
 	    subg = agusergraph(mn);
-	    /* clusters are processed by seperate calls to ordered_edges */
 #else /* WITH_CGRAPH */
 	graph_t *subg;
 
 	for (subg = agfstsubg(g); subg; subg = agnxtsubg(subg)) {
 #endif /* WITH_CGRAPH */
+	    /* clusters are processed by separate calls to ordered_edges */
 	    if (!is_cluster(subg))
 		ordered_edges(subg);
 	}
+	if (N_ordering) do_ordering_for_nodes (g);
     }
 }
 
@@ -1154,7 +1184,7 @@ static void flat_reorder(graph_t * g)
 	    for (j = 0; j < ND_flat_in(v).size; j++) {
 		flat_e = ND_flat_in(v).list[j];
 		if ((ED_weight(flat_e) > 0)
-		    && (inside_cluster(g, aghead(flat_e))))
+		    && (inside_cluster(g, agtail(flat_e))))
 		    local_in_cnt++;
 	    }
 	    for (j = 0; j < ND_flat_out(v).size; j++) {
