@@ -1,18 +1,15 @@
-/* $Id: expr.h,v 1.3 2009/01/05 20:12:47 ellson Exp $ $Revision: 1.3 $ */
+/* $Id: expr.h,v 1.9 2011/01/25 16:30:48 ellson Exp $ $Revision: 1.9 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #ifdef __cplusplus
 extern "C" {
@@ -76,9 +73,9 @@ extern "C" {
 /* previously known as EXID, but EXID is also defined by bison in y.tab.h */
 #define EX_ID(n,l,i,t,f)	{{0},(l),(i),(t),0,(f),0,{0},n}
 
-#define DELETE		BREAK	/* exexpr() delete `type'       */
+#define DELETE_T		BREAK	/* exexpr() delete `type'       */
 
-#define INTEGRAL(t)	((t)>=INT&&(t)<=CHAR)
+#define INTEGRAL(t)	((t)>=INTEGER&&(t)<=CHARACTER)
 #define BUILTIN(t)  ((t) > MINTOKEN)
 
 /* function type mechanism
@@ -126,6 +123,7 @@ extern "C" {
 
     typedef int (*Exerror_f) (Expr_t *, Exdisc_t *, int, const char *,
 			      ...);
+    typedef void (*Exexit_f) (Expr_t *, Exdisc_t *, int);
 
     typedef struct {		/* user defined member type       */
 	Sflong_t number;
@@ -221,7 +219,7 @@ extern "C" {
 	/* binary operator function     */
 	char *(*typename) (Expr_t *, int);
 	/* application type names       */
-	int (*stringof) (Expr_t *, Exnode_t *, int);
+	int (*stringof) (Expr_t *, Exnode_t *, int, Exdisc_t *);
 	/* value to string conversion   */
 	 Extype_t(*keyf) (Expr_t *, Extype_t, int, Exdisc_t *);
 	/* dictionary key for external type objects     */
@@ -237,6 +235,8 @@ extern "C" {
 	/* set value function           */
 	int (*matchf) (Expr_t *, Exnode_t *, const char *, Exnode_t *,
 		       const char *, void *, Exdisc_t *);
+	/* exit function           */
+	Exexit_f exitf;
 	int *types;
 	void *user;
     };
@@ -310,6 +310,7 @@ extern "C" {
     extern char *extype(int);
     extern Extype_t exzero(int);
     extern char *exopname(int);
+    extern void exinit(void);
     extern char *extypename(Expr_t * p, int);
     extern int exisAssign(Exnode_t *);
 
