@@ -1,18 +1,15 @@
-/* $Id: tlayout.c,v 1.9 2008/10/23 01:49:26 ellson Exp $ $Revision: 1.9 $ */
+/* $Id: tlayout.c,v 1.13 2011/01/25 16:30:48 ellson Exp $ $Revision: 1.13 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 /* tlayout.c:
  * Written by Emden R. Gansner
@@ -552,7 +549,7 @@ static pointf initPositions(graph_t * g, bport_t * pp)
     if (T_smode == INIT_RANDOM)
 	local_seed = T_seed;
     else {
-#ifdef MSWIN32
+#if defined(MSWIN32) || defined(WIN32)
 	local_seed = time(NULL);
 #else
 	local_seed = getpid() ^ time(NULL);
