@@ -1,18 +1,15 @@
-/* $Id: xlayout.c,v 1.14 2009/06/18 14:36:00 erg Exp $ $Revision: 1.14 $ */
+/* $Id: xlayout.c,v 1.16 2011/01/25 16:30:48 ellson Exp $ $Revision: 1.16 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 /* xlayout.c:
@@ -43,7 +40,7 @@ Increase less between tries
 /* #define ORIG      */
 #define BOX	/* Use bbox to determine overlap, else use circles */
 
-#define DFLT_overlap   "9:portho"    /* default overlap value */
+#define DFLT_overlap   "9:prism"    /* default overlap value */
 
 #define WD2(n) (X_marg.doAdd ? (ND_width(n)/2.0 + X_marg.x): ND_width(n)*X_marg.x/2.0)
 #define HT2(n) (X_marg.doAdd ? (ND_height(n)/2.0 + X_marg.y): ND_height(n)*X_marg.y/2.0)
