@@ -1,18 +1,15 @@
-/* $Id: glcompbutton.c,v 1.19 2009/10/09 17:25:34 erg Exp $Revision: */
+/* $Id: glcompbutton.c,v 1.23 2011/01/25 16:30:48 ellson Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2007 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include "glcompbutton.h"
 #include "glcomplabel.h"
@@ -51,7 +48,7 @@ glCompButton *glCompButtonNew(glCompObj * par, GLfloat x, GLfloat y,
     p->customptr = '\0';
     /*set event functions */
 
-    p->common.functions.draw = glCompButtonDraw;
+    p->common.functions.draw = (glcompdrawfunc_t)glCompButtonDraw;
 
     p->common.functions.click = glCompButtonClick;
     p->common.functions.doubleclick = glCompButtonDoubleClick;
@@ -62,7 +59,7 @@ glCompButton *glCompButtonNew(glCompObj * par, GLfloat x, GLfloat y,
     p->common.functions.mouseup = glCompButtonMouseUp;
 
     /*caption */
-    p->common.font = new_font_from_parent((glCompObj *) p, NULL);
+    p->common.font = glNewFontFromParent ((glCompObj *) p, NULL);
     p->label = glCompLabelNew((glCompObj *) p, 0, 0, caption);
     p->label->common.font->justify.VJustify = glFontVJustifyCenter;
     p->label->common.font->justify.HJustify = glFontHJustifyCenter;
@@ -82,7 +79,7 @@ int glCompButtonAddPngGlyph(glCompButton * b, char *fileName)
     /*image on left for now */
     b->image = glCompImageNew((glCompObj *) b, 0, 0);
 
-    rv = glCompImageLoadPng(b->image, fileName);
+    rv = glCompImageLoadPng(b->image, fileName,1);
     if (rv) {
 	b->image->common.anchor.leftAnchor = 1;
 	b->image->common.anchor.left = 0;
@@ -154,16 +151,19 @@ void glCompButtonClick(glCompObj * o, GLfloat x, GLfloat y,
     glCompObj *obj;
     glCompSet *s = o->common.compset;
     int ind = 0;
-    if (p->groupid > 0) {
+    ((glCompButton *) o)->status=((glCompButton *) o)->refStatus ;
+    if (p->groupid > 0) 
+    {
 	for (; ind < s->objcnt; ind++) {
 	    obj = s->obj[ind];
-	    if (obj->objType == glButtonObj) {
+	    if ((obj->objType == glButtonObj)&&(obj!=o)) {
 		if (((glCompButton *) obj)->groupid == p->groupid)
 		    ((glCompButton *) obj)->status = 0;
 	    }
 	}
 	p->status = 1;
-    } else {
+    }
+    else {
 	if (p->groupid == -1) {
 	    if (p->status == 0)
 		p->status = 1;
@@ -189,6 +189,8 @@ void glCompButtonMouseDown(glCompObj * obj, GLfloat x, GLfloat y,
 {
     /*Put your internal code here */
 
+    
+    ((glCompButton *) obj)->refStatus = ((glCompButton *) obj)->status;
     ((glCompButton *) obj)->status = 1;
     if (((glCompButton *) obj)->common.callbacks.mousedown)
 	((glCompButton *) obj)->common.callbacks.mousedown(obj, x, y, t);
@@ -219,6 +221,7 @@ void glCompButtonMouseUp(glCompObj * obj, GLfloat x, GLfloat y,
 			 glMouseButtonType t)
 {
     /*Put your internal code here */
+
     if (((glCompButton *) obj)->common.callbacks.mouseup)
 	((glCompButton *) obj)->common.callbacks.mouseup(obj, x, y, t);
 }
