@@ -1,18 +1,15 @@
-/* $Id: glcompdefs.h,v 1.16 2009/12/03 19:16:04 arif Exp $Revision: */
+/* $Id: glcompdefs.h,v 1.21 2011/01/25 16:30:48 ellson Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2007 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 #ifndef GLCOMPDEFS_H
 #define GLCOMPDEFS_H
 
@@ -178,7 +175,11 @@ extern "C" {
     typedef struct _glCompPointI {
 	int x, y;
     } glCompPointI;
-
+    typedef struct {
+	int cnt;
+	int hotKey;
+	glCompPoint* pts;
+    }glCompPoly;
 
     typedef struct {
 	GLfloat R;
@@ -186,6 +187,7 @@ extern "C" {
 	GLfloat B;
 	GLfloat A;		//Alpha
 	int tag;
+	int test;
     } glCompColor;
 
 
@@ -268,14 +270,11 @@ extern "C" {
 	glObjType objType;	/*always keep this here for each drawable object */
 	glCompCommon common;
 	glCompTex *texture;
-	char *pngFile;
+	GLfloat width, height;  /* width and height in world coords */
+	/* char *pngFile; */
 	int stretch;
     } glCompImage;
 
-
-
-
-
 /*generic panel*/
     typedef struct _glCompPanel {
 	glObjType objType;	/*always keep this here for each drawable object */
@@ -302,6 +301,7 @@ extern "C" {
 	GLfloat width, height;
 	glCompLabel *label;
 	int status;		//0 not pressed 1 pressed;
+	int refStatus;		//0 not pressed 1 pressed;
 	int groupid;
 	glCompImage *image;	/*glyph */
 	glCompButtonGlyph glyphPos;
