@@ -1,18 +1,15 @@
-/* $Id: glcomplabel.c,v 1.12 2009/12/03 19:16:04 arif Exp $Revision: */
+/* $Id: glcomplabel.c,v 1.15 2011/01/25 16:30:48 ellson Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2007 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include "glcomplabel.h"
 #include "glcompfont.h"
@@ -32,8 +29,8 @@ glCompLabel *glCompLabelNew(glCompObj * par, GLfloat x, GLfloat y,
     //typedef enum {glPanelObj,glbuttonObj,glLabelObj,glImageObj}glObjType;
 
     p->text = strdup(text);
-    p->common.font = new_font_from_parent((glCompObj*)p, text);
-    p->common.functions.draw = glCompLabelDraw;
+    p->common.font = glNewFontFromParent ((glCompObj*)p, text);
+    p->common.functions.draw = (glcompdrawfunc_t)glCompLabelDraw;
 
     return p;
 }
@@ -64,9 +61,12 @@ static void update_font(glCompLabel * p,char* text,char* desc,int fs)
 {
 
     glCompFont* temp=p->common.font;
-    p->common.font=new_font(p->common.compset,text,&p->common.color,temp->type,desc,fs,temp->is2D);
+    if (strlen(text) >512)
+	return ;
+
+    p->common.font=glNewFont (p->common.compset,text,&p->common.color,temp->type,desc,fs,temp->is2D);
     if(temp)
-	delete_font(temp);
+	glDeleteFont(temp);
     if(p->text)
 	free(p->text);
     p->text = strdup(text);
