@@ -1,18 +1,15 @@
-/* $Id: glcompset.h,v 1.20 2009/10/09 17:25:34 erg Exp $Revision: */
+/* $Id: glcompset.h,v 1.22 2011/01/25 16:30:48 ellson Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2007 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 /*Open GL basic component set
   includes glPanel,glCompButton,glCompCustomButton,clCompLabel,glCompStyle
@@ -43,7 +40,6 @@ extern "C" {
     extern int glcompsetGetGroupId(glCompSet * s);
     extern void glCompDrawBegin(void);
     extern void glCompDrawEnd(void);
-    extern void glCompDeleteTexture(glCompTex * t);
     extern void glCompSetAddObj(glCompSet * s, glCompObj * obj);
     glCompObj *glCompGetObjByMouse(glCompSet * s, glCompMouse * m,
 				   int onlyClickable);
