@@ -1,28 +1,26 @@
-/* $Id: glcomptexture.c,v 1.10 2009/12/03 19:16:04 arif Exp $Revision: */
+/* $Id: glcomptexture.c,v 1.13 2011/01/25 16:30:48 ellson Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2007 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include "glcomptexture.h"
 #include "glpangofont.h"
 
 #include "memory.h"
 
+#if 0
 void glCompSetRemoveTexLabel(glCompSet * s, glCompFont * t)
 {
 }
-
+#endif
 
 static glCompTex *glCompSetAddNewTexture(glCompSet * s, int width,
 					 int height, unsigned char *data,
@@ -60,7 +58,7 @@ static glCompTex *glCompSetAddNewTexture(glCompSet * s, int width,
 	}
     }
     if (is2D && !Er) {
-	t->data = N_NEW(4 * width * height, char);
+	t->data = N_NEW(4 * width * height, unsigned char);
 	offset = 4;		//RGBA  mod,TO DO implement other modes 
 	/*data upside down because of pango gl coord system */
 	for (ind = 0; ind < height; ind++) {
@@ -78,10 +76,13 @@ static glCompTex *glCompSetAddNewTexture(glCompSet * s, int width,
     t->userCount = 1;
     t->width = (GLfloat) width;
     t->height = (GLfloat) height;
-    s->textureCount++;
-    s->textures =
+    if(s)
+    {
+	s->textureCount++;
+	s->textures =
 	realloc(s->textures, s->textureCount * sizeof(glCompTex *));
-    s->textures[s->textureCount - 1] = t;
+	s->textures[s->textureCount - 1] = t;
+    }
     return t;
 
 
@@ -133,7 +134,7 @@ glCompTex *glCompSetAddNewTexLabel(glCompSet * s, char *def, int fs,
     }
 
 
-    data = create_pango_texture(def, fs, text, surface, &width, &height);
+    data = glCompCreatePangoTexture(def, fs, text, surface, &width, &height);
     if (!data)			/*pango error , */
 	Er = 1;
     t = glCompSetAddNewTexture(s, width, height, data, is2D,fs);
