@@ -1,18 +1,15 @@
-/* $Id: glutils.c,v 1.30 2009/12/03 19:16:04 arif Exp $Revision: */
+/* $Id: glutils.c,v 1.35 2011/01/25 16:30:49 ellson Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2007 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include "glutils.h"
 #include "stdlib.h"
@@ -244,7 +241,8 @@ int GetFixedOGLPoslocal(int x, int y, GLfloat * X, GLfloat * Y,
     return 1;
 
 }
-void linear_interplotate(float x1, float y1, float x2, float y2, float x3,
+#if 0
+void linear_interpolate(float x1, float y1, float x2, float y2, float x3,
 			 float *y3)
 {
 
@@ -254,7 +252,6 @@ void linear_interplotate(float x1, float y1, float x2, float y2, float x3,
     *y3 = a * x3 + b;
 }
 
-#if 0
 int glreversecamera(ViewInfo * view)
 {
 
@@ -279,15 +276,17 @@ int glreversecamera(ViewInfo * view)
 
 
 
-static point3f add(point3f p, point3f q)
+#if 0
+static glCompPoint add(glCompPoint p, glCompPoint q)
 {
     p.x += q.x;
     p.y += q.y;
     p.z += q.z;
     return p;
 }
+#endif
 
-static point3f sub(point3f p, point3f q)
+static glCompPoint sub(glCompPoint p, glCompPoint q)
 {
     p.x -= q.x;
     p.y -= q.y;
@@ -295,27 +294,29 @@ static point3f sub(point3f p, point3f q)
     return p;
 }
 
-static double dot(point3f p, point3f q)
+static double dot(glCompPoint p, glCompPoint q)
 {
     return (p.x * q.x + p.y * q.y + p.z * q.z);
 }
 
-static double len(point3f p)
+static double len(glCompPoint p)
 {
     return sqrt(dot(p, p));
 }
 
-static point3f scale(double d, point3f p)
+#if 0
+static glCompPoint scale(double d, glCompPoint p)
 {
     p.x *= (float) d;
     p.y *= (float) d;
     p.z *= (float) d;
     return p;
 }
+#endif
 
-static point3f blend(point3f p, point3f q, float m)
+static glCompPoint blend(glCompPoint p, glCompPoint q, float m)
 {
-    point3f r;
+    glCompPoint r;
 
     r.x = p.x + m * (q.x - p.x);
     r.y = p.y + m * (q.y - p.y);
@@ -323,19 +324,20 @@ static point3f blend(point3f p, point3f q, float m)
     return r;
 }
 
-static point3f normalize(point3f p)
+static double dist(glCompPoint p, glCompPoint q)
+{
+    return (len(sub(p, q)));
+}
+
+#if 0
+static glCompPoint normalize(glCompPoint p)
 {
     double d = len(p);
 
     return scale(1 / d, p);
 }
 
-static double dist(point3f p, point3f q)
-{
-    return (len(sub(p, q)));
-}
-
-static point3f intersect(line l, plane J)
+static glCompPoint intersect(line l, plane J)
 {
     double t = -(J.d + dot(l.u, J.N)) / dot(l.v, J.N);
     return (add(l.u, scale(t, l.v)));
@@ -345,11 +347,11 @@ static point3f intersect(line l, plane J)
  * Given a line l determined by two points a and b, and a 3rd point p,
  * return the distance between the point and the line
  */
-double point_to_line_dist(point3f p, point3f a, point3f b)
+double point_to_line_dist(glCompPoint p, glCompPoint a, glCompPoint b)
 {
     line l;
     plane J;
-    point3f q;
+    glCompPoint q;
 
     l.u = a;
     l.v = normalize(sub(b, a));
@@ -361,6 +363,7 @@ double point_to_line_dist(point3f p, point3f a, point3f b)
 
     return (dist(p, q));
 }
+#endif
 
 
 /*
@@ -369,12 +372,12 @@ double point_to_line_dist(point3f p, point3f a, point3f b)
  * If the perpendicular from p to the line a-b is outside of the segment,
  * return the distance to the closer of a or b.
  */
-double point_to_lineseg_dist(point3f p, point3f a, point3f b)
+double point_to_lineseg_dist(glCompPoint p, glCompPoint a, glCompPoint b)
 {
     float U;
-    point3f q;
-    point3f ba = sub(b, a);
-    point3f pa = sub(p, a);
+    glCompPoint q;
+    glCompPoint ba = sub(b, a);
+    glCompPoint pa = sub(p, a);
 
     U = (float) (dot(pa, ba) / dot(ba, ba));
 
@@ -389,12 +392,12 @@ double point_to_lineseg_dist(point3f p, point3f a, point3f b)
 
 }
 
+#if 0
 /*
 	Calculates the parameters of a plane via given 3 points on it
 */
 
-
-void make_plane(point3f a, point3f b, point3f c, plane * P)
+void make_plane(glCompPoint a, glCompPoint b, glCompPoint c, plane * P)
 {
     P->N.x = a.y * (b.z - c.z) + b.y * (c.z - a.z) + c.y * (a.z - b.z);	//+
     P->N.y = a.z * (b.x - c.x) + b.z * (c.x - a.x) + c.z * (a.x - b.x);	//+
@@ -403,6 +406,7 @@ void make_plane(point3f a, point3f b, point3f c, plane * P)
 	(a.x * (b.y * c.z - c.y * b.z) + b.x * (c.y * a.z - a.y * c.z) +
 	 c.x * (a.y * b.z - b.y * a.z)) * -1;
 }
+#endif
 void replacestr(char *source, char **target)
 {
 
@@ -411,6 +415,7 @@ void replacestr(char *source, char **target)
     *target = strdup(source);
 }
 
+#if 0
 /*
 	move a point on the great circle of it (spherical)
 
@@ -418,7 +423,7 @@ void replacestr(char *source, char **target)
 
 #define G_PI    3.1415926535897932384626433832795028841971693993751
 #define DEG2RAD  G_PI/180
-int rot_spherex(plane J, float tet, point3f P, point3f * P2)
+int rot_spherex(plane J, float tet, glCompPoint P, glCompPoint * P2)
 {
     if (tet > 0) {
 	tet = 5;
@@ -454,6 +459,7 @@ int rot_spherex(plane J, float tet, point3f P, point3f * P2)
 	return 0;
 
 }
+#endif
 
 void glCompSelectionBox(glCompSet * s)
 {
@@ -506,6 +512,12 @@ void glCompCalcWidget(glCompCommon * parent, glCompCommon * child,
     GLfloat borderWidth;
     ref->height = child->height;
     ref->width = child->width;
+    if(!parent)
+    {
+	child->refPos.x = child->pos.x;
+	child->refPos.y = child->pos.y;
+	return;
+    }
     if (parent->borderType == glBorderNone)
 	borderWidth = 0;
     else
@@ -682,8 +694,8 @@ void copy_glcomp_color(glCompColor * source, glCompColor * target)
 
 }
 
-
-double area2(glCompPoint * p1p, glCompPoint * p2p, glCompPoint * p3p) 
+#if 0
+static double area2(glCompPoint * p1p, glCompPoint * p2p, glCompPoint * p3p) 
 {
     double d;
 
@@ -694,7 +706,7 @@ double area2(glCompPoint * p1p, glCompPoint * p2p, glCompPoint * p3p)
 
 
 enum {ISCCW, ISON, ISCW};  /* counterclockwise; collinear; clockwise */ 
-int sideOf (glCompPoint * p1p, glCompPoint * p2p, glCompPoint * p3p) {
+static int sideOf (glCompPoint * p1p, glCompPoint * p2p, glCompPoint * p3p) {
     double d = area2 (p1p,p2p,p3p);
     if (d < 0) return ISCCW;
     else if (d > 0) return ISCW;
@@ -705,49 +717,27 @@ int lines_intersect (glCompPoint* a, glCompPoint* b, glCompPoint* c, glCompPoint
 {
   return ((sideOf(a,b,c) != sideOf(a,b,d)) && (sideOf(c,d,a) != sideOf(c,d,b))); 
 }
-
-
-
-
-
-#ifdef DEBUG
-void main(void)
-{
-    point3f LineStart, LineEnd, Point;
-    float Distance;
-
-
-    LineStart.x = 50.0f;
-    LineStart.y = 80.0f;
-    LineStart.z = 300.0f;
-    LineEnd.x = 50.0f;
-    LineEnd.y = -800.0f;
-    LineEnd.z = 1000.0f;
-    Point.x = 20.0f;
-    Point.y = 1000.0f;
-    Point.z = 400.0f;
-
-    if (DistancePointLine(&Point, &LineStart, &LineEnd, &Distance))
-	printf("closest point falls within line segment, distance = %f\n",
-	       Distance);
-    else
-	printf("closest point does not fall within line segment\n");
-
-
-    LineStart.x = 0.0f;
-    LineStart.y = 0.0f;
-    LineStart.z = 50.0f;
-    LineEnd.x = 0.0f;
-    LineEnd.y = 0.0f;
-    LineEnd.z = -50.0f;
-    Point.x = 10.0f;
-    Point.y = 50.0f;
-    Point.z = 10.0f;
-
-    if (DistancePointLine(&Point, &LineStart, &LineEnd, &Distance))
-	printf("closest point falls within line segment, distance = %f\n",
-	       Distance);
-    else
-	printf("closest point does not fall within line segment\n");
-}
 #endif
+GLfloat distBetweenPts(glCompPoint A,glCompPoint B,float R)
+{
+    GLfloat rv=0;	
+    rv=(A.x-B.x)*(A.x-B.x) + (A.y-B.y)*(A.y-B.y) +(A.z-B.z)*(A.z-B.z);
+    rv=sqrt(rv);
+    if (rv <=R)
+	return 0;
+    return rv;
+}
+
+int is_point_in_rectangle(float X, float Y, float RX, float RY, float RW,float RH)
+{
+    if ((X >= RX) && (X <= (RX + RW)) && (Y >= RY) && (Y <= (RY + RH)))
+	return 1;
+    else
+	return 0;
+}
+
+
+
+
+
+
