@@ -1,18 +1,15 @@
-/* $Id: agxbuf.c,v 1.5 2009/06/03 01:10:53 ellson Exp $ $Revision: 1.5 $ */
+/* $Id: agxbuf.c,v 1.8 2011/02/26 20:02:10 erg Exp $ $Revision: 1.8 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 #include <stdio.h>
@@ -57,7 +54,7 @@ int agxbmore(agxbuf * xb, unsigned int ssz)
 	nsize = size + ssz;
     cnt = xb->ptr - xb->buf;
     if (xb->dyna) {
-	nbuf = realloc(xb->buf, nsize);
+	nbuf = (unsigned char*)realloc(xb->buf, nsize);
     } else {
 	nbuf = N_GNEW(nsize, unsigned char);
 	memcpy(nbuf, xb->buf, cnt);
@@ -72,7 +69,7 @@ int agxbmore(agxbuf * xb, unsigned int ssz)
 /* agxbput_n:
  * Append string s of length n onto xb
  */
-int agxbput_n(agxbuf * xb, char *s, unsigned int ssz)
+int agxbput_n(agxbuf * xb, const char *s, unsigned int ssz)
 {
     if (xb->ptr + ssz > xb->eptr)
 	agxbmore(xb, ssz);
@@ -84,7 +81,7 @@ int agxbput_n(agxbuf * xb, char *s, unsigned int ssz)
 /* agxbput:
  * Append string s into xb
  */
-int agxbput(agxbuf * xb, char *s)
+int agxbput(agxbuf * xb, const char *s)
 {
     unsigned int ssz = strlen(s);
 
