@@ -1,18 +1,15 @@
-/* $Id: graphio.c,v 1.24 2009/12/05 22:34:03 erg Exp $ $Revision: 1.24 $ */
+/* $Id: graphio.c,v 1.27 2011/02/01 20:30:32 ellson Exp $ $Revision: 1.27 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 #include "libgraph.h"
@@ -129,13 +126,13 @@ _agstrcanon (char* arg, char* buf)
 	*p++ = (char) uc;
 	uc = *(unsigned char *) s++;
 	cnt++;
-        if (uc && backslash_pending && !((_is_number_char(p[-1]) || isalpha(p[-1])) && (_is_number_char(uc) || isalpha(uc)))) {
+        if (uc && backslash_pending && !((_is_number_char(p[-1]) || isalpha(p[-1]) || (p[-1] == '\\')) && (_is_number_char(uc) || isalpha(uc)))) {
             *p++ = '\\';
             *p++ = '\n';
             has_special = TRUE;
             backslash_pending = FALSE;
         } else if (uc && cnt % SMALLBUF == 0) {
-            if (!((_is_number_char(p[-1]) || isalpha(p[-1])) && (_is_number_char(uc) || isalpha(uc)))) {
+            if (!((_is_number_char(p[-1]) || isalpha(p[-1]) || (p[-1] == '\\')) && (_is_number_char(uc) || isalpha(uc)))) {
 	        *p++ = '\\';
     	        *p++ = '\n';
 	        has_special = TRUE;
@@ -229,9 +226,9 @@ static char *getoutputbuffer(char *str)
     req = MAX(2 * strlen(str) + 2, BUFSIZ);
     if (req > len) {
 	if (rv)
-	    rv = realloc(rv, req);
+	    rv = (char*)realloc(rv, req);
 	else
-	    rv = malloc(req);
+	    rv = (char*)malloc(req);
 	len = req;
     }
     return rv;
