@@ -1,18 +1,15 @@
- /* $Id: gvc.c,v 1.63 2009/07/14 13:18:07 ellson Exp $ $Revision: 1.63 $ */
+ /* $Id: gvc.c,v 1.67 2011/03/09 16:24:19 arif Exp $ $Revision: 1.67 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -26,6 +23,20 @@
 #include "gvconfig.h"
 #include "gvio.h"
 
+#ifdef WIN32 /*dependencies*/
+#ifdef WITH_CGRAPH
+    #pragma comment( lib, "cgraph.lib" )
+#else
+    #pragma comment( lib, "graph.lib" )
+#endif
+    #pragma comment( lib, "cdt.lib" )
+    #pragma comment( lib, "ltdl.lib" )
+    #pragma comment( lib, "xml2.lib" )
+    #pragma comment( lib, "expat.lib" )
+    #pragma comment( lib, "zdll.lib" )
+#endif
+
+
 GVC_t *gvContext(void)
 {
     GVC_t *gvc;
@@ -119,11 +130,11 @@ int gvRender(GVC_t *gvc, graph_t *g, const char *format, FILE *out)
     job->output_file = out;
     if (out == NULL)
 	job->flags |= OUTPUT_NOT_REQUIRED;
-    gvRenderJobs(gvc, g);
+    rc = gvRenderJobs(gvc, g);
     gvrender_end_job(job);
     gvjobs_delete(gvc);
 
-    return 0;
+    return rc;
 }
 
 /* Render layout in a specified format to an open FILE */
@@ -149,12 +160,12 @@ int gvRenderFilename(GVC_t *gvc, graph_t *g, const char *format, const char *fil
 	return -1;
     }
     gvjobs_output_filename(gvc, filename);
-    gvRenderJobs(gvc, g);
+    rc = gvRenderJobs(gvc, g);
     gvrender_end_job(job);
     gvdevice_finalize(job);
     gvjobs_delete(gvc);
 
-    return 0;
+    return rc;
 }
 
 /* Render layout in a specified format to an external context */
@@ -180,16 +191,15 @@ int gvRenderContext(GVC_t *gvc, graph_t *g, const char *format, void *context)
 		return -1;
     }
 	
-	job->context = context;
-	job->external_context = TRUE;
+    job->context = context;
+    job->external_context = TRUE;
 	
-    gvRenderJobs(gvc, g);
+    rc = gvRenderJobs(gvc, g);
     gvrender_end_job(job);
     gvdevice_finalize(job);
-    
-	gvjobs_delete(gvc);
+    gvjobs_delete(gvc);
 	
-    return 0;
+    return rc;
 }
 
 /* Render layout in a specified format to a malloc'ed string */
@@ -227,14 +237,16 @@ int gvRenderData(GVC_t *gvc, graph_t *g, const char *format, char **result, unsi
     job->output_data_allocated = OUTPUT_DATA_INITIAL_ALLOCATION;
     job->output_data_position = 0;
 
-    gvRenderJobs(gvc, g);
+    rc = gvRenderJobs(gvc, g);
     gvrender_end_job(job);
 
-    *result = job->output_data;
-    *length = job->output_data_position;
+    if (rc == 0) {
+	*result = job->output_data;
+	*length = job->output_data_position;
+    }
     gvjobs_delete(gvc);
 
-    return 0;
+    return rc;
 }
 
 
