@@ -1,18 +1,15 @@
-/* $Id: gvc.h,v 1.66 2009/10/04 20:15:42 ellson Exp $ $Revision: 1.66 $ */
+/* $Id: gvc.h,v 1.70 2011/02/26 19:56:38 erg Exp $ $Revision: 1.70 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #ifndef			GVC_H
 #define			GVC_H
@@ -72,8 +69,8 @@ extern void attach_attrs(graph_t *g);
 /* Parse an html string */
 #ifndef WITH_CGRAPH
 extern char *agstrdup_html(char *s);
-#endif
 extern int aghtmlstr(char *s);
+#endif
 
 /* Render layout in a specified format to an open FILE */
 extern int gvRender(GVC_t *gvc, graph_t *g, const char *format, FILE *out);
@@ -97,10 +94,27 @@ extern int gvFreeLayout(GVC_t *gvc, graph_t *g);
 extern void gvFinalize(GVC_t *gvc);
 extern int gvFreeContext(GVC_t *gvc);
 
+/* Return list of plugins of type kind.
+ * kind would normally be "render" "layout" "textlayout" "device" "loadimage"
+ * The size of the list is stored in sz.
+ * The caller is responsible for freeing the storage. This involves
+ * freeing each item, then the list.
+ * Returns NULL on error, or if there are no plugins.
+ * In the former case, sz is unchanged; in the latter, sz = 0.
+ *
+ * At present, the str argument is unused, but may be used to modify
+ * the search as in gvplugin_list above.
+ */
+extern char** gvPluginList (GVC_t *gvc, char* kind, int* sz, char*);
+
 /** Add a library from your user application
  * @param gvc Graphviz context to add library to
  * @param lib library to add
  */
+
+
+
+
 extern void gvAddLibrary(GVC_t *gvc, gvplugin_library_t *lib);
 
 #undef extern
