@@ -1,18 +1,15 @@
-/* $Id: gvconfig.c,v 1.111 2009/07/08 15:14:20 ellson Exp $ $Revision: 1.111 $ */
+/* $Id: gvconfig.c,v 1.113 2011/01/25 16:30:49 ellson Exp $ $Revision: 1.113 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -267,6 +264,7 @@ char * gvconfig_libdir(GVC_t * gvc)
 {
     static char line[BSZ];
     static char *libdir;
+    static boolean dirShown = 0; 
     char *path, *tmp;
     FILE *f;
 
@@ -323,9 +321,10 @@ char * gvconfig_libdir(GVC_t * gvc)
 	    }
 #endif
 	}
-	if (gvc->common.verbose > 1) 
-	    fprintf (stderr, "libdir = \"%s\"\n",
-		(libdir ? libdir : "<null>"));
+    }
+    if (gvc->common.verbose && !dirShown) {
+	fprintf (stderr, "libdir = \"%s\"\n", (libdir ? libdir : "<null>"));
+	dirShown = 1;
     }
     return libdir;
 }
