@@ -1,18 +1,15 @@
-/* $Id: actions.c,v 1.7 2009/11/22 19:59:20 erg Exp $ $Revision: 1.7 $ */
+/* $Id: actions.c,v 1.11 2011/01/25 16:30:49 ellson Exp $ $Revision: 1.11 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 /*
@@ -137,7 +134,7 @@ void nodeInduce(Agraph_t * selected)
     }
 }
 
-/* copyAttr;
+/* copyAttr:
  * Copy attributes from src to tgt. Overrides currently
  * defined values.
  * FIX: we should probably use the default value of the source
@@ -359,6 +356,22 @@ static void cloneGraph(Agraph_t * tgt, Agraph_t * src)
     free (data);
 }
 
+/* cloneG:
+ */
+Agraph_t *cloneG(Agraph_t * g, char* name)
+{
+    Agraph_t* ng;
+
+    if (!name || (*name == '\0'))
+	name = agnameof (g);
+    ng = openG(name, g->desc);
+    if (ng) {
+	copyAttr((Agobj_t*)g, (Agobj_t*)ng);
+	cloneGraph(ng, g);
+    }
+    return ng;
+}
+
 /* clone:
  * Create new object of type AGTYPE(obj) with all of its
  * attributes and substructure.
@@ -394,9 +407,10 @@ Agobj_t *clone(Agraph_t * g, Agobj_t * obj)
 	    nobj = (Agobj_t *) openSubg(g, name);
 	else
 	    nobj = (Agobj_t *) openG(name, ((Agraph_t *) obj)->desc);
-	if (nobj)
+	if (nobj) {
 	    copyAttr(obj, nobj);
-	cloneGraph((Agraph_t *) nobj, (Agraph_t *) obj);
+	    cloneGraph((Agraph_t *) nobj, (Agraph_t *) obj);
+	}
 	break;
     case AGINEDGE:
     case AGOUTEDGE:
@@ -776,6 +790,14 @@ char *toUpper(Expr_t * pgm, char *s, Sfio_t* tmps)
     return exstring(pgm, sfstruse(tmps));
 }
 
+/* toHtml:
+ * Create a string marked as HTML
+ */
+char *toHtml(Agraph_t* g, char *arg)
+{
+    return agstrdup_html (g, arg);
+}
+
 /* canon:
  * Canonicalize a string for printing.
  */
@@ -789,6 +811,7 @@ char *canon(Expr_t * pgm, char *arg)
 
     return p;
 }
+
 #include <stdlib.h>
 #ifdef WIN32
 #include "compat.h"
@@ -1290,10 +1313,10 @@ char *colorx (Expr_t* ex, char* incolor, char* fmt, Sfio_t* fp)
 
     switch (type) {
     case HSVA_DOUBLE :
-	sfprintf (fp, ".03f .03f .03f", 
+	sfprintf (fp, "%.03f %.03f %.03f", 
 	    color.u.HSVA[0], color.u.HSVA[1], color.u.HSVA[2]);
 	if (alpha)
-	    sfprintf (fp, " .03f", color.u.HSVA[3]);
+	    sfprintf (fp, " %.03f", color.u.HSVA[3]);
 	break;
     case RGBA_BYTE :
 	sfprintf (fp, "#%02x%02x%02x", 
