@@ -1,18 +1,15 @@
-/* $Id: compile.c,v 1.8 2009/11/22 19:10:33 erg Exp $ $Revision: 1.8 $ */
+/* $Id: compile.c,v 1.17 2011/01/25 16:30:49 ellson Exp $ $Revision: 1.17 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 /*
@@ -65,7 +62,7 @@ static int iofread(void *chan, char *buf, int bufsize)
     return read(sffileno((Sfio_t *) chan), buf, bufsize);
 }
 
-static int ioputstr(void *chan, char *str)
+static int ioputstr(void *chan, const char *str)
 {
     return sfputr((Sfio_t *) chan, str, -1);
 }
@@ -100,7 +97,7 @@ static char *nameOf(Expr_t * ex, Agobj_t * obj, Sfio_t* tmps)
 	break;
     default:			/* edge */
 	e = (Agedge_t *) obj;
-	key = agnameof(AGMKOUT(obj));
+	key = agnameof(AGMKOUT(e));
 	sfputr(tmps, agnameof(AGTAIL(e)), -1);
 	if (agisdirected(agraphof(e)))
 	    sfputr(tmps, "->", -1);
@@ -632,6 +629,7 @@ getval(Expr_t * pgm, Exnode_t * node, Exid_t * sym, Exref_t * ref,
     Agnode_t *hp;
     Agedge_t *ep;
     char* name;
+    gvprbinding* bp;
 
     assert(sym->lex != CONSTANT);
     if (elt == EX_CALL) {
@@ -647,6 +645,9 @@ getval(Expr_t * pgm, Exnode_t * node, Exid_t * sym, Exref_t * ref,
 	    if (gp) {
 		gp = openSubg(gp, args[1].string);
 		v.integer = PTR2INT(gp);
+	    } else {
+		error(ERROR_WARNING, "NULL graph passed to subg()");
+		v.integer = 0;
 	    }
 	    break;
 	case F_issubg:
@@ -1088,6 +1089,16 @@ getval(Expr_t * pgm, Exnode_t * node, Exid_t * sym, Exref_t * ref,
 	    } else
 		v.integer = PTR2INT(clone(gp, objp));
 	    break;
+	case F_cloneG:
+	    gp = INT2PTR(Agraph_t *, args[0].integer);
+	    if (gp) {
+		gp = cloneG(gp, args[1].string);
+		v.integer = PTR2INT(gp);
+	    } else {
+		error(ERROR_WARNING, "NULL graph passed to cloneG()");
+		v.integer = 0;
+	    }
+	    break;
 	case F_copya:
 	    objp = INT2PTR(Agobj_t *, args[0].integer);
 	    objp1 = INT2PTR(Agobj_t *, args[1].integer);
@@ -1178,6 +1189,9 @@ getval(Expr_t * pgm, Exnode_t * node, Exid_t * sym, Exref_t * ref,
 	    } else if (objp == (Agobj_t *) (state->target)) {
 		error(ERROR_WARNING, "cannot delete target graph $T");
 		v.integer = 1;
+	    } else if (objp == state->curobj) {
+		if (!(v.integer = deleteObj(gp, objp)))
+		    state->curobj = NULL;
 	    } else
 		v.integer = deleteObj(gp, objp);
 	    break;
@@ -1362,12 +1376,32 @@ getval(Expr_t * pgm, Exnode_t * node, Exid_t * sym, Exref_t * ref,
 	case F_canon:
 	    v.string = canon(pgm, args[0].string);
 	    break;
+	case F_html:
+	    gp = INT2PTR(Agraph_t *, args[0].integer);
+	    if (gp) {
+		v.string = toHtml(gp, args[1].string);
+	    } else {
+		error(ERROR_WARNING, "NULL graph passed to html()");
+		v.string = 0;
+	    }
+	    break;
 	case F_tolower:
 	    v.string = toLower(pgm, args[0].string, state->tmp);
 	    break;
 	case F_colorx:
 	    v.string = colorx(pgm, args[0].string, args[1].string, state->tmp);
 	    break;
+	case F_strcmp:
+	    if (args[0].string) {
+		if (args[1].string)
+		    v.integer = strcmp(args[0].string,args[1].string);
+		else
+		    v.integer = -1; 
+	    } else if (args[1].string)
+		v.integer = 1; 
+	    else
+		v.integer = 0; 
+	    break;
 	case F_toupper:
 	    v.string = toUpper(pgm, args[0].string, state->tmp);
 	    break;
@@ -1395,6 +1429,12 @@ getval(Expr_t * pgm, Exnode_t * node, Exid_t * sym, Exref_t * ref,
 	case F_match:
 	    v.integer = match(args[0].string, args[1].string);
 	    break;
+	case F_call:
+	    if ((bp = findBinding (state, args[0].string)))
+		v.integer = (bp->fn)(args[1].string);
+	    else
+		v.integer = -1;
+	    break;
 	default:
 	    exerror("unknown function call: %s", sym->name);
 	}
@@ -1514,7 +1554,7 @@ setval(Expr_t * pgm, Exnode_t * x, Exid_t * sym, Exref_t * ref,
 		state->tvt = (trav_type) iv;
 	    else
 		error(1, "unexpected value %d assigned to %s : ignored",
-		      iv, typeName(pgm, V_travtype));
+		      iv, typeName(pgm, T_tvtyp));
 	    break;
 	case V_travroot:
 	    np = INT2PTR(Agnode_t *, v.integer);
@@ -2239,6 +2279,16 @@ static case_stmt *mkStmts(Expr_t * prog, char *src, case_info * sp,
 	    cs[i].action = compile(prog, src, sp->action, sp->astart,
 				   sfstruse(tmps), 0, INTEGER);
 	    if (getErrorErrors()) break;
+	    /* If no error but no compiled action, the input action must
+	     * have been essentially an empty block, which should be
+	     * considered different from a missing block. So, compile a
+	     * trivial block.
+	     */
+	    if (!cs[i].action) {
+		sfprintf(tmps, "%s__a%d", lbl, i);
+		cs[i].action = compile(prog, src, "1", sp->astart,
+				   sfstruse(tmps), 0, INTEGER);
+	    }
 	}
 	sp = sp->next;
     }
@@ -2251,6 +2301,7 @@ static case_stmt *mkStmts(Expr_t * prog, char *src, case_info * sp,
 static int mkBlock(comp_block* bp, Expr_t * prog, char *src, parse_block *inp, Sfio_t* tmps, int i)
 {
     int rv = 0;
+    char label[BUFSIZ];
 
     codePhase = 1;
     if (inp->begg_stmt) {
@@ -2269,8 +2320,9 @@ static int mkBlock(comp_block* bp, Expr_t * prog, char *src, parse_block *inp, S
 	symbols[0].type = T_node;
 	tchk[V_this][1] = Y(V);
 	bp->n_nstmts = inp->n_nstmts;
+	sprintf (label, "_nd%d", i);
 	bp->node_stmts = mkStmts(prog, src, inp->node_stmts,
-				inp->n_nstmts, "_nd", tmps);
+				inp->n_nstmts, label, tmps);
 	if (getErrorErrors())
 	    goto finishBlk;
 	bp->walks |= WALKSG;
@@ -2281,8 +2333,9 @@ static int mkBlock(comp_block* bp, Expr_t * prog, char *src, parse_block *inp, S
 	symbols[0].type = T_edge;
 	tchk[V_this][1] = Y(E);
 	bp->n_estmts = inp->n_estmts;
+	sprintf (label, "_eg%d", i);
 	bp->edge_stmts = mkStmts(prog, src, inp->edge_stmts,
-				inp->n_estmts, "_eg", tmps);
+				inp->n_estmts, label, tmps);
 	if (getErrorErrors())
 	    goto finishBlk;
 	bp->walks |= WALKSG;
