@@ -1,18 +1,15 @@
-/* $Id: gvpr.c,v 1.9 2009/11/05 19:33:49 ellson Exp $ $Revision: 1.9 $ */
+/* $Id: gvpr.c,v 1.15 2011/01/25 16:30:49 ellson Exp $ $Revision: 1.15 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 /*
@@ -314,7 +311,7 @@ doFlags(char* arg, int argi, int argc, char** argv, options* opts)
 	    else return -1;
 	    break;
 	case 'o':
-	    if (!(optarg = getOptarg(c, &arg, &argi, argc, argv)) && !(opts->outFile = openOut(optarg)))
+	    if (!(optarg = getOptarg(c, &arg, &argi, argc, argv)) || !(opts->outFile = openOut(optarg)))
 		return -1;
 	    break;
 	case 'q':
@@ -424,7 +421,7 @@ static options* scanArgs(int argc, char **argv, gvpropts* uopts)
     return opts;
 }
 
-static void evalEdge(Gpr_t * state, Expr_t* prog, comp_block * xprog, Agedge_t * e)
+static Agobj_t* evalEdge(Gpr_t * state, Expr_t* prog, comp_block * xprog, Agedge_t * e)
 {
     int i;
     case_stmt *cs;
@@ -444,9 +441,10 @@ static void evalEdge(Gpr_t * state, Expr_t* prog, comp_block * xprog, Agedge_t *
 		agsubedge(state->target, e, TRUE);
 	}
     }
+    return state->curobj;
 }
 
-static void evalNode(Gpr_t * state, Expr_t* prog, comp_block * xprog, Agnode_t * n)
+static Agobj_t* evalNode(Gpr_t * state, Expr_t* prog, comp_block * xprog, Agnode_t * n)
 {
     int i;
     case_stmt *cs;
@@ -466,6 +464,7 @@ static void evalNode(Gpr_t * state, Expr_t* prog, comp_block * xprog, Agnode_t *
 		agsubnode(state->target, n, TRUE);
 	}
     }
+    return (state->curobj);
 }
 
 typedef struct {
@@ -517,6 +516,7 @@ static void travBFS(Gpr_t * state, Expr_t* prog, comp_block * xprog)
     ndata *nd;
     Agnode_t *n;
     Agedge_t *cure;
+    Agedge_t *nxte;
     Agraph_t *g = state->curgraph;
 
     q = mkQueue();
@@ -533,13 +533,13 @@ static void travBFS(Gpr_t * state, Expr_t* prog, comp_block * xprog)
 	    MARK(nd);
 	    POP(nd);
 	    state->tvedge = nd->ine;
-	    evalNode(state, prog, xprog, n);
-	    for (cure = agfstedge(g, n); cure;
-		 cure = agnxtedge(g, cure, n)) {
+	    if (!evalNode(state, prog, xprog, n)) continue;
+	    for (cure = agfstedge(g, n); cure; cure = nxte) {
+		nxte = agnxtedge(g, cure, n);
 		nd = nData(cure->node);
 		if (MARKED(nd))
 		    continue;
-		evalEdge(state, prog, xprog, cure);
+		if (!evalEdge(state, prog, xprog, cure)) continue;
 		if (!ONSTACK(nd)) {
 		    push(q, cure->node);
 		    PUSH(nd,cure);
@@ -617,7 +617,7 @@ static void travDFS(Gpr_t * state, Expr_t* prog, comp_block * xprog, trav_fns *
 		POP(nd);
 		cure = entry;
 		entry = (Agedge_t *) pull(stk);
-		if (entry == &seed)
+		if (entry == &(seed.out))
 		    state->tvedge = 0;
 		else
 		    state->tvedge = entry;
@@ -635,8 +635,10 @@ static void travDFS(Gpr_t * state, Expr_t* prog, comp_block * xprog, trav_fns *
 static void travNodes(Gpr_t * state, Expr_t* prog, comp_block * xprog)
 {
     Agnode_t *n;
+    Agnode_t *next;
     Agraph_t *g = state->curgraph;
-    for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
+    for (n = agfstnode(g); n; n = next) {
+	next =  agnxtnode(g, n);
 	evalNode(state, prog, xprog, n);
     }
 }
@@ -644,10 +646,14 @@ static void travNodes(Gpr_t * state, Expr_t* prog, comp_block * xprog)
 static void travEdges(Gpr_t * state, Expr_t* prog, comp_block * xprog)
 {
     Agnode_t *n;
+    Agnode_t *next;
     Agedge_t *e;
+    Agedge_t *nexte;
     Agraph_t *g = state->curgraph;
-    for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
-	for (e = agfstout(g, n); e; e = agnxtout(g, e)) {
+    for (n = agfstnode(g); n; n = next) {
+	next = agnxtnode(g, n);
+	for (e = agfstout(g, n); e; e = nexte) {
+	    nexte = agnxtout(g, e);
 	    evalEdge(state, prog, xprog, e);
 	}
     }
@@ -656,21 +662,41 @@ static void travEdges(Gpr_t * state, Expr_t* prog, comp_block * xprog)
 static void travFlat(Gpr_t * state, Expr_t* prog, comp_block * xprog)
 {
     Agnode_t *n;
+    Agnode_t *next;
     Agedge_t *e;
+    Agedge_t *nexte;
     Agraph_t *g = state->curgraph;
-    for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
-	evalNode(state, prog, xprog, n);
+    for (n = agfstnode(g); n; n = next) {
+	next =  agnxtnode(g, n);
+	if (!evalNode(state, prog, xprog, n)) continue;
 	if (xprog->n_estmts > 0) {
-	    for (e = agfstout(g, n); e; e = agnxtout(g, e)) {
+	    for (e = agfstout(g, n); e; e = nexte) {
+		nexte = agnxtout(g, e);
 		evalEdge(state, prog, xprog, e);
 	    }
 	}
     }
 }
 
-/* traverse:
+/* doCleanup:
+ * Reset node traversal data
  */
-static void traverse(Gpr_t * state, Expr_t* prog, comp_block * bp)
+static void doCleanup (Agraph_t* g)
+{
+    Agnode_t *n;
+    ndata *nd;
+
+    for (n = agfstnode(g); n; n =  agnxtnode(g, n)) {
+	nd = nData(n);
+	nd->ine = NULL;
+	nd->iu.integer = 0;
+    }
+}
+
+/* traverse:
+ * return 1 if traversal requires cleanup
+ */
+static int traverse(Gpr_t * state, Expr_t* prog, comp_block * bp, int cleanup)
 {
     char *target;
 
@@ -681,6 +707,12 @@ static void traverse(Gpr_t * state, Expr_t* prog, comp_block * bp)
 	} else
 	    target = state->tgtname;
 	state->name_used++;
+	/* make sure target subgraph does not exist */
+	while (agsubg (state->curgraph, target, 0)) {
+	    state->name_used++;
+	    sfprintf(state->tmp, "%s%d", state->tgtname, state->name_used);
+	    target = sfstruse(state->tmp);
+	}
 	state->target = openSubg(state->curgraph, target);
     }
     if (!state->outgraph)
@@ -691,43 +723,63 @@ static void traverse(Gpr_t * state, Expr_t* prog, comp_block * bp)
 	travFlat(state, prog, bp);
 	break;
     case TV_bfs:
+	if (cleanup) doCleanup (state->curgraph);
 	travBFS(state, prog, bp);
+	cleanup = 1;
 	break;
     case TV_dfs:
+	if (cleanup) doCleanup (state->curgraph);
 	DFSfns.visit = PRE_VISIT;
 	travDFS(state, prog, bp, &DFSfns);
+	cleanup = 1;
 	break;
     case TV_fwd:
+	if (cleanup) doCleanup (state->curgraph);
 	FWDfns.visit = PRE_VISIT;
 	travDFS(state, prog, bp, &FWDfns);
+	cleanup = 1;
 	break;
     case TV_rev:
+	if (cleanup) doCleanup (state->curgraph);
 	REVfns.visit = PRE_VISIT;
 	travDFS(state, prog, bp, &REVfns);
+	cleanup = 1;
 	break;
     case TV_postdfs:
+	if (cleanup) doCleanup (state->curgraph);
 	DFSfns.visit = POST_VISIT;
 	travDFS(state, prog, bp, &DFSfns);
+	cleanup = 1;
 	break;
     case TV_postfwd:
+	if (cleanup) doCleanup (state->curgraph);
 	FWDfns.visit = POST_VISIT;
 	travDFS(state, prog, bp, &FWDfns);
+	cleanup = 1;
 	break;
     case TV_postrev:
+	if (cleanup) doCleanup (state->curgraph);
 	REVfns.visit = POST_VISIT | PRE_VISIT;
 	travDFS(state, prog, bp, &REVfns);
+	cleanup = 1;
 	break;
     case TV_prepostdfs:
+	if (cleanup) doCleanup (state->curgraph);
 	DFSfns.visit = POST_VISIT | PRE_VISIT;
 	travDFS(state, prog, bp, &DFSfns);
+	cleanup = 1;
 	break;
     case TV_prepostfwd:
+	if (cleanup) doCleanup (state->curgraph);
 	FWDfns.visit = POST_VISIT | PRE_VISIT;
 	travDFS(state, prog, bp, &FWDfns);
+	cleanup = 1;
 	break;
     case TV_prepostrev:
+	if (cleanup) doCleanup (state->curgraph);
 	REVfns.visit = POST_VISIT;
 	travDFS(state, prog, bp, &REVfns);
+	cleanup = 1;
 	break;
     case TV_ne:
 	travNodes(state, prog, bp);
@@ -738,6 +790,7 @@ static void traverse(Gpr_t * state, Expr_t* prog, comp_block * bp)
 	travNodes(state, prog, bp);
 	break;
     }
+    return cleanup;
 }
 
 /* addOutputGraph:
@@ -851,7 +904,7 @@ int gvpr (int argc, char *argv[], gvpropts * uopts)
     gpr_info info;
     int rv = 0;
     options* opts = 0;
-    int i, incoreGraphs;
+    int cleanup, i, incoreGraphs;
 
     setErrorErrors (0);
     ingDisc.dflt = sfstdin;
@@ -888,6 +941,8 @@ int gvpr (int argc, char *argv[], gvpropts * uopts)
 	rv = 1;
 	goto finish;
     }
+    if (uopts->bindings)
+	addBindings (state, uopts->bindings);
     xprog = compileProg(prog, state, opts->compflags);
     if (!xprog) {
 	rv = 1;
@@ -926,6 +981,7 @@ int gvpr (int argc, char *argv[], gvpropts * uopts)
 	
 	while ((state->curgraph = nextGraph(ing))) {
 	    state->infname = fileName(ing);
+	    cleanup = 0;
 
 	    for (i = 0; i < xprog->n_blocks; i++) {
 		comp_block* bp = xprog->blocks + i;
@@ -939,8 +995,9 @@ int gvpr (int argc, char *argv[], gvpropts * uopts)
 		    exeval(xprog->prog, bp->begg_stmt, state);
 
 		/* walk graph */
-		if (walksGraph(bp))
-		    traverse(state, xprog->prog, bp);
+		if (walksGraph(bp)) {
+		    cleanup = traverse(state, xprog->prog, bp, cleanup);
+		}
 	    }
 
 	    /* end graph */
