@@ -1,18 +1,15 @@
-/* $Id: delaunay.c,v 1.17 2009/09/04 02:40:11 erg Exp $ $Revision: 1.17 $ */
+/* $Id: delaunay.c,v 1.22 2011/03/03 16:54:28 erg Exp $ $Revision: 1.22 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -139,9 +136,18 @@ destroy (GtsVertex* v)
 }
 
 /* tri:
+ * Main entry point to using GTS for triangulation.
+ * Input is npt points with x and y coordinates stored either separately
+ * in x[] and y[] (sepArr != 0) or consecutively in x[] (sepArr == 0).
+ * Optionally, the input can include nsegs line segments, whose endpoint
+ * indices are supplied in segs[2*i] and segs[2*i+1] yielding a constrained
+ * triangulation.
+ *
+ * The return value is the corresponding gts surface, which can be queries for
+ * the triangles and line segments composing the triangulation.
  */
 static GtsSurface*
-tri(double *x, double *y, int npt, int *segs, int nsegs)
+tri(double *x, double *y, int npt, int *segs, int nsegs, int sepArr)
 {
     int i;
     GtsSurface *surface;
@@ -153,11 +159,21 @@ tri(double *x, double *y, int npt, int *segs, int nsegs)
     GtsVertexClass *vcl = (GtsVertexClass *) g_vertex_class();
     GtsEdgeClass *ecl = GTS_EDGE_CLASS (gts_constraint_class ());
 
-    for (i = 0; i < npt; i++) {
-	GVertex *p = (GVertex *) gts_vertex_new(vcl, x[i], y[i], 0);
-	p->idx = i;
-	vertices[i] = p;
+    if (sepArr) {
+	for (i = 0; i < npt; i++) {
+	    GVertex *p = (GVertex *) gts_vertex_new(vcl, x[i], y[i], 0);
+	    p->idx = i;
+	    vertices[i] = p;
+	}
     }
+    else {
+	for (i = 0; i < npt; i++) {
+	    GVertex *p = (GVertex *) gts_vertex_new(vcl, x[2*i], x[2*i+1], 0);
+	    p->idx = i;
+	    vertices[i] = p;
+	}
+    }
+
     /* N.B. Edges need to be created here, presumably before the
      * the vertices are added to the face. In particular, they cannot
      * be added created and added vi gts_delaunay_add_constraint() below.
@@ -253,7 +269,7 @@ static void add_edge (GtsSegment * e, v_data* delaunay)
 v_data *delaunay_triangulation(double *x, double *y, int n)
 {
     v_data *delaunay;
-    GtsSurface* s = tri(x, y, n, NULL, 0);
+    GtsSurface* s = tri(x, y, n, NULL, 0, 1);
     int i, nedges;
     int* edges;
     estats stats;
@@ -332,7 +348,7 @@ vcmp (int* a, int* b)
  */
 int *delaunay_tri(double *x, double *y, int n, int* pnedges)
 {
-    GtsSurface* s = tri(x, y, n, NULL, 0);
+    GtsSurface* s = tri(x, y, n, NULL, 0, 1);
     int nedges;
     int* edges;
     estats stats;
@@ -427,10 +443,29 @@ static void addFace (GFace* f, fstate* es)
 	neigh[i] = -1;
 }
 
+static void addTri (GFace* f, fstate* es)
+{
+    int myid = f->idx;
+    int* ip = es->faces + 3*myid;
+    GtsVertex *v1, *v2, *v3;
+
+    gts_triangle_vertices (&f->v.triangle, &v1, &v2, &v3);
+    *ip++ = ((GVertex*)(v1))->idx;
+    *ip++ = ((GVertex*)(v2))->idx;
+    *ip++ = ((GVertex*)(v3))->idx;
+}
+
+/* mkSurface:
+ * Given n points whose coordinates are in x[] and y[], and nsegs line
+ * segments whose end point indices are given in segs, return a surface
+ * corresponding the constrained Delaunay triangulation.
+ * The surface records the line segments, the triangles, and the neighboring
+ * triangles.
+ */
 surface_t* 
 mkSurface (double *x, double *y, int n, int* segs, int nsegs)
 {
-    GtsSurface* s = tri(x, y, n, segs, nsegs);
+    GtsSurface* s = tri(x, y, n, segs, nsegs, 1);
     estats stats;
     estate state;
     fstate statf;
@@ -472,6 +507,35 @@ mkSurface (double *x, double *y, int n, int* segs, int nsegs)
     return sf;
 }
 
+/* get_triangles:
+ * Given n points whose coordinates are stored as (x[2*i],x[2*i+1]),
+ * compute a Delaunay triangulation of the points.
+ * The number of triangles in the triangulation is returned in tris.
+ * The return value t is an array of 3*(*tris) integers,
+ * with triangle i having points whose indices are t[3*i], t[3*i+1] and t[3*i+2].
+ */
+int* 
+get_triangles (double *x, int n, int* tris)
+{
+    GtsSurface* s;
+    int nfaces = 0;
+    fstate statf;
+
+    if (n <= 2) return NULL;
+
+    s = tri(x, NULL, n, NULL, 0, 0);
+    if (!s) return NULL;
+
+    gts_surface_foreach_face (s, (GtsFunc) cntFace, &nfaces);
+    statf.faces = N_GNEW(3 * nfaces, int);
+    gts_surface_foreach_face (s, (GtsFunc) addTri, &statf);
+
+    gts_object_destroy (GTS_OBJECT (s));
+
+    *tris = nfaces;
+    return statf.faces;
+}
+
 void 
 freeSurface (surface_t* s)
 {
@@ -483,6 +547,76 @@ freeSurface (surface_t* s)
 #define TRILIBRARY
 #include "triangle.c"
 #include "assert.h"
+#include "general.h"
+
+int*
+get_triangles (double *x, int n, int* tris)
+{
+    struct triangulateio in, mid, vorout;
+    int i;
+
+    if (n <= 2) return NULL;
+
+    in.numberofpoints = n;
+    in.numberofpointattributes = 0;
+    in.pointlist = (REAL *) N_GNEW(in.numberofpoints * 2, REAL);
+
+    for (i = 0; i < n; i++){
+	in.pointlist[i*2] = x[i*2];
+	in.pointlist[i*2 + 1] = x[i*2 + 1];
+    }
+    in.pointattributelist = NULL;
+    in.pointmarkerlist = NULL;
+    in.numberofsegments = 0;
+    in.numberofholes = 0;
+    in.numberofregions = 0;
+    in.regionlist = NULL;
+    mid.pointlist = (REAL *) NULL;            /* Not needed if -N switch used. */
+    mid.pointattributelist = (REAL *) NULL;
+    mid.pointmarkerlist = (int *) NULL; /* Not needed if -N or -B switch used. */
+    mid.trianglelist = (int *) NULL;          /* Not needed if -E switch used. */
+    mid.triangleattributelist = (REAL *) NULL;
+    mid.neighborlist = (int *) NULL;         /* Needed only if -n switch used. */
+    mid.segmentlist = (int *) NULL;
+    mid.segmentmarkerlist = (int *) NULL;
+    mid.edgelist = (int *) NULL;             /* Needed only if -e switch used. */
+    mid.edgemarkerlist = (int *) NULL;   /* Needed if -e used and -B not used. */
+    vorout.pointlist = (REAL *) NULL;        /* Needed only if -v switch used. */
+    vorout.pointattributelist = (REAL *) NULL;
+    vorout.edgelist = (int *) NULL;          /* Needed only if -v switch used. */
+    vorout.normlist = (REAL *) NULL;         /* Needed only if -v switch used. */
+
+    /* Triangulate the points.  Switches are chosen to read and write a  */
+    /*   PSLG (p), preserve the convex hull (c), number everything from  */
+    /*   zero (z), assign a regional attribute to each element (A), and  */
+    /*   produce an edge list (e), a Voronoi diagram (v), and a triangle */
+    /*   neighbor list (n).                                              */
+
+    triangulate("Qenv", &in, &mid, &vorout);
+    assert (mid.numberofcorners == 3);
+
+    *tris = mid.numberoftriangles;
+    
+    FREE(in.pointlist);
+    FREE(in.pointattributelist);
+    FREE(in.pointmarkerlist);
+    FREE(in.regionlist);
+    FREE(mid.pointlist);
+    FREE(mid.pointattributelist);
+    FREE(mid.pointmarkerlist);
+    FREE(mid.triangleattributelist);
+    FREE(mid.neighborlist);
+    FREE(mid.segmentlist);
+    FREE(mid.segmentmarkerlist);
+    FREE(mid.edgelist);
+    FREE(mid.edgemarkerlist);
+    FREE(vorout.pointlist);
+    FREE(vorout.pointattributelist);
+    FREE(vorout.edgelist);
+    FREE(vorout.normlist);
+
+    return mid.trianglelist;
+}
 
 // maybe it should be replaced by RNG - relative neigborhood graph, or by GG - gabriel graph
 int* 
@@ -555,7 +689,6 @@ delaunay_tri (double *x, double *y, int n, int* nedges)
     free (out.segmentmarkerlist);
     free (out.holelist);
     free (out.regionlist);
-    free (out.edgelist);
     free (out.edgemarkerlist);
     free (out.normlist);
     return out.edgelist;
@@ -613,6 +746,11 @@ freeSurface (surface_t* s)
 }
 #else
 static char* err = "Graphviz built without any triangulation library\n";
+int* get_triangles (double *x, int n, int* tris)
+{
+    agerr(AGERR, "get_triangles: %s\n", err);
+    return 0;
+}
 v_data *delaunay_triangulation(double *x, double *y, int n)
 {
     agerr(AGERR, "delaunay_triangulation: %s\n", err);
