@@ -1,18 +1,15 @@
-/* $Id: multispline.c,v 1.13 2008/10/23 04:05:44 ellson Exp $Revision: */
+/* $Id: multispline.c,v 1.20 2011/01/25 16:30:49 ellson Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include <multispline.h>
 #include <delaunay.h>
@@ -281,6 +278,10 @@ raySegIntersect(pointf v, pointf w, pointf a, pointf b, pointf * p)
 	return 0;
 }
 
+#ifdef DEBUG
+#include <psdbg.c>
+#endif
+
 /* triPoint:
  * Given the triangle vertex v, and point w so that v->w points
  * into the polygon, return where the ray v->w intersects the
@@ -299,14 +300,15 @@ triPoint(tripoly_t * trip, int vx, pointf v, pointf w, pointf * ip)
 	    return 0;
     }
 #ifdef DEBUG
-    fprintf(stderr, "%%Failure in triPoint\n");
-    fprintf(stderr, "0 0 1 setrgbcolor\n");
-    drawLine(v, w);
+    psInit();
+    psComment ("Failure in triPoint");
+    psColor("0 0 1");
+    psSeg (v, w);
     for (tp = trip->triMap[vx]; tp; tp = tp->nxttri) {
-	drawTri(v, trip->poly.ps[tp->v.i], trip->poly.ps[tp->v.j]);
+	psTri(v, trip->poly.ps[tp->v.i], trip->poly.ps[tp->v.j]);
     }
+    psOut(stderr);
 #endif
-
     return 1;
 }
 
@@ -335,7 +337,7 @@ static int ctrlPtIdx(pointf v, Ppoly_t * polys)
  * The first point will aways be v.
  * The rest are positioned equally spaced with maximum spacing SEP.
  * In addition, they all lie within the polygon trip->poly.
- * Parameter s gives the index after which a vertex likes on the
+ * Parameter s gives the index after which a vertex lies on the
  * opposite side. This is necessary to get the "curvature" of the
  * path correct.
  */
@@ -357,11 +359,13 @@ static pointf *mkCtrlPts(int s, int mult, pointf prev, pointf v,
     cosTheta = cos(theta);
     w.x = v.x + 100 * cosTheta;
     w.y = v.y + 100 * sinTheta;
-    if ((idx > s) && (wind(prev, v, w) != 1)) {
-	sinTheta *= -1;
-	cosTheta *= -1;
-	w.x = v.x + 100 * cosTheta;
-	w.y = v.y + 100 * sinTheta;
+    if (idx > s) {
+	if (wind(prev, v, w) != 1) {
+	    sinTheta *= -1;
+	    cosTheta *= -1;
+	    w.x = v.x + 100 * cosTheta;
+	    w.y = v.y + 100 * sinTheta;
+	}
     } else if (wind(prev, v, w) != -1) {
 	sinTheta *= -1;
 	cosTheta *= -1;
@@ -606,7 +610,7 @@ static tgraph *mkTriGraph(surface_t * sf, int maxv, pointf * pts)
 	edgei += degT(sf->neigh + 3 * i) + 1;
     }
     /* initialize variable nodes */
-    np++;
+    np = g->nodes + i;
     np->ne = 0;
     np->edges = edgei;
     np++;
@@ -642,7 +646,19 @@ void freeRouter(router_t * rtr)
 }
 
 #ifdef DEBUG
-#include <psdbg.c>
+static void
+prTriPoly (tripoly_t *poly, int si, int ei)
+{
+    FILE* fp = fopen ("dumppoly","w");
+    
+    psInit();
+    psPoly (&(poly->poly));
+    psPoint (poly->poly.ps[si]);
+    psPoint (poly->poly.ps[ei]);
+    psOut(fp);
+    fclose(fp);
+}
+
 static void
 prTriGraph (router_t* rtr, int n)
 {
@@ -662,6 +678,7 @@ prTriGraph (router_t* rtr, int n)
         psTxt (buf, nodes[i].ctr);
     }
     for (i=rtr->tn;i < n; i++) {
+	sprintf (buf, "%d", i);
         psTxt (buf, nodes[i].ctr);
     }
     psColor ("1 0 0");
@@ -757,7 +774,7 @@ router_t *mkRouter(Ppoly_t** obsp, int npoly)
  * if necessary, and adding edge labels
  */
 static void
-finishEdge (edge_t* e, Ppoly_t spl, int flip, pointf p, pointf q)
+finishEdge (graph_t* g, edge_t* e, Ppoly_t spl, int flip, pointf p, pointf q)
 {
     int j;
     pointf *spline = N_GNEW(spl.pn, pointf);
@@ -782,7 +799,7 @@ finishEdge (edge_t* e, Ppoly_t spl, int flip, pointf p, pointf q)
     clip_and_install(e, aghead(e), spline, spl.pn, &sinfo);
     free(spline);
 
-    addEdgeLabels(e, p1, q1);
+    addEdgeLabels(g, e, p1, q1);
 }
 
 #define EQPT(p,q) (((p).x==(q).x)&&((p).y==(q).y))
@@ -838,7 +855,7 @@ tweakPath (Ppoly_t poly, int s, int t, Ppolyline_t pl)
  * Return 0 on success.
  */
 static int 
-genroute(tripoly_t * trip, int s, int t, edge_t * e, int doPolyline)
+genroute(graph_t* g, tripoly_t * trip, int s, int t, edge_t * e, int doPolyline)
 {
     pointf eps[2];
     Pvector_t evs[2];
@@ -864,7 +881,7 @@ genroute(tripoly_t * trip, int s, int t, edge_t * e, int doPolyline)
     evs[0].x = evs[0].y = 0;
     evs[1].x = evs[1].y = 0;
 
-    if (mult == 1) {
+    if ((mult == 1) || Concentrate) {
 	poly = trip->poly;
 	for (j = 0; j < poly.pn; j++) {
 	    medges[j].a = poly.ps[j];
@@ -872,7 +889,7 @@ genroute(tripoly_t * trip, int s, int t, edge_t * e, int doPolyline)
 	}
 	tweakPath (poly, s, t, pl);
 	Proutespline(medges, poly.pn, pl, evs, &spl);
-	finishEdge (e, spl, aghead(e) != head, eps[0], eps[1]);
+	finishEdge (g, e, spl, aghead(e) != head, eps[0], eps[1]);
 	free(medges);
 
 	return 0;
@@ -915,7 +932,7 @@ genroute(tripoly_t * trip, int s, int t, edge_t * e, int doPolyline)
 	    tweakPath (poly, 0, pl.pn-1, mmpl);
 	    Proutespline(medges, poly.pn, mmpl, evs, &spl);
 	}
-	finishEdge (e, spl, aghead(e) != head, eps[0], eps[1]);
+	finishEdge (g, e, spl, aghead(e) != head, eps[0], eps[1]);
 
 	e = ED_to_virt(e);
     }
@@ -1296,7 +1313,7 @@ triPath(tgraph * g, int n, int v0, int v1, PQ * pq)
  * so avoid in neato spline code.
  * Return 0 on success.
  */
-int makeMultiSpline(edge_t* e, router_t * rtr, int doPolyline)
+int makeMultiSpline(graph_t* g,  edge_t* e, router_t * rtr, int doPolyline)
 {
     Ppolyline_t line = ED_path(e);
     node_t *t = agtail(e);
@@ -1335,10 +1352,11 @@ int makeMultiSpline(edge_t* e, router_t * rtr, int doPolyline)
 
 	/* Use path of triangles to generate guiding polygon */
     poly = mkPoly(rtr, sp, h_id, t_id, h_p, t_p, &idx);
+
     free(sp);
 
 	/* Generate multiple splines using polygon */
-    ret = genroute(poly, 0, idx, e, doPolyline);
+    ret = genroute(g, poly, 0, idx, e, doPolyline);
     freeTripoly (poly);
 
     resetGraph(rtr->tg, rtr->tn, ecnt);
