@@ -1,4 +1,4 @@
-/* $Id: quad_prog_vpsc.c,v 1.9 2009/06/03 01:10:54 ellson Exp $ $Revision: 1.9 $ */
+/* $Id: quad_prog_vpsc.c,v 1.10 2010/11/01 18:49:35 erg Exp $ $Revision: 1.10 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**
@@ -113,7 +113,10 @@ constrained_majorization_vpsc(CMajEnvVPSC * e, float *b, float *place,
 	    }
 	    denominator -= r * g[i];
 	}
-	alpha = numerator / denominator;
+	if (denominator != 0)
+	    alpha = numerator / denominator;
+	else
+	    alpha = 1.0;
 	for (i = 0; i < n; i++) {
 	    place[i] -= alpha * g[i];
 	}
