@@ -1,18 +1,15 @@
-/* $Id: stress.c,v 1.13 2009/06/03 01:10:54 ellson Exp $ $Revision: 1.13 $ */
+/* $Id: stress.c,v 1.16 2011/01/25 16:30:49 ellson Exp $ $Revision: 1.16 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 #include "neato.h"
@@ -1551,6 +1548,9 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
 #ifdef ALTERNATIVE_STRESS_CALC
     double mat_stress;
 #endif
+#ifdef NONCORE
+    FILE* fp = NULL;
+#endif
 
 	/*************************************************
 	** Computation of full, dense, unrestricted k-D ** 
@@ -1704,6 +1704,7 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
 	fp = fopen(FILENAME, "wb");
 	fwrite(lap2, sizeof(float), lap_length, fp);
 	fclose(fp);
+	fp = NULL;
     }
 #endif
 
@@ -1837,9 +1838,11 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
 	/* Invariant: old_stress > 0. In theory, old_stress >= new_stress
 	 * but we use fabs in case of numerical error.
 	 */
-	converged =
-	    (((fabs(old_stress - new_stress) / old_stress) < Epsilon)
-	     || (new_stress < Epsilon));
+	{
+	    double diff = old_stress - new_stress;
+	    double change = ABS(diff);
+	    converged = (((change / old_stress) < Epsilon) || (new_stress < Epsilon));
+	}
 	old_stress = new_stress;
 
 	for (k = 0; k < dim; k++) {
@@ -1884,6 +1887,11 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
 #endif /* WITH_CGRAPH */
 	}
     }
+#ifdef NONCORE
+    if (fp)
+	fclose (fp);
+#endif
+
     free(coords[0]);
     free(coords);
 
