@@ -1,24 +1,23 @@
-/* $Id: maze.c,v 1.6 2009/06/03 01:10:54 ellson Exp $Revision: */
+/* $Id: maze.c,v 1.11 2011/01/25 16:30:49 ellson Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#define DEBUG
+
 #include <stddef.h>
 #include <maze.h>
 #include <partition.h>
@@ -145,8 +144,14 @@ static Dtdisc_t hdictDisc = {
 #define HORZ(g,e) ((g->nodes + e->v1)->isVert)
 #define BIG 16384
 #define CHANSZ(w) (((w)-3)/2)
+#define IS_SMALL(v) (CHANSZ(v) < 2)
 /* #define CHANSZ(w) (w) */
 
+/* updateWt:
+ * At present, we use a step function. When a bound is reached, the weight
+ * becomes huge. We might consider bumping up the weight more gradually, the
+ * thinner the channel, the faster the weight rises.
+ */
 static void
 updateWt (cell* cp, sedge* ep, int sz)
 {
@@ -178,7 +183,7 @@ updateWts (sgraph* g, cell* cp, sedge* ep)
 	e = cp->edges[i];
 	if (!BEND(g,e)) break;
 	updateWt (cp, e, minsz);
-    }
+}
 
     for (; i < cp->nedges; i++) {
 	e = cp->edges[i];
@@ -186,6 +191,64 @@ updateWts (sgraph* g, cell* cp, sedge* ep)
     }
 }
 
+/* markSmall:
+ * cp corresponds to a real node. If it is small, its associated cells should
+ * be marked as usable.
+ */
+static void
+markSmall (cell* cp, sgraph* g)
+{
+    int i;
+    snode* onp;
+    cell* ocp;
+
+    if (IS_SMALL(cp->bb.UR.y-cp->bb.LL.y)) {
+	for (i = 0; i < cp->nsides; i++) {
+	    onp = cp->sides[i];
+	    if (!onp->isVert) continue;
+	    if (onp->cells[0] == cp) {  /* onp on the right of cp */
+		ocp = onp->cells[1];
+		ocp->flags |= MZ_SMALLV;
+		while ((onp = ocp->sides[M_RIGHT]) && !IsNode(onp->cells[1])) {
+		    ocp = onp->cells[1];
+		    ocp->flags |= MZ_SMALLV;
+		}
+	    }
+	    else {                      /* onp on the left of cp */
+		ocp = onp->cells[0];
+		ocp->flags |= MZ_SMALLV;
+		while ((onp = ocp->sides[M_LEFT]) && !IsNode(onp->cells[0])) {
+		    ocp = onp->cells[0];
+		    ocp->flags |= MZ_SMALLV;
+		}
+	    }
+	}
+    }
+
+    if (IS_SMALL(cp->bb.UR.x-cp->bb.LL.x)) {
+	for (i = 0; i < cp->nsides; i++) {
+	    onp = cp->sides[i];
+	    if (onp->isVert) continue;
+	    if (onp->cells[0] == cp) {  /* onp on the top of cp */
+		ocp = onp->cells[1];
+		ocp->flags |= MZ_SMALLH;
+		while ((onp = ocp->sides[M_TOP]) && !IsNode(onp->cells[1])) {
+		    ocp = onp->cells[1];
+		    ocp->flags |= MZ_SMALLH;
+		}
+	    }
+	    else {                      /* onp on the bottom of cp */
+		ocp = onp->cells[0];
+		ocp->flags |= MZ_SMALLH;
+		while ((onp = ocp->sides[M_BOTTOM]) && !IsNode(onp->cells[0])) {
+		    ocp = onp->cells[0];
+		    ocp->flags |= MZ_SMALLH;
+		}
+	    }
+	}
+    }
+}
+
 static void
 createSEdges (cell* cp, sgraph* g)
 {
@@ -194,11 +257,14 @@ createSEdges (cell* cp, sgraph* g)
     double vwt = delta*(bb.UR.y-bb.LL.y);
     double wt = (hwt + vwt)/2.0 + mu;
     
-    if (CHANSZ(bb.UR.y-bb.LL.y) < 2) {
+    /* We automatically make small channels have high cost to guide routes to
+     * more spacious channels.
+     */
+    if (IS_SMALL(bb.UR.y-bb.LL.y) && !IsSmallV(cp)) {
 	hwt = BIG;
 	wt = BIG;
     }
-    if (CHANSZ(bb.UR.x-bb.LL.x) < 2) {
+    if (IS_SMALL(bb.UR.x-bb.LL.x) && !IsSmallH(cp)) {
 	vwt = BIG;
 	wt = BIG;
     }
@@ -235,6 +301,22 @@ findSVert (sgraph* g, Dt_t* cdt, pointf p, snodeitem* ditems, boolean isVert)
     return n->np;
 }
 
+static void
+chkSgraph (sgraph* g)
+{
+  int i;
+  snode* np;
+
+  for (i = 0; i < g->nnodes; i++) {
+    np = g->nodes+i;
+    if (!np->cells[0]) fprintf (stderr, "failed at node %d[0]\n", i); 
+    assert (np->cells[0]);
+    if (!np->cells[1]) fprintf (stderr, "failed at node %d[1]\n", i); 
+    assert (np->cells[1]);
+  }
+    
+}
+
 /* mkMazeGraph:
  */
 static sgraph*
@@ -296,9 +378,11 @@ mkMazeGraph (maze* mp, boxf bb)
     for (i = 0; i < mp->ngcells; i++) {
 	cell* cp = mp->gcells+i;
         pointf pt; 
+	snodeitem* np;
+
 	cp->sides = sides+nsides;
         pt = cp->bb.LL;
-	snodeitem* np = dtmatch (hdict, &pt);
+	np = dtmatch (hdict, &pt);
 	for (; np && np->p.x < cp->bb.UR.x; np = dtnext (hdict, np)) {
 	    cp->sides[cp->nsides++] = np->np;
 	    np->np->cells[1] = cp;
@@ -326,6 +410,14 @@ mkMazeGraph (maze* mp, boxf bb)
     }
     RALLOC (nsides, sides, snode*);
 
+    /* Mark cells that are small because of a small node, not because of the close
+     * alignment of two rectangles.
+     */
+    for (i = 0; i < mp->ngcells; i++) {
+	cell* cp = mp->gcells+i;
+	markSmall (cp, g);
+    }
+
     /* Set index of two dummy nodes used for real nodes */
     g->nodes[g->nnodes].index = g->nnodes;
     g->nodes[g->nnodes+1].index = g->nnodes+1;
@@ -348,6 +440,7 @@ mkMazeGraph (maze* mp, boxf bb)
     dtclose (hdict);
     free (ditems);
 
+chkSgraph (g);
     /* save core graph state */
     gsave(g);
     return g;
@@ -356,7 +449,7 @@ mkMazeGraph (maze* mp, boxf bb)
 /* mkMaze:
  */
 maze*
-mkMaze (graph_t* g)
+mkMaze (graph_t* g, int doLbls)
 {
     node_t* n;
     maze* mp = NEW(maze);
@@ -373,7 +466,9 @@ mkMaze (graph_t* g)
     BB.UR.x = BB.UR.y = -MAXDOUBLE;
     for (n = agfstnode (g); n; n = agnxtnode(g,n)) {
         w2 = ND_xsize(n)/2.0;
+	if (w2 < 1) w2 = 1;
         h2 = ND_ysize(n)/2.0;
+	if (h2 < 1) h2 = 1;
         bb.LL.x = ND_coord(n).x - w2;
         bb.UR.x = ND_coord(n).x + w2;
         bb.LL.y = ND_coord(n).y - h2;
@@ -388,6 +483,9 @@ mkMaze (graph_t* g)
 	cp++;
     }
 
+    if (doLbls) {
+    }
+
     BB.LL.x -= MARGIN;
     BB.LL.y -= MARGIN;
     BB.UR.x += MARGIN;
@@ -395,7 +493,7 @@ mkMaze (graph_t* g)
     rects = partition (mp->gcells, mp->ngcells, &nrect, BB);
 
 #ifdef DEBUG
-    psdump (mp->gcells, mp->ngcells, BB, rects, nrect);
+    if (odb_flags & ODB_MAZE) psdump (mp->gcells, mp->ngcells, BB, rects, nrect);
 #endif
     mp->cells = N_NEW(nrect, cell);
     mp->ncells = nrect;
