@@ -1,27 +1,23 @@
-/* $Id: ortho.c,v 1.9 2009/07/10 21:21:14 erg Exp $Revision: */
+/* $Id: ortho.c,v 1.17 2011/01/28 16:24:29 erg Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 /* TODO:
  * In dot, prefer bottom or top routing
  * In general, prefer closest side to closest side routing.
- * Fix arrowheads
- * Ports/compass points
  * Edge labels
- * Loops
+ * Ports/compass points
+ * ordering attribute
  * Weights on edges in nodes
  * Edge concentrators?
  */
@@ -30,6 +26,7 @@
 #include "config.h"
 #endif
 
+#define DEBUG
 #include <stddef.h>
 #include <maze.h>
 #include "fPQ.h"
@@ -38,10 +35,15 @@
 #include "globals.h"
 #include "render.h"
 #include "pointset.h"
+typedef struct {
+    int d;
+    Agedge_t* e;
+} epair_t;
 
 #ifdef DEBUG
 static void emitSearchGraph (FILE* fp, sgraph* sg);
-static void emitGraph (FILE* fp, maze* mp, Agraph_t* g, route* route_list);
+static void emitGraph (FILE* fp, maze* mp, int n_edges, route* route_list, epair_t[]);
+int odb_flags;
 #endif
 
 #define CELL(n) ((cell*)ND_alg(n))
@@ -443,13 +445,41 @@ assignSegs (int nrtes, route* route_list, maze* mp)
 }
 
 /* addLoop:
- * Add temporary nodes to sgraph corresponding to cell cp, represented
- * by np.
+ * Add two temporary nodes to sgraph corresponding to two ends of a loop at cell cp, i
+ * represented by dp and sp.
  */
 static void
-addLoop (sgraph* sg, cell* cp, snode* np)
+addLoop (sgraph* sg, cell* cp, snode* dp, snode* sp)
 {
+    int i;
+    int onTop;
+    pointf midp = midPt (cp);
+
+    for (i = 0; i < cp->nsides; i++) {
+	cell* ocp;
+	pointf p;
+	double wt;
+	snode* onp = cp->sides[i];
+
+	if (onp->isVert) continue;
+	if (onp->cells[0] == cp) {
+	    onTop = 1;
+	    ocp = onp->cells[1];
+	}
+	else {
+	    onTop = 0;
+	    ocp = onp->cells[0];
+	}
+	p = sidePt (onp, ocp);
+	wt = abs(p.x - midp.x) +  abs(p.y - midp.y);
+	if (onTop)
+	    createSEdge (sg, sp, onp, 0);  /* FIX weight */
+	else
+	    createSEdge (sg, dp, onp, 0);  /* FIX weight */
+    }
+    sg->nnodes += 2;
 }
+
 /* addNodeEdges:
  * Add temporary node to sgraph corresponding to cell cp, represented
  * by np.
@@ -458,17 +488,19 @@ static void
 addNodeEdges (sgraph* sg, cell* cp, snode* np)
 {
     int i;
+    pointf midp = midPt (cp);
+
     for (i = 0; i < cp->nsides; i++) {
 	snode* onp = cp->sides[i];
 	cell* ocp;
-	pointf midp, p;
+	pointf p;
 	double wt;
+
 	if (onp->cells[0] == cp)
 	    ocp = onp->cells[1];
 	else
 	    ocp = onp->cells[0];
 	p = sidePt (onp, ocp);
-	midp = midPt (cp);
 	wt = abs(p.x - midp.x) +  abs(p.y - midp.y);
 	createSEdge (sg, np, onp, 0);  /* FIX weight */
     }
@@ -552,7 +584,7 @@ assignTrackNo (Dt_t* chans)
 	    cp = (channel*)l2;
 	    if (cp->cnt) {
 #ifdef DEBUG
-/* dumpChanG (cp, ((chanItem*)l1)->v); */
+    if (odb_flags & ODB_CHANG) dumpChanG (cp, ((chanItem*)l1)->v);
 #endif
 		top_sort (cp->G);
 		for (k=0;k<cp->cnt;k++)
@@ -1076,10 +1108,6 @@ assignTracks (int nrtes, route* route_list, maze* mp)
     assignTrackNo (mp->vchans);
 }
 
-#ifdef DEBUG
-static void emitGraph (FILE* fp, maze* mp, Agraph_t* g, route* route_list);
-#endif
-
 static double
 vtrack (segment* seg, maze* m)
 {
@@ -1100,11 +1128,6 @@ htrack (segment* seg, maze* m)
   return lo + f*(hi-lo);
 }
 
-typedef struct {
-    int d;
-    Agedge_t* e;
-} epair_t;
-
 static pointf
 addPoints(pointf p0, pointf p1)
 {
@@ -1114,16 +1137,17 @@ addPoints(pointf p0, pointf p1)
 }
 
 static void
-attachOrthoEdges (maze* mp, int n_edges, route* route_list, splineInfo *sinfo, epair_t es[])
+attachOrthoEdges (Agraph_t* g, maze* mp, int n_edges, route* route_list, splineInfo *sinfo, epair_t es[], int doLbls)
 {
     int irte = 0;
-    int i, ipt, npts;;
+    int i, ipt, npts;
     pointf* ispline = 0;
     int splsz = 0;
     pointf p, p1, q1;
     route rte;
     segment* seg;
     Agedge_t* e;
+    textlabel_t* lbl;
 
     for (; irte < n_edges; irte++) {
 	e = es[irte].e;
@@ -1169,10 +1193,11 @@ attachOrthoEdges (maze* mp, int n_edges, route* route_list, splineInfo *sinfo, e
 		p.x = q1.x;
 	}
 	ispline[ipt] = ispline[ipt+1] = p;
-
 	if (Verbose > 1)
-		fprintf(stderr, "ortho %s %s\n", agnameof(agtail(e)),agnameof(aghead(e)));
+	    fprintf(stderr, "ortho %s %s\n", agnameof(agtail(e)),agnameof(aghead(e)));
 	clip_and_install(e, aghead(e), ispline, npts, sinfo);
+	if (doLbls && (lbl = ED_label(e)) && !lbl->set)
+	    addEdgeLabels(g, e, p1, q1);
     }
     free(ispline);
 }
@@ -1200,10 +1225,15 @@ static boolean swap_ends_p(edge_t * e)
     return FALSE;
 }
 
-static splineInfo sinfo = { swap_ends_p, spline_merge, 1 };
+static splineInfo sinfo = { swap_ends_p, spline_merge, 1, 1 };
 
+/* orthoEdges:
+ * For edges without position information, construct an orthogonal routing.
+ * If doLbls is true, use edge label info when available to guide routing, 
+ * and set label pos for those edges for which this info is not available.
+ */
 void
-orthoEdges (Agraph_t* g, int useLbls)
+orthoEdges (Agraph_t* g, int doLbls)
 {
     sgraph* sg;
     maze* mp;
@@ -1218,13 +1248,46 @@ orthoEdges (Agraph_t* g, int useLbls)
     cell* start;
     cell* dest;
     PointSet* ps;
+    textlabel_t* lbl;
 
     if (Concentrate) 
 	ps = newPS();
 
-    mp = mkMaze (g);
+#ifdef DEBUG
+    {
+	char* s = agget(g, "odb");
+        char c;
+	odb_flags = 0;
+	if (s && (*s != '\0')) {
+	    while ((c = *s++)) {
+		switch (c) {
+		case 'c' :
+		    odb_flags |= ODB_CHANG;     // emit channel graph 
+		    break;
+		case 'i' :
+		    odb_flags |= (ODB_SGRAPH|ODB_IGRAPH);  // emit search graphs
+		    break;
+		case 'm' :
+		    odb_flags |= ODB_MAZE;      // emit maze
+		    break;
+		case 'r' :
+		    odb_flags |= ODB_ROUTE;     // emit routes in maze
+		    break;
+		case 's' :
+		    odb_flags |= ODB_SGRAPH;    // emit search graph 
+		    break;
+		}
+	    }
+	}
+    }
+#endif
+    mp = mkMaze (g, doLbls);
     sg = mp->sg;
+#ifdef DEBUG
+    if (odb_flags & ODB_SGRAPH) emitSearchGraph (stderr, sg);
+#endif
 
+    /* store edges to be routed in es, along with their lengths */
     n_edges = 0;
     for (n = agfstnode (g); n; n = agnxtnode(g, n)) {
         for (e = agfstout(g, n); e; e = agnxtout(g,e)) {
@@ -1256,17 +1319,24 @@ orthoEdges (Agraph_t* g, int useLbls)
     sn = &sg->nodes[gstart];
     dn = &sg->nodes[gstart+1];
     for (i = 0; i < n_edges; i++) {
+#ifdef DEBUG
+	if ((i > 0) && (odb_flags & ODB_IGRAPH)) emitSearchGraph (stderr, sg);
+#endif
 	e = es[i].e;
         start = CELL(agtail(e));
         dest = CELL(aghead(e));
 
-	if (start == dest)
-	    addLoop (sg, start, dn);
+	if (doLbls && (lbl = ED_label(e)) && lbl->set) {
+	}
 	else {
-       	    addNodeEdges (sg, dest, dn);
-	    addNodeEdges (sg, start, sn);
+	    if (start == dest)
+		addLoop (sg, start, dn, sn);
+	    else {
+       		addNodeEdges (sg, dest, dn);
+		addNodeEdges (sg, start, sn);
+	    }
+       	    shortPath (sg, dn, sn);
 	}
-       	shortPath (sg, dn, sn);
 	    
        	route_list[i] = convertSPtoRoute(sg, sn, dn);
        	reset (sg);
@@ -1277,8 +1347,10 @@ orthoEdges (Agraph_t* g, int useLbls)
     mp->vchans = extractVChans (mp);
     assignSegs (n_edges, route_list, mp);
     assignTracks (n_edges, route_list, mp);
-    /* emitGraph (stdout, mp, g, route_list); */
-    attachOrthoEdges (mp, n_edges, route_list, &sinfo, es);
+#ifdef DEBUG
+    if (odb_flags & ODB_ROUTE) emitGraph (stderr, mp, n_edges, route_list, es);
+#endif
+    attachOrthoEdges (g, mp, n_edges, route_list, &sinfo, es, doLbls);
 
     if (Concentrate)
 	freePS (ps);
@@ -1357,54 +1429,54 @@ coordOf (cell* cp, snode* np)
 static boxf
 emitEdge (FILE* fp, Agedge_t* e, route rte, maze* m, int ix, boxf bb)
 {
-  int i, x, y;
-  boxf n = CELL(aghead(e))->bb;
-  segment* seg = rte.segs;
-  if (seg->isVert) {
-    x = vtrack(seg, m);
-    y = (n.UR.y + n.LL.y)/2;
-  }
-  else {
-    y = htrack(seg, m);
-    x = (n.UR.x + n.LL.x)/2;
-  }
-  bb.LL.x = MIN(bb.LL.x, SC*x);
-  bb.LL.y = MIN(bb.LL.y, SC*y);
-  bb.UR.x = MAX(bb.UR.x, SC*x);
-  bb.UR.y = MAX(bb.UR.y, SC*y);
-  fprintf (fp, "newpath %d %d moveto\n", SC*x, SC*y);
-
-  for (i = 1;i<rte.n;i++) {
-    seg = rte.segs+i;
+    int i, x, y;
+    boxf n = CELL(agtail(e))->bb;
+    segment* seg = rte.segs;
     if (seg->isVert) {
-      x = vtrack(seg, m);
+	x = vtrack(seg, m);
+	y = (n.UR.y + n.LL.y)/2;
     }
     else {
-      y = htrack(seg, m);
+	y = htrack(seg, m);
+	x = (n.UR.x + n.LL.x)/2;
     }
     bb.LL.x = MIN(bb.LL.x, SC*x);
     bb.LL.y = MIN(bb.LL.y, SC*y);
     bb.UR.x = MAX(bb.UR.x, SC*x);
     bb.UR.y = MAX(bb.UR.y, SC*y);
-    fprintf (fp, "%d %d lineto\n", SC*x, SC*y);
-  }
+    fprintf (fp, "newpath %d %d moveto\n", SC*x, SC*y);
 
-  n = CELL(agtail(e))->bb;
-  if (seg->isVert) {
-    x = vtrack(seg, m);
-    y = (n.UR.y + n.LL.y)/2;
-  }
-  else {
-    y = htrack(seg, m);
-    x = (n.LL.x + n.UR.x)/2;
-  }
-  bb.LL.x = MIN(bb.LL.x, SC*x);
-  bb.LL.y = MIN(bb.LL.y, SC*y);
-  bb.UR.x = MAX(bb.UR.x, SC*x);
-  bb.UR.y = MAX(bb.UR.y, SC*y);
-  fprintf (fp, "%d %d lineto stroke\n", SC*x, SC*y);
+    for (i = 1;i<rte.n;i++) {
+	seg = rte.segs+i;
+	if (seg->isVert) {
+	    x = vtrack(seg, m);
+	}
+	else {
+	    y = htrack(seg, m);
+	}
+	bb.LL.x = MIN(bb.LL.x, SC*x);
+	bb.LL.y = MIN(bb.LL.y, SC*y);
+	bb.UR.x = MAX(bb.UR.x, SC*x);
+	bb.UR.y = MAX(bb.UR.y, SC*y);
+	fprintf (fp, "%d %d lineto\n", SC*x, SC*y);
+    }
 
-  return bb;
+    n = CELL(aghead(e))->bb;
+    if (seg->isVert) {
+	x = vtrack(seg, m);
+	y = (n.UR.y + n.LL.y)/2;
+    }
+    else {
+	y = htrack(seg, m);
+	x = (n.LL.x + n.UR.x)/2;
+    }
+    bb.LL.x = MIN(bb.LL.x, SC*x);
+    bb.LL.y = MIN(bb.LL.y, SC*y);
+    bb.UR.x = MAX(bb.UR.x, SC*x);
+    bb.UR.y = MAX(bb.UR.y, SC*y);
+    fprintf (fp, "%d %d lineto stroke\n", SC*x, SC*y);
+
+    return bb;
 }
 
 static void
@@ -1439,13 +1511,11 @@ emitSearchGraph (FILE* fp, sgraph* sg)
 }
 
 static void
-emitGraph (FILE* fp, maze* mp, Agraph_t* g, route* route_list)
+emitGraph (FILE* fp, maze* mp, int n_edges, route* route_list, epair_t es[])
 {
-  int i;
-  boxf bb, absbb;
-  box bbox;
-  Agnode_t* n;
-  Agedge_t* e;
+    int i;
+    boxf bb, absbb;
+    box bbox;
 
     absbb.LL.x = absbb.LL.y = MAXDOUBLE;
     absbb.UR.x = absbb.UR.y = -MAXDOUBLE;
@@ -1456,31 +1526,27 @@ emitGraph (FILE* fp, maze* mp, Agraph_t* g, route* route_list)
     fputs ("0 0 1 setrgbcolor\n", fp);
     for (i = 0; i < mp->ngcells; i++) {
       bb = mp->gcells[i].bb;
-      printf ("%f %f %f %f node\n", bb.LL.x, bb.LL.y, bb.UR.x, bb.UR.y);
+      fprintf (fp, "%f %f %f %f node\n", bb.LL.x, bb.LL.y, bb.UR.x, bb.UR.y);
     }
 
-    i = 0;
-    for (n = agfstnode (g); n; n = agnxtnode(g, n)) {
-        for (e = agfstout(g, n); e; e = agnxtout(g,e)) {
-	    absbb = emitEdge (fp, e, route_list[i], mp, i, absbb);
-	    i++;
-	}
+    for (i = 0; i < n_edges; i++) {
+	absbb = emitEdge (fp, es[i].e, route_list[i], mp, i, absbb);
     }
     
     fputs ("0.8 0.8 0.8 setrgbcolor\n", fp);
     for (i = 0; i < mp->ncells; i++) {
       bb = mp->cells[i].bb;
-      printf ("%f %f %f %f cell\n", bb.LL.x, bb.LL.y, bb.UR.x, bb.UR.y);
+      fprintf (fp, "%f %f %f %f cell\n", bb.LL.x, bb.LL.y, bb.UR.x, bb.UR.y);
       absbb.LL.x = MIN(absbb.LL.x, bb.LL.x);
       absbb.LL.y = MIN(absbb.LL.y, bb.LL.y);
       absbb.UR.x = MAX(absbb.UR.x, bb.UR.x);
       absbb.UR.y = MAX(absbb.UR.y, bb.UR.y);
     }
 
-  bbox.LL.x = absbb.LL.x + TRANS;
-  bbox.LL.y = absbb.LL.y + TRANS;
-  bbox.UR.x = absbb.UR.x + TRANS;
-  bbox.UR.y = absbb.UR.y + TRANS;
-  fprintf (fp, epilog2, bbox.LL.x, bbox.LL.y,  bbox.UR.x, bbox.UR.y);
+    bbox.LL.x = absbb.LL.x + TRANS;
+    bbox.LL.y = absbb.LL.y + TRANS;
+    bbox.UR.x = absbb.UR.x + TRANS;
+    bbox.UR.y = absbb.UR.y + TRANS;
+    fprintf (fp, epilog2, bbox.LL.x, bbox.LL.y,  bbox.UR.x, bbox.UR.y);
 }
 #endif
