@@ -1,18 +1,15 @@
-/* $Id: partition.c,v 1.4 2009/06/03 01:10:54 ellson Exp $Revision: */
+/* $Id: partition.c,v 1.7 2011/01/25 16:30:49 ellson Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -43,6 +40,13 @@
 #define CROSS_SINE(v0, v1) ((v0).x * (v1).y - (v1).x * (v0).y)
 #define LENGTH(v0) (sqrt((v0).x * (v0).x + (v0).y * (v0).y))
 
+#ifndef HAVE_SRAND48
+#define srand48 srand
+#endif
+#ifdef WIN32
+extern double drand48(void);
+#endif
+
 typedef struct {
   int vnum;
   int next;         /* Circularly linked list  */
