@@ -1,18 +1,15 @@
-/* $Id: trapezoid.c,v 1.4 2009/06/03 01:10:54 ellson Exp $Revision: */
+/* $Id: trapezoid.c,v 1.7 2011/01/25 16:30:49 ellson Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 #ifdef HAVE_CONFIG_H
@@ -29,6 +26,10 @@
 #include <memory.h>
 #include <trap.h>
 
+#ifdef WIN32
+#define log2(x)  (log(x)/log(2))
+#endif
+
 /* Node types */
 
 #define T_X     1
@@ -1023,7 +1024,7 @@ static int math_logstar_n(int n)
   double v;
 
   for (i = 0, v = (double) n; v >= 1; i++)
-    v = log2(v);
+      v = log2(v);
 
   return (i - 1);
 }
@@ -1034,7 +1035,7 @@ static int math_N(int n, int h)
   double v;
 
   for (i = 0, v = (int) n; i < h; i++)
-    v = log2(v);
+      v = log2(v);
 
   return (int) ceil((double) 1.0*n/v);
 }
