@@ -1,18 +1,15 @@
+/* $Id: patchworkinit.c,v 1.9 2011/04/20 22:10:10 erg Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
-
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include    "patchwork.h"
 #include    "adjust.h"
@@ -111,16 +108,12 @@ mkClusters (graph_t * g, clist_t* pclist, graph_t* parent)
 static void patchwork_init_node(node_t * n)
 {
     agset(n,"shape","box");
-    common_init_node_opt(n,FALSE);
-    /* gv_nodesize(n, GD_flip(agraphof(n))); */
-    /* ND_pos(n) = ALLOC(GD_ndim(agraphof(n)), 0, double); */
+    /* common_init_node_opt(n,FALSE); */
 }
 
 static void patchwork_init_edge(edge_t * e)
 {
     /* common_init_edge(e); */
-
-    ED_factor(e) = late_double(e, E_weight, 1.0, 0.0);
 }
 
 static void patchwork_init_node_edge(graph_t * g)
@@ -143,7 +136,7 @@ static void patchwork_init_node_edge(graph_t * g)
     }
 }
 
-void patchwork_init_graph(graph_t * g)
+static void patchwork_init_graph(graph_t * g)
 {
 #ifndef WITH_CGRAPH
     N_shape = agnodeattr(g, "shape", "box");
@@ -157,6 +150,21 @@ void patchwork_init_graph(graph_t * g)
     patchwork_init_node_edge(g);
 }
 
+/* patchwork_layout:
+ * The current version makes no use of edges, neither for a notion of connectivity
+ * nor during drawing.
+ */
+void patchwork_layout(Agraph_t *g)
+{
+    patchwork_init_graph(g);
+
+    if ((agnnodes(g) == 0) && (GD_n_cluster(g) == 0)) return;
+
+    patchworkLayout (g);
+
+    dotneato_postprocess(g);
+}
+
 static void patchwork_cleanup_graph(graph_t * g)
 {
     free(GD_neato_nlist(g));
@@ -173,7 +181,10 @@ void patchwork_cleanup(graph_t * g)
     node_t *n;
     edge_t *e;
 
-    for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
+    n = agfstnode(g);
+    if (!n) return;
+    free (ND_alg(n));
+    for (; n; n = agnxtnode(g, n)) {
 	for (e = agfstout(g, n); e; e = agnxtout(g, e)) {
 	    gv_cleanup_edge(e);
 	}
