@@ -1,18 +1,15 @@
-/* $Id: twopiinit.c,v 1.19 2009/08/11 21:21:20 erg Exp $ $Revision: 1.19 $ */
+/* $Id: twopiinit.c,v 1.24 2011/04/15 17:02:44 erg Exp $ $Revision: 1.24 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2004 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 
 /*
@@ -39,9 +36,11 @@ static void twopi_init_node_edge(graph_t * g)
     node_t *n;
     edge_t *e;
     int i = 0;
-    rdata* alg = N_NEW(agnnodes(g), rdata);
+    int n_nodes = agnnodes(g);
+    rdata* alg;
 
-    GD_neato_nlist(g) = N_NEW(agnnodes(g) + 1, node_t *);
+    alg = N_NEW(n_nodes, rdata);
+    GD_neato_nlist(g) = N_NEW(n_nodes + 1, node_t *);
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	neato_init_node(n);
 	ND_alg(n) = alg + i;
@@ -54,6 +53,21 @@ static void twopi_init_node_edge(graph_t * g)
     }
 }
 
+static void scaleGraph (graph_t * g, node_t* root, pointf sc)
+{
+    pointf ctr;
+    node_t* n;
+
+    ctr.x = ND_pos(root)[0];
+    ctr.y = ND_pos(root)[1];
+
+    for (n = agfstnode(g); n; n = agnxtnode (g, n)) {
+	if (n == root) continue;
+	ND_pos(n)[0] = sc.x*(ND_pos(n)[0] - ctr.x) + ctr.x;
+	ND_pos(n)[1] = sc.y*(ND_pos(n)[1] - ctr.y) + ctr.y;
+    }
+}
+
 void twopi_init_graph(graph_t * g)
 {
     setEdgeType (g, ET_LINE);
@@ -68,16 +82,38 @@ void twopi_layout(Agraph_t * g)
 {
     Agnode_t *ctr = 0;
     char *s;
+    int setRoot = 0;
+    pointf sc;
+    int doScale = 0;
+    int r;
+
+    if (agnnodes(g) == 0) return;
 
     twopi_init_graph(g);
     s = agget(g, "root");
-    if (s && (*s != '\0')) {
-	ctr = agfindnode(g, s);
-	if (!ctr) {
-	    agerr(AGWARN, "specified root node \"%s\" was not found.", s);
-	    agerr(AGPREV, "Using default calculation for root node\n");
+    if ((s = agget(g, "root"))) {
+	if (*s) {
+	    ctr = agfindnode(g, s);
+	    if (!ctr) {
+		agerr(AGWARN, "specified root node \"%s\" was not found.", s);
+		agerr(AGPREV, "Using default calculation for root node\n");
+		setRoot = 1;
+	    }
+	}
+	else {
+	    setRoot = 1;
 	}
     }
+
+    if ((s = agget(g, "scale")) && *s) {
+	if ((r = sscanf (s, "%lf,%lf",&sc.x,&sc.y))) {
+	    if (r == 1) sc.y = sc.x;
+	    doScale = 1;
+	    if (Verbose)
+		fprintf (stderr, "scale = (%f,%f)\n", sc.x, sc.y);
+	}
+    }
+
     if (agnnodes(g)) {
 	Agraph_t **ccs;
 	Agraph_t *sg;
@@ -87,8 +123,12 @@ void twopi_layout(Agraph_t * g)
 
 	ccs = ccomps(g, &ncc, 0);
 	if (ncc == 1) {
-	    circleLayout(g, ctr);
+	    c = circleLayout(g, ctr);
+	    if (setRoot && !ctr)
+		ctr = c;
 	    free(ND_alg(agfstnode(g)));
+	    if (doScale)
+		scaleGraph (g, c, sc);
 	    adjustNodes(g);
 	    spline_edges(g);
 	} else {
@@ -103,7 +143,11 @@ void twopi_layout(Agraph_t * g)
 		else
 		    c = 0;
 		nodeInduce(sg);
-		circleLayout(sg, c);
+		c = circleLayout(sg, c);
+	        if (setRoot && !ctr)
+		    ctr = c;
+		if (doScale)
+		    scaleGraph (sg, c, sc);
 		adjustNodes(sg);
 		setEdgeType (sg, ET_LINE);
 		spline_edges(sg);
@@ -116,6 +160,8 @@ void twopi_layout(Agraph_t * g)
 	}
 	free(ccs);
     }
+    if (setRoot)
+	agset (g, "root", agnameof (ctr)); 
     dotneato_postprocess(g);
 
 }
@@ -136,7 +182,10 @@ void twopi_cleanup(graph_t * g)
     node_t *n;
     edge_t *e;
 
-    for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
+    n = agfstnode (g);
+    if (!n) return; /* empty graph */
+    free (ND_alg(n));
+    for (; n; n = agnxtnode(g, n)) {
 	for (e = agfstout(g, n); e; e = agnxtout(g, e)) {
 	    gv_cleanup_edge(e);
 	}
