@@ -1,18 +1,15 @@
-/* $Id: xdot.c,v 1.19 2009/11/06 18:37:28 erg Exp $Revision: */
+/* $Id: xdot.c,v 1.22 2011/01/26 23:52:19 erg Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
-/**********************************************************
-*      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
-*                                                         *
-*            Copyright (c) 1994-2007 AT&T Corp.           *
-*                and is licensed under the                *
-*            Common Public License, Version 1.0           *
-*                      by AT&T Corp.                      *
-*                                                         *
-*        Information and Software Systems Research        *
-*              AT&T Research, Florham Park NJ             *
-**********************************************************/
+/*************************************************************************
+ * Copyright (c) 2011 AT&T Intellectual Property 
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ *************************************************************************/
 
 #include <xdot.h>
 #include <stdlib.h>
@@ -37,11 +34,21 @@ static char *parseReal(char *s, double *fp)
 
 static char *parseInt(char *s, int *ip)
 {
-    int r, sz;
+    char* endp;
+
+#ifdef UNUSED
     r = sscanf(s, "%d%n", ip, &sz);
     if (r != 1) return 0;
     else return (s + sz);
+#endif
+
+    *ip = (int)strtol (s, &endp, 10);
+    if (s == endp)
+	return 0;
+    else
+	return endp;
 }
+
 #ifdef UNUSED
 static char *parsePoint(char *s, xdot_point * pp)
 {
@@ -55,11 +62,40 @@ static char *parsePoint(char *s, xdot_point * pp)
 
 static char *parseRect(char *s, xdot_rect * rp)
 {
+    char* endp;
+#ifdef UNUSED
     int r, sz;
     r = sscanf(s, "%lf %lf %lf %lf%n", &(rp->x), &(rp->y), &(rp->w),
 	       &(rp->h), &sz);
     if (r != 4) return 0;
     else return (s + sz);
+#endif
+
+    rp->x = strtod (s, &endp);
+    if (s == endp)
+	return 0;
+    else
+	s = endp;
+
+    rp->y = strtod (s, &endp);
+    if (s == endp)
+	return 0;
+    else
+	s = endp;
+
+    rp->w = strtod (s, &endp);
+    if (s == endp)
+	return 0;
+    else
+	s = endp;
+
+    rp->y = strtod (s, &endp);
+    if (s == endp)
+	return 0;
+    else
+	s = endp;
+
+    return s;
 }
 
 static char *parsePolyline(char *s, xdot_polyline * pp)
@@ -631,6 +667,61 @@ void freeXDot (xdot * x)
     free(x);
 }
 
+int statXDot (xdot* x, xdot_stats* sp)
+{
+    int i;
+    xdot_op *op;
+    char *base;
+
+    if (!x || !sp) return 1;
+    memset(sp, 0, sizeof(xdot_stats));
+    sp->cnt = x->cnt;
+    base = (char *) (x->ops);
+    for (i = 0; i < x->cnt; i++) {
+	op = (xdot_op *) (base + i * x->sz);
+ 	switch (op->kind) {
+	case xd_filled_ellipse:
+	case xd_unfilled_ellipse:
+	    sp->n_ellipse++;
+	    break;
+	case xd_filled_polygon:
+	case xd_unfilled_polygon:
+	    sp->n_polygon++;
+	    sp->n_polygon_pts += op->u.polygon.cnt;
+	    break;
+	case xd_filled_bezier:
+	case xd_unfilled_bezier:
+	    sp->n_bezier++;
+	    sp->n_bezier_pts += op->u.bezier.cnt;
+	    break;
+	case xd_polyline:
+	    sp->n_polyline++;
+	    sp->n_polyline_pts += op->u.polyline.cnt;
+	    break;
+	case xd_text:
+	    sp->n_text++;
+	    break;
+	case xd_image:
+	    sp->n_image++;
+	    break;
+	case xd_fill_color:
+	case xd_pen_color:
+	    sp->n_color++;
+	    break;
+        case xd_font:
+	    sp->n_font++;
+	    break;
+	case xd_style:
+	    sp->n_style++;
+	    break;
+	default :
+	    break;
+	}
+    }
+    
+    return 0;
+}
+
 #if 0
 static void execOp(xdot_op * op, int param)
 {
